(self["webpackChunkgrader_labextension"] = self["webpackChunkgrader_labextension"] || []).push([["vendors-node_modules_blueprintjs_icons_lib_esm_generated_iconNames_js-node_modules_jupyterlab-6aeeed"],{

/***/ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js":
/*!**********************************************************************!*\
  !*** ./node_modules/@babel/runtime/helpers/interopRequireDefault.js ***!
  \**********************************************************************/
/***/ ((module) => {

function _interopRequireDefault(obj) {
  return obj && obj.__esModule ? obj : {
    "default": obj
  };
}

module.exports = _interopRequireDefault, module.exports.__esModule = true, module.exports["default"] = module.exports;

/***/ }),

/***/ "./node_modules/@blueprintjs/icons/lib/esm/generated/iconNames.js":
/*!************************************************************************!*\
  !*** ./node_modules/@blueprintjs/icons/lib/esm/generated/iconNames.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ADD": () => (/* binding */ ADD),
/* harmony export */   "ADD_CLIP": () => (/* binding */ ADD_CLIP),
/* harmony export */   "ADD_COLUMN_LEFT": () => (/* binding */ ADD_COLUMN_LEFT),
/* harmony export */   "ADD_COLUMN_RIGHT": () => (/* binding */ ADD_COLUMN_RIGHT),
/* harmony export */   "ADD_LOCATION": () => (/* binding */ ADD_LOCATION),
/* harmony export */   "ADD_ROW_BOTTOM": () => (/* binding */ ADD_ROW_BOTTOM),
/* harmony export */   "ADD_ROW_TOP": () => (/* binding */ ADD_ROW_TOP),
/* harmony export */   "ADD_TO_ARTIFACT": () => (/* binding */ ADD_TO_ARTIFACT),
/* harmony export */   "ADD_TO_FOLDER": () => (/* binding */ ADD_TO_FOLDER),
/* harmony export */   "AIRPLANE": () => (/* binding */ AIRPLANE),
/* harmony export */   "ALIGNMENT_BOTTOM": () => (/* binding */ ALIGNMENT_BOTTOM),
/* harmony export */   "ALIGNMENT_HORIZONTAL_CENTER": () => (/* binding */ ALIGNMENT_HORIZONTAL_CENTER),
/* harmony export */   "ALIGNMENT_LEFT": () => (/* binding */ ALIGNMENT_LEFT),
/* harmony export */   "ALIGNMENT_RIGHT": () => (/* binding */ ALIGNMENT_RIGHT),
/* harmony export */   "ALIGNMENT_TOP": () => (/* binding */ ALIGNMENT_TOP),
/* harmony export */   "ALIGNMENT_VERTICAL_CENTER": () => (/* binding */ ALIGNMENT_VERTICAL_CENTER),
/* harmony export */   "ALIGN_CENTER": () => (/* binding */ ALIGN_CENTER),
/* harmony export */   "ALIGN_JUSTIFY": () => (/* binding */ ALIGN_JUSTIFY),
/* harmony export */   "ALIGN_LEFT": () => (/* binding */ ALIGN_LEFT),
/* harmony export */   "ALIGN_RIGHT": () => (/* binding */ ALIGN_RIGHT),
/* harmony export */   "ANNOTATION": () => (/* binding */ ANNOTATION),
/* harmony export */   "ANTENNA": () => (/* binding */ ANTENNA),
/* harmony export */   "APPLICATION": () => (/* binding */ APPLICATION),
/* harmony export */   "APPLICATIONS": () => (/* binding */ APPLICATIONS),
/* harmony export */   "APP_HEADER": () => (/* binding */ APP_HEADER),
/* harmony export */   "ARCHIVE": () => (/* binding */ ARCHIVE),
/* harmony export */   "AREA_OF_INTEREST": () => (/* binding */ AREA_OF_INTEREST),
/* harmony export */   "ARRAY": () => (/* binding */ ARRAY),
/* harmony export */   "ARRAY_BOOLEAN": () => (/* binding */ ARRAY_BOOLEAN),
/* harmony export */   "ARRAY_DATE": () => (/* binding */ ARRAY_DATE),
/* harmony export */   "ARRAY_NUMERIC": () => (/* binding */ ARRAY_NUMERIC),
/* harmony export */   "ARRAY_STRING": () => (/* binding */ ARRAY_STRING),
/* harmony export */   "ARRAY_TIMESTAMP": () => (/* binding */ ARRAY_TIMESTAMP),
/* harmony export */   "ARROWS_HORIZONTAL": () => (/* binding */ ARROWS_HORIZONTAL),
/* harmony export */   "ARROWS_VERTICAL": () => (/* binding */ ARROWS_VERTICAL),
/* harmony export */   "ARROW_BOTTOM_LEFT": () => (/* binding */ ARROW_BOTTOM_LEFT),
/* harmony export */   "ARROW_BOTTOM_RIGHT": () => (/* binding */ ARROW_BOTTOM_RIGHT),
/* harmony export */   "ARROW_DOWN": () => (/* binding */ ARROW_DOWN),
/* harmony export */   "ARROW_LEFT": () => (/* binding */ ARROW_LEFT),
/* harmony export */   "ARROW_RIGHT": () => (/* binding */ ARROW_RIGHT),
/* harmony export */   "ARROW_TOP_LEFT": () => (/* binding */ ARROW_TOP_LEFT),
/* harmony export */   "ARROW_TOP_RIGHT": () => (/* binding */ ARROW_TOP_RIGHT),
/* harmony export */   "ARROW_UP": () => (/* binding */ ARROW_UP),
/* harmony export */   "ASTERISK": () => (/* binding */ ASTERISK),
/* harmony export */   "AUTOMATIC_UPDATES": () => (/* binding */ AUTOMATIC_UPDATES),
/* harmony export */   "BACKLINK": () => (/* binding */ BACKLINK),
/* harmony export */   "BADGE": () => (/* binding */ BADGE),
/* harmony export */   "BANK_ACCOUNT": () => (/* binding */ BANK_ACCOUNT),
/* harmony export */   "BAN_CIRCLE": () => (/* binding */ BAN_CIRCLE),
/* harmony export */   "BARCODE": () => (/* binding */ BARCODE),
/* harmony export */   "BLANK": () => (/* binding */ BLANK),
/* harmony export */   "BLOCKED_PERSON": () => (/* binding */ BLOCKED_PERSON),
/* harmony export */   "BOLD": () => (/* binding */ BOLD),
/* harmony export */   "BOOK": () => (/* binding */ BOOK),
/* harmony export */   "BOOKMARK": () => (/* binding */ BOOKMARK),
/* harmony export */   "BOX": () => (/* binding */ BOX),
/* harmony export */   "BRIEFCASE": () => (/* binding */ BRIEFCASE),
/* harmony export */   "BRING_DATA": () => (/* binding */ BRING_DATA),
/* harmony export */   "BUGGY": () => (/* binding */ BUGGY),
/* harmony export */   "BUILD": () => (/* binding */ BUILD),
/* harmony export */   "CALCULATOR": () => (/* binding */ CALCULATOR),
/* harmony export */   "CALENDAR": () => (/* binding */ CALENDAR),
/* harmony export */   "CAMERA": () => (/* binding */ CAMERA),
/* harmony export */   "CARET_DOWN": () => (/* binding */ CARET_DOWN),
/* harmony export */   "CARET_LEFT": () => (/* binding */ CARET_LEFT),
/* harmony export */   "CARET_RIGHT": () => (/* binding */ CARET_RIGHT),
/* harmony export */   "CARET_UP": () => (/* binding */ CARET_UP),
/* harmony export */   "CARGO_SHIP": () => (/* binding */ CARGO_SHIP),
/* harmony export */   "CELL_TOWER": () => (/* binding */ CELL_TOWER),
/* harmony export */   "CHANGES": () => (/* binding */ CHANGES),
/* harmony export */   "CHART": () => (/* binding */ CHART),
/* harmony export */   "CHAT": () => (/* binding */ CHAT),
/* harmony export */   "CHEVRON_BACKWARD": () => (/* binding */ CHEVRON_BACKWARD),
/* harmony export */   "CHEVRON_DOWN": () => (/* binding */ CHEVRON_DOWN),
/* harmony export */   "CHEVRON_FORWARD": () => (/* binding */ CHEVRON_FORWARD),
/* harmony export */   "CHEVRON_LEFT": () => (/* binding */ CHEVRON_LEFT),
/* harmony export */   "CHEVRON_RIGHT": () => (/* binding */ CHEVRON_RIGHT),
/* harmony export */   "CHEVRON_UP": () => (/* binding */ CHEVRON_UP),
/* harmony export */   "CIRCLE": () => (/* binding */ CIRCLE),
/* harmony export */   "CIRCLE_ARROW_DOWN": () => (/* binding */ CIRCLE_ARROW_DOWN),
/* harmony export */   "CIRCLE_ARROW_LEFT": () => (/* binding */ CIRCLE_ARROW_LEFT),
/* harmony export */   "CIRCLE_ARROW_RIGHT": () => (/* binding */ CIRCLE_ARROW_RIGHT),
/* harmony export */   "CIRCLE_ARROW_UP": () => (/* binding */ CIRCLE_ARROW_UP),
/* harmony export */   "CITATION": () => (/* binding */ CITATION),
/* harmony export */   "CLEAN": () => (/* binding */ CLEAN),
/* harmony export */   "CLIP": () => (/* binding */ CLIP),
/* harmony export */   "CLIPBOARD": () => (/* binding */ CLIPBOARD),
/* harmony export */   "CLOUD": () => (/* binding */ CLOUD),
/* harmony export */   "CLOUD_DOWNLOAD": () => (/* binding */ CLOUD_DOWNLOAD),
/* harmony export */   "CLOUD_UPLOAD": () => (/* binding */ CLOUD_UPLOAD),
/* harmony export */   "CODE": () => (/* binding */ CODE),
/* harmony export */   "CODE_BLOCK": () => (/* binding */ CODE_BLOCK),
/* harmony export */   "COG": () => (/* binding */ COG),
/* harmony export */   "COLLAPSE_ALL": () => (/* binding */ COLLAPSE_ALL),
/* harmony export */   "COLUMN_LAYOUT": () => (/* binding */ COLUMN_LAYOUT),
/* harmony export */   "COMMENT": () => (/* binding */ COMMENT),
/* harmony export */   "COMPARISON": () => (/* binding */ COMPARISON),
/* harmony export */   "COMPASS": () => (/* binding */ COMPASS),
/* harmony export */   "COMPRESSED": () => (/* binding */ COMPRESSED),
/* harmony export */   "CONFIRM": () => (/* binding */ CONFIRM),
/* harmony export */   "CONSOLE": () => (/* binding */ CONSOLE),
/* harmony export */   "CONTRAST": () => (/* binding */ CONTRAST),
/* harmony export */   "CONTROL": () => (/* binding */ CONTROL),
/* harmony export */   "CREDIT_CARD": () => (/* binding */ CREDIT_CARD),
/* harmony export */   "CROSS": () => (/* binding */ CROSS),
/* harmony export */   "CROWN": () => (/* binding */ CROWN),
/* harmony export */   "CUBE": () => (/* binding */ CUBE),
/* harmony export */   "CUBE_ADD": () => (/* binding */ CUBE_ADD),
/* harmony export */   "CUBE_REMOVE": () => (/* binding */ CUBE_REMOVE),
/* harmony export */   "CURVED_RANGE_CHART": () => (/* binding */ CURVED_RANGE_CHART),
/* harmony export */   "CUT": () => (/* binding */ CUT),
/* harmony export */   "CYCLE": () => (/* binding */ CYCLE),
/* harmony export */   "DASHBOARD": () => (/* binding */ DASHBOARD),
/* harmony export */   "DATABASE": () => (/* binding */ DATABASE),
/* harmony export */   "DATA_CONNECTION": () => (/* binding */ DATA_CONNECTION),
/* harmony export */   "DATA_LINEAGE": () => (/* binding */ DATA_LINEAGE),
/* harmony export */   "DELETE": () => (/* binding */ DELETE),
/* harmony export */   "DELTA": () => (/* binding */ DELTA),
/* harmony export */   "DERIVE_COLUMN": () => (/* binding */ DERIVE_COLUMN),
/* harmony export */   "DESKTOP": () => (/* binding */ DESKTOP),
/* harmony export */   "DIAGNOSIS": () => (/* binding */ DIAGNOSIS),
/* harmony export */   "DIAGRAM_TREE": () => (/* binding */ DIAGRAM_TREE),
/* harmony export */   "DIRECTION_LEFT": () => (/* binding */ DIRECTION_LEFT),
/* harmony export */   "DIRECTION_RIGHT": () => (/* binding */ DIRECTION_RIGHT),
/* harmony export */   "DISABLE": () => (/* binding */ DISABLE),
/* harmony export */   "DOCUMENT": () => (/* binding */ DOCUMENT),
/* harmony export */   "DOCUMENT_OPEN": () => (/* binding */ DOCUMENT_OPEN),
/* harmony export */   "DOCUMENT_SHARE": () => (/* binding */ DOCUMENT_SHARE),
/* harmony export */   "DOLLAR": () => (/* binding */ DOLLAR),
/* harmony export */   "DOT": () => (/* binding */ DOT),
/* harmony export */   "DOUBLE_CARET_HORIZONTAL": () => (/* binding */ DOUBLE_CARET_HORIZONTAL),
/* harmony export */   "DOUBLE_CARET_VERTICAL": () => (/* binding */ DOUBLE_CARET_VERTICAL),
/* harmony export */   "DOUBLE_CHEVRON_DOWN": () => (/* binding */ DOUBLE_CHEVRON_DOWN),
/* harmony export */   "DOUBLE_CHEVRON_LEFT": () => (/* binding */ DOUBLE_CHEVRON_LEFT),
/* harmony export */   "DOUBLE_CHEVRON_RIGHT": () => (/* binding */ DOUBLE_CHEVRON_RIGHT),
/* harmony export */   "DOUBLE_CHEVRON_UP": () => (/* binding */ DOUBLE_CHEVRON_UP),
/* harmony export */   "DOUGHNUT_CHART": () => (/* binding */ DOUGHNUT_CHART),
/* harmony export */   "DOWNLOAD": () => (/* binding */ DOWNLOAD),
/* harmony export */   "DRAG_HANDLE_HORIZONTAL": () => (/* binding */ DRAG_HANDLE_HORIZONTAL),
/* harmony export */   "DRAG_HANDLE_VERTICAL": () => (/* binding */ DRAG_HANDLE_VERTICAL),
/* harmony export */   "DRAW": () => (/* binding */ DRAW),
/* harmony export */   "DRAWER_LEFT": () => (/* binding */ DRAWER_LEFT),
/* harmony export */   "DRAWER_LEFT_FILLED": () => (/* binding */ DRAWER_LEFT_FILLED),
/* harmony export */   "DRAWER_RIGHT": () => (/* binding */ DRAWER_RIGHT),
/* harmony export */   "DRAWER_RIGHT_FILLED": () => (/* binding */ DRAWER_RIGHT_FILLED),
/* harmony export */   "DRIVE_TIME": () => (/* binding */ DRIVE_TIME),
/* harmony export */   "DUPLICATE": () => (/* binding */ DUPLICATE),
/* harmony export */   "EDIT": () => (/* binding */ EDIT),
/* harmony export */   "EJECT": () => (/* binding */ EJECT),
/* harmony export */   "EMOJI": () => (/* binding */ EMOJI),
/* harmony export */   "ENDORSED": () => (/* binding */ ENDORSED),
/* harmony export */   "ENVELOPE": () => (/* binding */ ENVELOPE),
/* harmony export */   "EQUALS": () => (/* binding */ EQUALS),
/* harmony export */   "ERASER": () => (/* binding */ ERASER),
/* harmony export */   "ERROR": () => (/* binding */ ERROR),
/* harmony export */   "EURO": () => (/* binding */ EURO),
/* harmony export */   "EXCHANGE": () => (/* binding */ EXCHANGE),
/* harmony export */   "EXCLUDE_ROW": () => (/* binding */ EXCLUDE_ROW),
/* harmony export */   "EXPAND_ALL": () => (/* binding */ EXPAND_ALL),
/* harmony export */   "EXPORT": () => (/* binding */ EXPORT),
/* harmony export */   "EYE_OFF": () => (/* binding */ EYE_OFF),
/* harmony export */   "EYE_ON": () => (/* binding */ EYE_ON),
/* harmony export */   "EYE_OPEN": () => (/* binding */ EYE_OPEN),
/* harmony export */   "FAST_BACKWARD": () => (/* binding */ FAST_BACKWARD),
/* harmony export */   "FAST_FORWARD": () => (/* binding */ FAST_FORWARD),
/* harmony export */   "FEED": () => (/* binding */ FEED),
/* harmony export */   "FEED_SUBSCRIBED": () => (/* binding */ FEED_SUBSCRIBED),
/* harmony export */   "FILM": () => (/* binding */ FILM),
/* harmony export */   "FILTER": () => (/* binding */ FILTER),
/* harmony export */   "FILTER_KEEP": () => (/* binding */ FILTER_KEEP),
/* harmony export */   "FILTER_LIST": () => (/* binding */ FILTER_LIST),
/* harmony export */   "FILTER_OPEN": () => (/* binding */ FILTER_OPEN),
/* harmony export */   "FILTER_REMOVE": () => (/* binding */ FILTER_REMOVE),
/* harmony export */   "FLAG": () => (/* binding */ FLAG),
/* harmony export */   "FLAME": () => (/* binding */ FLAME),
/* harmony export */   "FLASH": () => (/* binding */ FLASH),
/* harmony export */   "FLOPPY_DISK": () => (/* binding */ FLOPPY_DISK),
/* harmony export */   "FLOWS": () => (/* binding */ FLOWS),
/* harmony export */   "FLOW_BRANCH": () => (/* binding */ FLOW_BRANCH),
/* harmony export */   "FLOW_END": () => (/* binding */ FLOW_END),
/* harmony export */   "FLOW_LINEAR": () => (/* binding */ FLOW_LINEAR),
/* harmony export */   "FLOW_REVIEW": () => (/* binding */ FLOW_REVIEW),
/* harmony export */   "FLOW_REVIEW_BRANCH": () => (/* binding */ FLOW_REVIEW_BRANCH),
/* harmony export */   "FOLDER_CLOSE": () => (/* binding */ FOLDER_CLOSE),
/* harmony export */   "FOLDER_NEW": () => (/* binding */ FOLDER_NEW),
/* harmony export */   "FOLDER_OPEN": () => (/* binding */ FOLDER_OPEN),
/* harmony export */   "FOLDER_SHARED": () => (/* binding */ FOLDER_SHARED),
/* harmony export */   "FOLDER_SHARED_OPEN": () => (/* binding */ FOLDER_SHARED_OPEN),
/* harmony export */   "FOLLOWER": () => (/* binding */ FOLLOWER),
/* harmony export */   "FOLLOWING": () => (/* binding */ FOLLOWING),
/* harmony export */   "FONT": () => (/* binding */ FONT),
/* harmony export */   "FORK": () => (/* binding */ FORK),
/* harmony export */   "FORM": () => (/* binding */ FORM),
/* harmony export */   "FULLSCREEN": () => (/* binding */ FULLSCREEN),
/* harmony export */   "FULL_CIRCLE": () => (/* binding */ FULL_CIRCLE),
/* harmony export */   "FULL_STACKED_CHART": () => (/* binding */ FULL_STACKED_CHART),
/* harmony export */   "FUNCTION": () => (/* binding */ FUNCTION),
/* harmony export */   "GANTT_CHART": () => (/* binding */ GANTT_CHART),
/* harmony export */   "GEOFENCE": () => (/* binding */ GEOFENCE),
/* harmony export */   "GEOLOCATION": () => (/* binding */ GEOLOCATION),
/* harmony export */   "GEOSEARCH": () => (/* binding */ GEOSEARCH),
/* harmony export */   "GIT_BRANCH": () => (/* binding */ GIT_BRANCH),
/* harmony export */   "GIT_COMMIT": () => (/* binding */ GIT_COMMIT),
/* harmony export */   "GIT_MERGE": () => (/* binding */ GIT_MERGE),
/* harmony export */   "GIT_NEW_BRANCH": () => (/* binding */ GIT_NEW_BRANCH),
/* harmony export */   "GIT_PULL": () => (/* binding */ GIT_PULL),
/* harmony export */   "GIT_PUSH": () => (/* binding */ GIT_PUSH),
/* harmony export */   "GIT_REPO": () => (/* binding */ GIT_REPO),
/* harmony export */   "GLASS": () => (/* binding */ GLASS),
/* harmony export */   "GLOBE": () => (/* binding */ GLOBE),
/* harmony export */   "GLOBE_NETWORK": () => (/* binding */ GLOBE_NETWORK),
/* harmony export */   "GRAPH": () => (/* binding */ GRAPH),
/* harmony export */   "GRAPH_REMOVE": () => (/* binding */ GRAPH_REMOVE),
/* harmony export */   "GREATER_THAN": () => (/* binding */ GREATER_THAN),
/* harmony export */   "GREATER_THAN_OR_EQUAL_TO": () => (/* binding */ GREATER_THAN_OR_EQUAL_TO),
/* harmony export */   "GRID": () => (/* binding */ GRID),
/* harmony export */   "GRID_VIEW": () => (/* binding */ GRID_VIEW),
/* harmony export */   "GROUPED_BAR_CHART": () => (/* binding */ GROUPED_BAR_CHART),
/* harmony export */   "GROUP_OBJECTS": () => (/* binding */ GROUP_OBJECTS),
/* harmony export */   "HAND": () => (/* binding */ HAND),
/* harmony export */   "HAND_DOWN": () => (/* binding */ HAND_DOWN),
/* harmony export */   "HAND_LEFT": () => (/* binding */ HAND_LEFT),
/* harmony export */   "HAND_RIGHT": () => (/* binding */ HAND_RIGHT),
/* harmony export */   "HAND_UP": () => (/* binding */ HAND_UP),
/* harmony export */   "HAT": () => (/* binding */ HAT),
/* harmony export */   "HEADER": () => (/* binding */ HEADER),
/* harmony export */   "HEADER_ONE": () => (/* binding */ HEADER_ONE),
/* harmony export */   "HEADER_THREE": () => (/* binding */ HEADER_THREE),
/* harmony export */   "HEADER_TWO": () => (/* binding */ HEADER_TWO),
/* harmony export */   "HEADSET": () => (/* binding */ HEADSET),
/* harmony export */   "HEART": () => (/* binding */ HEART),
/* harmony export */   "HEART_BROKEN": () => (/* binding */ HEART_BROKEN),
/* harmony export */   "HEATMAP": () => (/* binding */ HEATMAP),
/* harmony export */   "HEAT_GRID": () => (/* binding */ HEAT_GRID),
/* harmony export */   "HELICOPTER": () => (/* binding */ HELICOPTER),
/* harmony export */   "HELP": () => (/* binding */ HELP),
/* harmony export */   "HELPER_MANAGEMENT": () => (/* binding */ HELPER_MANAGEMENT),
/* harmony export */   "HIGHLIGHT": () => (/* binding */ HIGHLIGHT),
/* harmony export */   "HIGH_PRIORITY": () => (/* binding */ HIGH_PRIORITY),
/* harmony export */   "HISTORY": () => (/* binding */ HISTORY),
/* harmony export */   "HOME": () => (/* binding */ HOME),
/* harmony export */   "HORIZONTAL_BAR_CHART": () => (/* binding */ HORIZONTAL_BAR_CHART),
/* harmony export */   "HORIZONTAL_BAR_CHART_ASC": () => (/* binding */ HORIZONTAL_BAR_CHART_ASC),
/* harmony export */   "HORIZONTAL_BAR_CHART_DESC": () => (/* binding */ HORIZONTAL_BAR_CHART_DESC),
/* harmony export */   "HORIZONTAL_DISTRIBUTION": () => (/* binding */ HORIZONTAL_DISTRIBUTION),
/* harmony export */   "HURRICANE": () => (/* binding */ HURRICANE),
/* harmony export */   "ID_NUMBER": () => (/* binding */ ID_NUMBER),
/* harmony export */   "IMAGE_ROTATE_LEFT": () => (/* binding */ IMAGE_ROTATE_LEFT),
/* harmony export */   "IMAGE_ROTATE_RIGHT": () => (/* binding */ IMAGE_ROTATE_RIGHT),
/* harmony export */   "IMPORT": () => (/* binding */ IMPORT),
/* harmony export */   "INBOX": () => (/* binding */ INBOX),
/* harmony export */   "INBOX_FILTERED": () => (/* binding */ INBOX_FILTERED),
/* harmony export */   "INBOX_GEO": () => (/* binding */ INBOX_GEO),
/* harmony export */   "INBOX_SEARCH": () => (/* binding */ INBOX_SEARCH),
/* harmony export */   "INBOX_UPDATE": () => (/* binding */ INBOX_UPDATE),
/* harmony export */   "INFO_SIGN": () => (/* binding */ INFO_SIGN),
/* harmony export */   "INHERITANCE": () => (/* binding */ INHERITANCE),
/* harmony export */   "INHERITED_GROUP": () => (/* binding */ INHERITED_GROUP),
/* harmony export */   "INNER_JOIN": () => (/* binding */ INNER_JOIN),
/* harmony export */   "INSERT": () => (/* binding */ INSERT),
/* harmony export */   "INTERSECTION": () => (/* binding */ INTERSECTION),
/* harmony export */   "IP_ADDRESS": () => (/* binding */ IP_ADDRESS),
/* harmony export */   "ISSUE": () => (/* binding */ ISSUE),
/* harmony export */   "ISSUE_CLOSED": () => (/* binding */ ISSUE_CLOSED),
/* harmony export */   "ISSUE_NEW": () => (/* binding */ ISSUE_NEW),
/* harmony export */   "ITALIC": () => (/* binding */ ITALIC),
/* harmony export */   "JOIN_TABLE": () => (/* binding */ JOIN_TABLE),
/* harmony export */   "KEY": () => (/* binding */ KEY),
/* harmony export */   "KEY_BACKSPACE": () => (/* binding */ KEY_BACKSPACE),
/* harmony export */   "KEY_COMMAND": () => (/* binding */ KEY_COMMAND),
/* harmony export */   "KEY_CONTROL": () => (/* binding */ KEY_CONTROL),
/* harmony export */   "KEY_DELETE": () => (/* binding */ KEY_DELETE),
/* harmony export */   "KEY_ENTER": () => (/* binding */ KEY_ENTER),
/* harmony export */   "KEY_ESCAPE": () => (/* binding */ KEY_ESCAPE),
/* harmony export */   "KEY_OPTION": () => (/* binding */ KEY_OPTION),
/* harmony export */   "KEY_SHIFT": () => (/* binding */ KEY_SHIFT),
/* harmony export */   "KEY_TAB": () => (/* binding */ KEY_TAB),
/* harmony export */   "KNOWN_VEHICLE": () => (/* binding */ KNOWN_VEHICLE),
/* harmony export */   "LABEL": () => (/* binding */ LABEL),
/* harmony export */   "LAB_TEST": () => (/* binding */ LAB_TEST),
/* harmony export */   "LAYER": () => (/* binding */ LAYER),
/* harmony export */   "LAYERS": () => (/* binding */ LAYERS),
/* harmony export */   "LAYER_OUTLINE": () => (/* binding */ LAYER_OUTLINE),
/* harmony export */   "LAYOUT": () => (/* binding */ LAYOUT),
/* harmony export */   "LAYOUT_AUTO": () => (/* binding */ LAYOUT_AUTO),
/* harmony export */   "LAYOUT_BALLOON": () => (/* binding */ LAYOUT_BALLOON),
/* harmony export */   "LAYOUT_CIRCLE": () => (/* binding */ LAYOUT_CIRCLE),
/* harmony export */   "LAYOUT_GRID": () => (/* binding */ LAYOUT_GRID),
/* harmony export */   "LAYOUT_GROUP_BY": () => (/* binding */ LAYOUT_GROUP_BY),
/* harmony export */   "LAYOUT_HIERARCHY": () => (/* binding */ LAYOUT_HIERARCHY),
/* harmony export */   "LAYOUT_LINEAR": () => (/* binding */ LAYOUT_LINEAR),
/* harmony export */   "LAYOUT_SKEW_GRID": () => (/* binding */ LAYOUT_SKEW_GRID),
/* harmony export */   "LAYOUT_SORTED_CLUSTERS": () => (/* binding */ LAYOUT_SORTED_CLUSTERS),
/* harmony export */   "LEARNING": () => (/* binding */ LEARNING),
/* harmony export */   "LEFT_JOIN": () => (/* binding */ LEFT_JOIN),
/* harmony export */   "LESS_THAN": () => (/* binding */ LESS_THAN),
/* harmony export */   "LESS_THAN_OR_EQUAL_TO": () => (/* binding */ LESS_THAN_OR_EQUAL_TO),
/* harmony export */   "LIFESAVER": () => (/* binding */ LIFESAVER),
/* harmony export */   "LIGHTBULB": () => (/* binding */ LIGHTBULB),
/* harmony export */   "LIGHTNING": () => (/* binding */ LIGHTNING),
/* harmony export */   "LINK": () => (/* binding */ LINK),
/* harmony export */   "LIST": () => (/* binding */ LIST),
/* harmony export */   "LIST_COLUMNS": () => (/* binding */ LIST_COLUMNS),
/* harmony export */   "LIST_DETAIL_VIEW": () => (/* binding */ LIST_DETAIL_VIEW),
/* harmony export */   "LOCATE": () => (/* binding */ LOCATE),
/* harmony export */   "LOCK": () => (/* binding */ LOCK),
/* harmony export */   "LOG_IN": () => (/* binding */ LOG_IN),
/* harmony export */   "LOG_OUT": () => (/* binding */ LOG_OUT),
/* harmony export */   "MANUAL": () => (/* binding */ MANUAL),
/* harmony export */   "MANUALLY_ENTERED_DATA": () => (/* binding */ MANUALLY_ENTERED_DATA),
/* harmony export */   "MANY_TO_MANY": () => (/* binding */ MANY_TO_MANY),
/* harmony export */   "MANY_TO_ONE": () => (/* binding */ MANY_TO_ONE),
/* harmony export */   "MAP": () => (/* binding */ MAP),
/* harmony export */   "MAP_CREATE": () => (/* binding */ MAP_CREATE),
/* harmony export */   "MAP_MARKER": () => (/* binding */ MAP_MARKER),
/* harmony export */   "MAXIMIZE": () => (/* binding */ MAXIMIZE),
/* harmony export */   "MEDIA": () => (/* binding */ MEDIA),
/* harmony export */   "MENU": () => (/* binding */ MENU),
/* harmony export */   "MENU_CLOSED": () => (/* binding */ MENU_CLOSED),
/* harmony export */   "MENU_OPEN": () => (/* binding */ MENU_OPEN),
/* harmony export */   "MERGE_COLUMNS": () => (/* binding */ MERGE_COLUMNS),
/* harmony export */   "MERGE_LINKS": () => (/* binding */ MERGE_LINKS),
/* harmony export */   "MINIMIZE": () => (/* binding */ MINIMIZE),
/* harmony export */   "MINUS": () => (/* binding */ MINUS),
/* harmony export */   "MOBILE_PHONE": () => (/* binding */ MOBILE_PHONE),
/* harmony export */   "MOBILE_VIDEO": () => (/* binding */ MOBILE_VIDEO),
/* harmony export */   "MODAL": () => (/* binding */ MODAL),
/* harmony export */   "MODAL_FILLED": () => (/* binding */ MODAL_FILLED),
/* harmony export */   "MOON": () => (/* binding */ MOON),
/* harmony export */   "MORE": () => (/* binding */ MORE),
/* harmony export */   "MOUNTAIN": () => (/* binding */ MOUNTAIN),
/* harmony export */   "MOVE": () => (/* binding */ MOVE),
/* harmony export */   "MUGSHOT": () => (/* binding */ MUGSHOT),
/* harmony export */   "MULTI_SELECT": () => (/* binding */ MULTI_SELECT),
/* harmony export */   "MUSIC": () => (/* binding */ MUSIC),
/* harmony export */   "NEST": () => (/* binding */ NEST),
/* harmony export */   "NEW_DRAWING": () => (/* binding */ NEW_DRAWING),
/* harmony export */   "NEW_GRID_ITEM": () => (/* binding */ NEW_GRID_ITEM),
/* harmony export */   "NEW_LAYER": () => (/* binding */ NEW_LAYER),
/* harmony export */   "NEW_LAYERS": () => (/* binding */ NEW_LAYERS),
/* harmony export */   "NEW_LINK": () => (/* binding */ NEW_LINK),
/* harmony export */   "NEW_OBJECT": () => (/* binding */ NEW_OBJECT),
/* harmony export */   "NEW_PERSON": () => (/* binding */ NEW_PERSON),
/* harmony export */   "NEW_PRESCRIPTION": () => (/* binding */ NEW_PRESCRIPTION),
/* harmony export */   "NEW_TEXT_BOX": () => (/* binding */ NEW_TEXT_BOX),
/* harmony export */   "NINJA": () => (/* binding */ NINJA),
/* harmony export */   "NOTIFICATIONS": () => (/* binding */ NOTIFICATIONS),
/* harmony export */   "NOTIFICATIONS_SNOOZE": () => (/* binding */ NOTIFICATIONS_SNOOZE),
/* harmony export */   "NOTIFICATIONS_UPDATED": () => (/* binding */ NOTIFICATIONS_UPDATED),
/* harmony export */   "NOT_EQUAL_TO": () => (/* binding */ NOT_EQUAL_TO),
/* harmony export */   "NUMBERED_LIST": () => (/* binding */ NUMBERED_LIST),
/* harmony export */   "NUMERICAL": () => (/* binding */ NUMERICAL),
/* harmony export */   "OFFICE": () => (/* binding */ OFFICE),
/* harmony export */   "OFFLINE": () => (/* binding */ OFFLINE),
/* harmony export */   "OIL_FIELD": () => (/* binding */ OIL_FIELD),
/* harmony export */   "ONE_COLUMN": () => (/* binding */ ONE_COLUMN),
/* harmony export */   "ONE_TO_MANY": () => (/* binding */ ONE_TO_MANY),
/* harmony export */   "ONE_TO_ONE": () => (/* binding */ ONE_TO_ONE),
/* harmony export */   "OUTDATED": () => (/* binding */ OUTDATED),
/* harmony export */   "PAGE_LAYOUT": () => (/* binding */ PAGE_LAYOUT),
/* harmony export */   "PANEL_STATS": () => (/* binding */ PANEL_STATS),
/* harmony export */   "PANEL_TABLE": () => (/* binding */ PANEL_TABLE),
/* harmony export */   "PAPERCLIP": () => (/* binding */ PAPERCLIP),
/* harmony export */   "PARAGRAPH": () => (/* binding */ PARAGRAPH),
/* harmony export */   "PATH": () => (/* binding */ PATH),
/* harmony export */   "PATH_SEARCH": () => (/* binding */ PATH_SEARCH),
/* harmony export */   "PAUSE": () => (/* binding */ PAUSE),
/* harmony export */   "PEOPLE": () => (/* binding */ PEOPLE),
/* harmony export */   "PERCENTAGE": () => (/* binding */ PERCENTAGE),
/* harmony export */   "PERSON": () => (/* binding */ PERSON),
/* harmony export */   "PHONE": () => (/* binding */ PHONE),
/* harmony export */   "PIE_CHART": () => (/* binding */ PIE_CHART),
/* harmony export */   "PIN": () => (/* binding */ PIN),
/* harmony export */   "PIVOT": () => (/* binding */ PIVOT),
/* harmony export */   "PIVOT_TABLE": () => (/* binding */ PIVOT_TABLE),
/* harmony export */   "PLAY": () => (/* binding */ PLAY),
/* harmony export */   "PLUS": () => (/* binding */ PLUS),
/* harmony export */   "POLYGON_FILTER": () => (/* binding */ POLYGON_FILTER),
/* harmony export */   "POWER": () => (/* binding */ POWER),
/* harmony export */   "PREDICTIVE_ANALYSIS": () => (/* binding */ PREDICTIVE_ANALYSIS),
/* harmony export */   "PRESCRIPTION": () => (/* binding */ PRESCRIPTION),
/* harmony export */   "PRESENTATION": () => (/* binding */ PRESENTATION),
/* harmony export */   "PRINT": () => (/* binding */ PRINT),
/* harmony export */   "PROJECTS": () => (/* binding */ PROJECTS),
/* harmony export */   "PROPERTIES": () => (/* binding */ PROPERTIES),
/* harmony export */   "PROPERTY": () => (/* binding */ PROPERTY),
/* harmony export */   "PUBLISH_FUNCTION": () => (/* binding */ PUBLISH_FUNCTION),
/* harmony export */   "PULSE": () => (/* binding */ PULSE),
/* harmony export */   "RAIN": () => (/* binding */ RAIN),
/* harmony export */   "RANDOM": () => (/* binding */ RANDOM),
/* harmony export */   "RECORD": () => (/* binding */ RECORD),
/* harmony export */   "RECTANGLE": () => (/* binding */ RECTANGLE),
/* harmony export */   "REDO": () => (/* binding */ REDO),
/* harmony export */   "REFRESH": () => (/* binding */ REFRESH),
/* harmony export */   "REGRESSION_CHART": () => (/* binding */ REGRESSION_CHART),
/* harmony export */   "REMOVE": () => (/* binding */ REMOVE),
/* harmony export */   "REMOVE_COLUMN": () => (/* binding */ REMOVE_COLUMN),
/* harmony export */   "REMOVE_COLUMN_LEFT": () => (/* binding */ REMOVE_COLUMN_LEFT),
/* harmony export */   "REMOVE_COLUMN_RIGHT": () => (/* binding */ REMOVE_COLUMN_RIGHT),
/* harmony export */   "REMOVE_ROW_BOTTOM": () => (/* binding */ REMOVE_ROW_BOTTOM),
/* harmony export */   "REMOVE_ROW_TOP": () => (/* binding */ REMOVE_ROW_TOP),
/* harmony export */   "REPEAT": () => (/* binding */ REPEAT),
/* harmony export */   "RESET": () => (/* binding */ RESET),
/* harmony export */   "RESOLVE": () => (/* binding */ RESOLVE),
/* harmony export */   "RIG": () => (/* binding */ RIG),
/* harmony export */   "RIGHT_JOIN": () => (/* binding */ RIGHT_JOIN),
/* harmony export */   "RING": () => (/* binding */ RING),
/* harmony export */   "ROCKET": () => (/* binding */ ROCKET),
/* harmony export */   "ROCKET_SLANT": () => (/* binding */ ROCKET_SLANT),
/* harmony export */   "ROTATE_DOCUMENT": () => (/* binding */ ROTATE_DOCUMENT),
/* harmony export */   "ROTATE_PAGE": () => (/* binding */ ROTATE_PAGE),
/* harmony export */   "ROUTE": () => (/* binding */ ROUTE),
/* harmony export */   "SATELLITE": () => (/* binding */ SATELLITE),
/* harmony export */   "SAVED": () => (/* binding */ SAVED),
/* harmony export */   "SCATTER_PLOT": () => (/* binding */ SCATTER_PLOT),
/* harmony export */   "SEARCH": () => (/* binding */ SEARCH),
/* harmony export */   "SEARCH_AROUND": () => (/* binding */ SEARCH_AROUND),
/* harmony export */   "SEARCH_TEMPLATE": () => (/* binding */ SEARCH_TEMPLATE),
/* harmony export */   "SEARCH_TEXT": () => (/* binding */ SEARCH_TEXT),
/* harmony export */   "SEGMENTED_CONTROL": () => (/* binding */ SEGMENTED_CONTROL),
/* harmony export */   "SELECT": () => (/* binding */ SELECT),
/* harmony export */   "SELECTION": () => (/* binding */ SELECTION),
/* harmony export */   "SEND_MESSAGE": () => (/* binding */ SEND_MESSAGE),
/* harmony export */   "SEND_TO": () => (/* binding */ SEND_TO),
/* harmony export */   "SEND_TO_GRAPH": () => (/* binding */ SEND_TO_GRAPH),
/* harmony export */   "SEND_TO_MAP": () => (/* binding */ SEND_TO_MAP),
/* harmony export */   "SERIES_ADD": () => (/* binding */ SERIES_ADD),
/* harmony export */   "SERIES_CONFIGURATION": () => (/* binding */ SERIES_CONFIGURATION),
/* harmony export */   "SERIES_DERIVED": () => (/* binding */ SERIES_DERIVED),
/* harmony export */   "SERIES_FILTERED": () => (/* binding */ SERIES_FILTERED),
/* harmony export */   "SERIES_SEARCH": () => (/* binding */ SERIES_SEARCH),
/* harmony export */   "SETTINGS": () => (/* binding */ SETTINGS),
/* harmony export */   "SHAPES": () => (/* binding */ SHAPES),
/* harmony export */   "SHARE": () => (/* binding */ SHARE),
/* harmony export */   "SHARED_FILTER": () => (/* binding */ SHARED_FILTER),
/* harmony export */   "SHIELD": () => (/* binding */ SHIELD),
/* harmony export */   "SHIP": () => (/* binding */ SHIP),
/* harmony export */   "SHOP": () => (/* binding */ SHOP),
/* harmony export */   "SHOPPING_CART": () => (/* binding */ SHOPPING_CART),
/* harmony export */   "SIGNAL_SEARCH": () => (/* binding */ SIGNAL_SEARCH),
/* harmony export */   "SIM_CARD": () => (/* binding */ SIM_CARD),
/* harmony export */   "SLASH": () => (/* binding */ SLASH),
/* harmony export */   "SMALL_CROSS": () => (/* binding */ SMALL_CROSS),
/* harmony export */   "SMALL_MINUS": () => (/* binding */ SMALL_MINUS),
/* harmony export */   "SMALL_PLUS": () => (/* binding */ SMALL_PLUS),
/* harmony export */   "SMALL_SQUARE": () => (/* binding */ SMALL_SQUARE),
/* harmony export */   "SMALL_TICK": () => (/* binding */ SMALL_TICK),
/* harmony export */   "SNOWFLAKE": () => (/* binding */ SNOWFLAKE),
/* harmony export */   "SOCIAL_MEDIA": () => (/* binding */ SOCIAL_MEDIA),
/* harmony export */   "SORT": () => (/* binding */ SORT),
/* harmony export */   "SORT_ALPHABETICAL": () => (/* binding */ SORT_ALPHABETICAL),
/* harmony export */   "SORT_ALPHABETICAL_DESC": () => (/* binding */ SORT_ALPHABETICAL_DESC),
/* harmony export */   "SORT_ASC": () => (/* binding */ SORT_ASC),
/* harmony export */   "SORT_DESC": () => (/* binding */ SORT_DESC),
/* harmony export */   "SORT_NUMERICAL": () => (/* binding */ SORT_NUMERICAL),
/* harmony export */   "SORT_NUMERICAL_DESC": () => (/* binding */ SORT_NUMERICAL_DESC),
/* harmony export */   "SPLIT_COLUMNS": () => (/* binding */ SPLIT_COLUMNS),
/* harmony export */   "SQUARE": () => (/* binding */ SQUARE),
/* harmony export */   "STACKED_CHART": () => (/* binding */ STACKED_CHART),
/* harmony export */   "STADIUM_GEOMETRY": () => (/* binding */ STADIUM_GEOMETRY),
/* harmony export */   "STAR": () => (/* binding */ STAR),
/* harmony export */   "STAR_EMPTY": () => (/* binding */ STAR_EMPTY),
/* harmony export */   "STEP_BACKWARD": () => (/* binding */ STEP_BACKWARD),
/* harmony export */   "STEP_CHART": () => (/* binding */ STEP_CHART),
/* harmony export */   "STEP_FORWARD": () => (/* binding */ STEP_FORWARD),
/* harmony export */   "STOP": () => (/* binding */ STOP),
/* harmony export */   "STOPWATCH": () => (/* binding */ STOPWATCH),
/* harmony export */   "STRIKETHROUGH": () => (/* binding */ STRIKETHROUGH),
/* harmony export */   "STYLE": () => (/* binding */ STYLE),
/* harmony export */   "SWAP_HORIZONTAL": () => (/* binding */ SWAP_HORIZONTAL),
/* harmony export */   "SWAP_VERTICAL": () => (/* binding */ SWAP_VERTICAL),
/* harmony export */   "SWITCH": () => (/* binding */ SWITCH),
/* harmony export */   "SYMBOL_CIRCLE": () => (/* binding */ SYMBOL_CIRCLE),
/* harmony export */   "SYMBOL_CROSS": () => (/* binding */ SYMBOL_CROSS),
/* harmony export */   "SYMBOL_DIAMOND": () => (/* binding */ SYMBOL_DIAMOND),
/* harmony export */   "SYMBOL_RECTANGLE": () => (/* binding */ SYMBOL_RECTANGLE),
/* harmony export */   "SYMBOL_SQUARE": () => (/* binding */ SYMBOL_SQUARE),
/* harmony export */   "SYMBOL_TRIANGLE_DOWN": () => (/* binding */ SYMBOL_TRIANGLE_DOWN),
/* harmony export */   "SYMBOL_TRIANGLE_UP": () => (/* binding */ SYMBOL_TRIANGLE_UP),
/* harmony export */   "SYRINGE": () => (/* binding */ SYRINGE),
/* harmony export */   "TAG": () => (/* binding */ TAG),
/* harmony export */   "TAKE_ACTION": () => (/* binding */ TAKE_ACTION),
/* harmony export */   "TANK": () => (/* binding */ TANK),
/* harmony export */   "TARGET": () => (/* binding */ TARGET),
/* harmony export */   "TAXI": () => (/* binding */ TAXI),
/* harmony export */   "TEMPERATURE": () => (/* binding */ TEMPERATURE),
/* harmony export */   "TEXT_HIGHLIGHT": () => (/* binding */ TEXT_HIGHLIGHT),
/* harmony export */   "TH": () => (/* binding */ TH),
/* harmony export */   "THIRD_PARTY": () => (/* binding */ THIRD_PARTY),
/* harmony export */   "THUMBS_DOWN": () => (/* binding */ THUMBS_DOWN),
/* harmony export */   "THUMBS_UP": () => (/* binding */ THUMBS_UP),
/* harmony export */   "TH_DERIVED": () => (/* binding */ TH_DERIVED),
/* harmony export */   "TH_DISCONNECT": () => (/* binding */ TH_DISCONNECT),
/* harmony export */   "TH_FILTERED": () => (/* binding */ TH_FILTERED),
/* harmony export */   "TH_LIST": () => (/* binding */ TH_LIST),
/* harmony export */   "TICK": () => (/* binding */ TICK),
/* harmony export */   "TICK_CIRCLE": () => (/* binding */ TICK_CIRCLE),
/* harmony export */   "TIME": () => (/* binding */ TIME),
/* harmony export */   "TIMELINE_AREA_CHART": () => (/* binding */ TIMELINE_AREA_CHART),
/* harmony export */   "TIMELINE_BAR_CHART": () => (/* binding */ TIMELINE_BAR_CHART),
/* harmony export */   "TIMELINE_EVENTS": () => (/* binding */ TIMELINE_EVENTS),
/* harmony export */   "TIMELINE_LINE_CHART": () => (/* binding */ TIMELINE_LINE_CHART),
/* harmony export */   "TINT": () => (/* binding */ TINT),
/* harmony export */   "TORCH": () => (/* binding */ TORCH),
/* harmony export */   "TRACTOR": () => (/* binding */ TRACTOR),
/* harmony export */   "TRAIN": () => (/* binding */ TRAIN),
/* harmony export */   "TRANSLATE": () => (/* binding */ TRANSLATE),
/* harmony export */   "TRASH": () => (/* binding */ TRASH),
/* harmony export */   "TREE": () => (/* binding */ TREE),
/* harmony export */   "TRENDING_DOWN": () => (/* binding */ TRENDING_DOWN),
/* harmony export */   "TRENDING_UP": () => (/* binding */ TRENDING_UP),
/* harmony export */   "TRUCK": () => (/* binding */ TRUCK),
/* harmony export */   "TWO_COLUMNS": () => (/* binding */ TWO_COLUMNS),
/* harmony export */   "UNARCHIVE": () => (/* binding */ UNARCHIVE),
/* harmony export */   "UNDERLINE": () => (/* binding */ UNDERLINE),
/* harmony export */   "UNDO": () => (/* binding */ UNDO),
/* harmony export */   "UNGROUP_OBJECTS": () => (/* binding */ UNGROUP_OBJECTS),
/* harmony export */   "UNKNOWN_VEHICLE": () => (/* binding */ UNKNOWN_VEHICLE),
/* harmony export */   "UNLOCK": () => (/* binding */ UNLOCK),
/* harmony export */   "UNPIN": () => (/* binding */ UNPIN),
/* harmony export */   "UNRESOLVE": () => (/* binding */ UNRESOLVE),
/* harmony export */   "UPDATED": () => (/* binding */ UPDATED),
/* harmony export */   "UPLOAD": () => (/* binding */ UPLOAD),
/* harmony export */   "USER": () => (/* binding */ USER),
/* harmony export */   "VARIABLE": () => (/* binding */ VARIABLE),
/* harmony export */   "VERTICAL_BAR_CHART_ASC": () => (/* binding */ VERTICAL_BAR_CHART_ASC),
/* harmony export */   "VERTICAL_BAR_CHART_DESC": () => (/* binding */ VERTICAL_BAR_CHART_DESC),
/* harmony export */   "VERTICAL_DISTRIBUTION": () => (/* binding */ VERTICAL_DISTRIBUTION),
/* harmony export */   "VIDEO": () => (/* binding */ VIDEO),
/* harmony export */   "VIRUS": () => (/* binding */ VIRUS),
/* harmony export */   "VOLUME_DOWN": () => (/* binding */ VOLUME_DOWN),
/* harmony export */   "VOLUME_OFF": () => (/* binding */ VOLUME_OFF),
/* harmony export */   "VOLUME_UP": () => (/* binding */ VOLUME_UP),
/* harmony export */   "WALK": () => (/* binding */ WALK),
/* harmony export */   "WARNING_SIGN": () => (/* binding */ WARNING_SIGN),
/* harmony export */   "WATERFALL_CHART": () => (/* binding */ WATERFALL_CHART),
/* harmony export */   "WAVES": () => (/* binding */ WAVES),
/* harmony export */   "WIDGET": () => (/* binding */ WIDGET),
/* harmony export */   "WIDGET_BUTTON": () => (/* binding */ WIDGET_BUTTON),
/* harmony export */   "WIDGET_FOOTER": () => (/* binding */ WIDGET_FOOTER),
/* harmony export */   "WIDGET_HEADER": () => (/* binding */ WIDGET_HEADER),
/* harmony export */   "WIND": () => (/* binding */ WIND),
/* harmony export */   "WRENCH": () => (/* binding */ WRENCH),
/* harmony export */   "ZOOM_IN": () => (/* binding */ ZOOM_IN),
/* harmony export */   "ZOOM_OUT": () => (/* binding */ ZOOM_OUT),
/* harmony export */   "ZOOM_TO_FIT": () => (/* binding */ ZOOM_TO_FIT)
/* harmony export */ });
/*
 * Copyright 2021 Palantir Technologies, Inc. All rights reserved.
 */
var ADD = "add";
var ADD_CLIP = "add-clip";
var ADD_COLUMN_LEFT = "add-column-left";
var ADD_COLUMN_RIGHT = "add-column-right";
var ADD_LOCATION = "add-location";
var ADD_ROW_BOTTOM = "add-row-bottom";
var ADD_ROW_TOP = "add-row-top";
var ADD_TO_ARTIFACT = "add-to-artifact";
var ADD_TO_FOLDER = "add-to-folder";
var AIRPLANE = "airplane";
var ALIGN_CENTER = "align-center";
var ALIGN_JUSTIFY = "align-justify";
var ALIGN_LEFT = "align-left";
var ALIGN_RIGHT = "align-right";
var ALIGNMENT_BOTTOM = "alignment-bottom";
var ALIGNMENT_HORIZONTAL_CENTER = "alignment-horizontal-center";
var ALIGNMENT_LEFT = "alignment-left";
var ALIGNMENT_RIGHT = "alignment-right";
var ALIGNMENT_TOP = "alignment-top";
var ALIGNMENT_VERTICAL_CENTER = "alignment-vertical-center";
var ANNOTATION = "annotation";
var ANTENNA = "antenna";
var APP_HEADER = "app-header";
var APPLICATION = "application";
var APPLICATIONS = "applications";
var ARCHIVE = "archive";
var AREA_OF_INTEREST = "area-of-interest";
var ARRAY = "array";
var ARRAY_BOOLEAN = "array-boolean";
var ARRAY_DATE = "array-date";
var ARRAY_NUMERIC = "array-numeric";
var ARRAY_STRING = "array-string";
var ARRAY_TIMESTAMP = "array-timestamp";
var ARROW_BOTTOM_LEFT = "arrow-bottom-left";
var ARROW_BOTTOM_RIGHT = "arrow-bottom-right";
var ARROW_DOWN = "arrow-down";
var ARROW_LEFT = "arrow-left";
var ARROW_RIGHT = "arrow-right";
var ARROW_TOP_LEFT = "arrow-top-left";
var ARROW_TOP_RIGHT = "arrow-top-right";
var ARROW_UP = "arrow-up";
var ARROWS_HORIZONTAL = "arrows-horizontal";
var ARROWS_VERTICAL = "arrows-vertical";
var ASTERISK = "asterisk";
var AUTOMATIC_UPDATES = "automatic-updates";
var BACKLINK = "backlink";
var BADGE = "badge";
var BAN_CIRCLE = "ban-circle";
var BANK_ACCOUNT = "bank-account";
var BARCODE = "barcode";
var BLANK = "blank";
var BLOCKED_PERSON = "blocked-person";
var BOLD = "bold";
var BOOK = "book";
var BOOKMARK = "bookmark";
var BOX = "box";
var BRIEFCASE = "briefcase";
var BRING_DATA = "bring-data";
var BUGGY = "buggy";
var BUILD = "build";
var CALCULATOR = "calculator";
var CALENDAR = "calendar";
var CAMERA = "camera";
var CARET_DOWN = "caret-down";
var CARET_LEFT = "caret-left";
var CARET_RIGHT = "caret-right";
var CARET_UP = "caret-up";
var CARGO_SHIP = "cargo-ship";
var CELL_TOWER = "cell-tower";
var CHANGES = "changes";
var CHART = "chart";
var CHAT = "chat";
var CHEVRON_BACKWARD = "chevron-backward";
var CHEVRON_DOWN = "chevron-down";
var CHEVRON_FORWARD = "chevron-forward";
var CHEVRON_LEFT = "chevron-left";
var CHEVRON_RIGHT = "chevron-right";
var CHEVRON_UP = "chevron-up";
var CIRCLE = "circle";
var CIRCLE_ARROW_DOWN = "circle-arrow-down";
var CIRCLE_ARROW_LEFT = "circle-arrow-left";
var CIRCLE_ARROW_RIGHT = "circle-arrow-right";
var CIRCLE_ARROW_UP = "circle-arrow-up";
var CITATION = "citation";
var CLEAN = "clean";
var CLIP = "clip";
var CLIPBOARD = "clipboard";
var CLOUD = "cloud";
var CLOUD_DOWNLOAD = "cloud-download";
var CLOUD_UPLOAD = "cloud-upload";
var CODE = "code";
var CODE_BLOCK = "code-block";
var COG = "cog";
var COLLAPSE_ALL = "collapse-all";
var COLUMN_LAYOUT = "column-layout";
var COMMENT = "comment";
var COMPARISON = "comparison";
var COMPASS = "compass";
var COMPRESSED = "compressed";
var CONFIRM = "confirm";
var CONSOLE = "console";
var CONTRAST = "contrast";
var CONTROL = "control";
var CREDIT_CARD = "credit-card";
var CROSS = "cross";
var CROWN = "crown";
var CUBE = "cube";
var CUBE_ADD = "cube-add";
var CUBE_REMOVE = "cube-remove";
var CURVED_RANGE_CHART = "curved-range-chart";
var CUT = "cut";
var CYCLE = "cycle";
var DASHBOARD = "dashboard";
var DATA_CONNECTION = "data-connection";
var DATA_LINEAGE = "data-lineage";
var DATABASE = "database";
var DELETE = "delete";
var DELTA = "delta";
var DERIVE_COLUMN = "derive-column";
var DESKTOP = "desktop";
var DIAGNOSIS = "diagnosis";
var DIAGRAM_TREE = "diagram-tree";
var DIRECTION_LEFT = "direction-left";
var DIRECTION_RIGHT = "direction-right";
var DISABLE = "disable";
var DOCUMENT = "document";
var DOCUMENT_OPEN = "document-open";
var DOCUMENT_SHARE = "document-share";
var DOLLAR = "dollar";
var DOT = "dot";
var DOUBLE_CARET_HORIZONTAL = "double-caret-horizontal";
var DOUBLE_CARET_VERTICAL = "double-caret-vertical";
var DOUBLE_CHEVRON_DOWN = "double-chevron-down";
var DOUBLE_CHEVRON_LEFT = "double-chevron-left";
var DOUBLE_CHEVRON_RIGHT = "double-chevron-right";
var DOUBLE_CHEVRON_UP = "double-chevron-up";
var DOUGHNUT_CHART = "doughnut-chart";
var DOWNLOAD = "download";
var DRAG_HANDLE_HORIZONTAL = "drag-handle-horizontal";
var DRAG_HANDLE_VERTICAL = "drag-handle-vertical";
var DRAW = "draw";
var DRAWER_LEFT = "drawer-left";
var DRAWER_LEFT_FILLED = "drawer-left-filled";
var DRAWER_RIGHT = "drawer-right";
var DRAWER_RIGHT_FILLED = "drawer-right-filled";
var DRIVE_TIME = "drive-time";
var DUPLICATE = "duplicate";
var EDIT = "edit";
var EJECT = "eject";
var EMOJI = "emoji";
var ENDORSED = "endorsed";
var ENVELOPE = "envelope";
var EQUALS = "equals";
var ERASER = "eraser";
var ERROR = "error";
var EURO = "euro";
var EXCHANGE = "exchange";
var EXCLUDE_ROW = "exclude-row";
var EXPAND_ALL = "expand-all";
var EXPORT = "export";
var EYE_OFF = "eye-off";
var EYE_ON = "eye-on";
var EYE_OPEN = "eye-open";
var FAST_BACKWARD = "fast-backward";
var FAST_FORWARD = "fast-forward";
var FEED = "feed";
var FEED_SUBSCRIBED = "feed-subscribed";
var FILM = "film";
var FILTER = "filter";
var FILTER_KEEP = "filter-keep";
var FILTER_LIST = "filter-list";
var FILTER_OPEN = "filter-open";
var FILTER_REMOVE = "filter-remove";
var FLAG = "flag";
var FLAME = "flame";
var FLASH = "flash";
var FLOPPY_DISK = "floppy-disk";
var FLOW_BRANCH = "flow-branch";
var FLOW_END = "flow-end";
var FLOW_LINEAR = "flow-linear";
var FLOW_REVIEW = "flow-review";
var FLOW_REVIEW_BRANCH = "flow-review-branch";
var FLOWS = "flows";
var FOLDER_CLOSE = "folder-close";
var FOLDER_NEW = "folder-new";
var FOLDER_OPEN = "folder-open";
var FOLDER_SHARED = "folder-shared";
var FOLDER_SHARED_OPEN = "folder-shared-open";
var FOLLOWER = "follower";
var FOLLOWING = "following";
var FONT = "font";
var FORK = "fork";
var FORM = "form";
var FULL_CIRCLE = "full-circle";
var FULL_STACKED_CHART = "full-stacked-chart";
var FULLSCREEN = "fullscreen";
var FUNCTION = "function";
var GANTT_CHART = "gantt-chart";
var GEOFENCE = "geofence";
var GEOLOCATION = "geolocation";
var GEOSEARCH = "geosearch";
var GIT_BRANCH = "git-branch";
var GIT_COMMIT = "git-commit";
var GIT_MERGE = "git-merge";
var GIT_NEW_BRANCH = "git-new-branch";
var GIT_PULL = "git-pull";
var GIT_PUSH = "git-push";
var GIT_REPO = "git-repo";
var GLASS = "glass";
var GLOBE = "globe";
var GLOBE_NETWORK = "globe-network";
var GRAPH = "graph";
var GRAPH_REMOVE = "graph-remove";
var GREATER_THAN = "greater-than";
var GREATER_THAN_OR_EQUAL_TO = "greater-than-or-equal-to";
var GRID = "grid";
var GRID_VIEW = "grid-view";
var GROUP_OBJECTS = "group-objects";
var GROUPED_BAR_CHART = "grouped-bar-chart";
var HAND = "hand";
var HAND_DOWN = "hand-down";
var HAND_LEFT = "hand-left";
var HAND_RIGHT = "hand-right";
var HAND_UP = "hand-up";
var HAT = "hat";
var HEADER = "header";
var HEADER_ONE = "header-one";
var HEADER_THREE = "header-three";
var HEADER_TWO = "header-two";
var HEADSET = "headset";
var HEART = "heart";
var HEART_BROKEN = "heart-broken";
var HEAT_GRID = "heat-grid";
var HEATMAP = "heatmap";
var HELICOPTER = "helicopter";
var HELP = "help";
var HELPER_MANAGEMENT = "helper-management";
var HIGH_PRIORITY = "high-priority";
var HIGHLIGHT = "highlight";
var HISTORY = "history";
var HOME = "home";
var HORIZONTAL_BAR_CHART = "horizontal-bar-chart";
var HORIZONTAL_BAR_CHART_ASC = "horizontal-bar-chart-asc";
var HORIZONTAL_BAR_CHART_DESC = "horizontal-bar-chart-desc";
var HORIZONTAL_DISTRIBUTION = "horizontal-distribution";
var HURRICANE = "hurricane";
var ID_NUMBER = "id-number";
var IMAGE_ROTATE_LEFT = "image-rotate-left";
var IMAGE_ROTATE_RIGHT = "image-rotate-right";
var IMPORT = "import";
var INBOX = "inbox";
var INBOX_FILTERED = "inbox-filtered";
var INBOX_GEO = "inbox-geo";
var INBOX_SEARCH = "inbox-search";
var INBOX_UPDATE = "inbox-update";
var INFO_SIGN = "info-sign";
var INHERITANCE = "inheritance";
var INHERITED_GROUP = "inherited-group";
var INNER_JOIN = "inner-join";
var INSERT = "insert";
var INTERSECTION = "intersection";
var IP_ADDRESS = "ip-address";
var ISSUE = "issue";
var ISSUE_CLOSED = "issue-closed";
var ISSUE_NEW = "issue-new";
var ITALIC = "italic";
var JOIN_TABLE = "join-table";
var KEY = "key";
var KEY_BACKSPACE = "key-backspace";
var KEY_COMMAND = "key-command";
var KEY_CONTROL = "key-control";
var KEY_DELETE = "key-delete";
var KEY_ENTER = "key-enter";
var KEY_ESCAPE = "key-escape";
var KEY_OPTION = "key-option";
var KEY_SHIFT = "key-shift";
var KEY_TAB = "key-tab";
var KNOWN_VEHICLE = "known-vehicle";
var LAB_TEST = "lab-test";
var LABEL = "label";
var LAYER = "layer";
var LAYER_OUTLINE = "layer-outline";
var LAYERS = "layers";
var LAYOUT = "layout";
var LAYOUT_AUTO = "layout-auto";
var LAYOUT_BALLOON = "layout-balloon";
var LAYOUT_CIRCLE = "layout-circle";
var LAYOUT_GRID = "layout-grid";
var LAYOUT_GROUP_BY = "layout-group-by";
var LAYOUT_HIERARCHY = "layout-hierarchy";
var LAYOUT_LINEAR = "layout-linear";
var LAYOUT_SKEW_GRID = "layout-skew-grid";
var LAYOUT_SORTED_CLUSTERS = "layout-sorted-clusters";
var LEARNING = "learning";
var LEFT_JOIN = "left-join";
var LESS_THAN = "less-than";
var LESS_THAN_OR_EQUAL_TO = "less-than-or-equal-to";
var LIFESAVER = "lifesaver";
var LIGHTBULB = "lightbulb";
var LIGHTNING = "lightning";
var LINK = "link";
var LIST = "list";
var LIST_COLUMNS = "list-columns";
var LIST_DETAIL_VIEW = "list-detail-view";
var LOCATE = "locate";
var LOCK = "lock";
var LOG_IN = "log-in";
var LOG_OUT = "log-out";
var MANUAL = "manual";
var MANUALLY_ENTERED_DATA = "manually-entered-data";
var MANY_TO_MANY = "many-to-many";
var MANY_TO_ONE = "many-to-one";
var MAP = "map";
var MAP_CREATE = "map-create";
var MAP_MARKER = "map-marker";
var MAXIMIZE = "maximize";
var MEDIA = "media";
var MENU = "menu";
var MENU_CLOSED = "menu-closed";
var MENU_OPEN = "menu-open";
var MERGE_COLUMNS = "merge-columns";
var MERGE_LINKS = "merge-links";
var MINIMIZE = "minimize";
var MINUS = "minus";
var MOBILE_PHONE = "mobile-phone";
var MOBILE_VIDEO = "mobile-video";
var MODAL = "modal";
var MODAL_FILLED = "modal-filled";
var MOON = "moon";
var MORE = "more";
var MOUNTAIN = "mountain";
var MOVE = "move";
var MUGSHOT = "mugshot";
var MULTI_SELECT = "multi-select";
var MUSIC = "music";
var NEST = "nest";
var NEW_DRAWING = "new-drawing";
var NEW_GRID_ITEM = "new-grid-item";
var NEW_LAYER = "new-layer";
var NEW_LAYERS = "new-layers";
var NEW_LINK = "new-link";
var NEW_OBJECT = "new-object";
var NEW_PERSON = "new-person";
var NEW_PRESCRIPTION = "new-prescription";
var NEW_TEXT_BOX = "new-text-box";
var NINJA = "ninja";
var NOT_EQUAL_TO = "not-equal-to";
var NOTIFICATIONS = "notifications";
var NOTIFICATIONS_SNOOZE = "notifications-snooze";
var NOTIFICATIONS_UPDATED = "notifications-updated";
var NUMBERED_LIST = "numbered-list";
var NUMERICAL = "numerical";
var OFFICE = "office";
var OFFLINE = "offline";
var OIL_FIELD = "oil-field";
var ONE_COLUMN = "one-column";
var ONE_TO_MANY = "one-to-many";
var ONE_TO_ONE = "one-to-one";
var OUTDATED = "outdated";
var PAGE_LAYOUT = "page-layout";
var PANEL_STATS = "panel-stats";
var PANEL_TABLE = "panel-table";
var PAPERCLIP = "paperclip";
var PARAGRAPH = "paragraph";
var PATH = "path";
var PATH_SEARCH = "path-search";
var PAUSE = "pause";
var PEOPLE = "people";
var PERCENTAGE = "percentage";
var PERSON = "person";
var PHONE = "phone";
var PIE_CHART = "pie-chart";
var PIN = "pin";
var PIVOT = "pivot";
var PIVOT_TABLE = "pivot-table";
var PLAY = "play";
var PLUS = "plus";
var POLYGON_FILTER = "polygon-filter";
var POWER = "power";
var PREDICTIVE_ANALYSIS = "predictive-analysis";
var PRESCRIPTION = "prescription";
var PRESENTATION = "presentation";
var PRINT = "print";
var PROJECTS = "projects";
var PROPERTIES = "properties";
var PROPERTY = "property";
var PUBLISH_FUNCTION = "publish-function";
var PULSE = "pulse";
var RAIN = "rain";
var RANDOM = "random";
var RECORD = "record";
var RECTANGLE = "rectangle";
var REDO = "redo";
var REFRESH = "refresh";
var REGRESSION_CHART = "regression-chart";
var REMOVE = "remove";
var REMOVE_COLUMN = "remove-column";
var REMOVE_COLUMN_LEFT = "remove-column-left";
var REMOVE_COLUMN_RIGHT = "remove-column-right";
var REMOVE_ROW_BOTTOM = "remove-row-bottom";
var REMOVE_ROW_TOP = "remove-row-top";
var REPEAT = "repeat";
var RESET = "reset";
var RESOLVE = "resolve";
var RIG = "rig";
var RIGHT_JOIN = "right-join";
var RING = "ring";
var ROCKET = "rocket";
var ROCKET_SLANT = "rocket-slant";
var ROTATE_DOCUMENT = "rotate-document";
var ROTATE_PAGE = "rotate-page";
var ROUTE = "route";
var SATELLITE = "satellite";
var SAVED = "saved";
var SCATTER_PLOT = "scatter-plot";
var SEARCH = "search";
var SEARCH_AROUND = "search-around";
var SEARCH_TEMPLATE = "search-template";
var SEARCH_TEXT = "search-text";
var SEGMENTED_CONTROL = "segmented-control";
var SELECT = "select";
var SELECTION = "selection";
var SEND_MESSAGE = "send-message";
var SEND_TO = "send-to";
var SEND_TO_GRAPH = "send-to-graph";
var SEND_TO_MAP = "send-to-map";
var SERIES_ADD = "series-add";
var SERIES_CONFIGURATION = "series-configuration";
var SERIES_DERIVED = "series-derived";
var SERIES_FILTERED = "series-filtered";
var SERIES_SEARCH = "series-search";
var SETTINGS = "settings";
var SHAPES = "shapes";
var SHARE = "share";
var SHARED_FILTER = "shared-filter";
var SHIELD = "shield";
var SHIP = "ship";
var SHOP = "shop";
var SHOPPING_CART = "shopping-cart";
var SIGNAL_SEARCH = "signal-search";
var SIM_CARD = "sim-card";
var SLASH = "slash";
var SMALL_CROSS = "small-cross";
var SMALL_MINUS = "small-minus";
var SMALL_PLUS = "small-plus";
var SMALL_SQUARE = "small-square";
var SMALL_TICK = "small-tick";
var SNOWFLAKE = "snowflake";
var SOCIAL_MEDIA = "social-media";
var SORT = "sort";
var SORT_ALPHABETICAL = "sort-alphabetical";
var SORT_ALPHABETICAL_DESC = "sort-alphabetical-desc";
var SORT_ASC = "sort-asc";
var SORT_DESC = "sort-desc";
var SORT_NUMERICAL = "sort-numerical";
var SORT_NUMERICAL_DESC = "sort-numerical-desc";
var SPLIT_COLUMNS = "split-columns";
var SQUARE = "square";
var STACKED_CHART = "stacked-chart";
var STADIUM_GEOMETRY = "stadium-geometry";
var STAR = "star";
var STAR_EMPTY = "star-empty";
var STEP_BACKWARD = "step-backward";
var STEP_CHART = "step-chart";
var STEP_FORWARD = "step-forward";
var STOP = "stop";
var STOPWATCH = "stopwatch";
var STRIKETHROUGH = "strikethrough";
var STYLE = "style";
var SWAP_HORIZONTAL = "swap-horizontal";
var SWAP_VERTICAL = "swap-vertical";
var SWITCH = "switch";
var SYMBOL_CIRCLE = "symbol-circle";
var SYMBOL_CROSS = "symbol-cross";
var SYMBOL_DIAMOND = "symbol-diamond";
var SYMBOL_RECTANGLE = "symbol-rectangle";
var SYMBOL_SQUARE = "symbol-square";
var SYMBOL_TRIANGLE_DOWN = "symbol-triangle-down";
var SYMBOL_TRIANGLE_UP = "symbol-triangle-up";
var SYRINGE = "syringe";
var TAG = "tag";
var TAKE_ACTION = "take-action";
var TANK = "tank";
var TARGET = "target";
var TAXI = "taxi";
var TEMPERATURE = "temperature";
var TEXT_HIGHLIGHT = "text-highlight";
var TH = "th";
var TH_DERIVED = "th-derived";
var TH_DISCONNECT = "th-disconnect";
var TH_FILTERED = "th-filtered";
var TH_LIST = "th-list";
var THIRD_PARTY = "third-party";
var THUMBS_DOWN = "thumbs-down";
var THUMBS_UP = "thumbs-up";
var TICK = "tick";
var TICK_CIRCLE = "tick-circle";
var TIME = "time";
var TIMELINE_AREA_CHART = "timeline-area-chart";
var TIMELINE_BAR_CHART = "timeline-bar-chart";
var TIMELINE_EVENTS = "timeline-events";
var TIMELINE_LINE_CHART = "timeline-line-chart";
var TINT = "tint";
var TORCH = "torch";
var TRACTOR = "tractor";
var TRAIN = "train";
var TRANSLATE = "translate";
var TRASH = "trash";
var TREE = "tree";
var TRENDING_DOWN = "trending-down";
var TRENDING_UP = "trending-up";
var TRUCK = "truck";
var TWO_COLUMNS = "two-columns";
var UNARCHIVE = "unarchive";
var UNDERLINE = "underline";
var UNDO = "undo";
var UNGROUP_OBJECTS = "ungroup-objects";
var UNKNOWN_VEHICLE = "unknown-vehicle";
var UNLOCK = "unlock";
var UNPIN = "unpin";
var UNRESOLVE = "unresolve";
var UPDATED = "updated";
var UPLOAD = "upload";
var USER = "user";
var VARIABLE = "variable";
var VERTICAL_BAR_CHART_ASC = "vertical-bar-chart-asc";
var VERTICAL_BAR_CHART_DESC = "vertical-bar-chart-desc";
var VERTICAL_DISTRIBUTION = "vertical-distribution";
var VIDEO = "video";
var VIRUS = "virus";
var VOLUME_DOWN = "volume-down";
var VOLUME_OFF = "volume-off";
var VOLUME_UP = "volume-up";
var WALK = "walk";
var WARNING_SIGN = "warning-sign";
var WATERFALL_CHART = "waterfall-chart";
var WAVES = "waves";
var WIDGET = "widget";
var WIDGET_BUTTON = "widget-button";
var WIDGET_FOOTER = "widget-footer";
var WIDGET_HEADER = "widget-header";
var WIND = "wind";
var WRENCH = "wrench";
var ZOOM_IN = "zoom-in";
var ZOOM_OUT = "zoom-out";
var ZOOM_TO_FIT = "zoom-to-fit";
//# sourceMappingURL=iconNames.js.map

/***/ }),

/***/ "./node_modules/@jupyterlab/filebrowser/lib/model.js":
/*!***********************************************************!*\
  !*** ./node_modules/@jupyterlab/filebrowser/lib/model.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "CHUNK_SIZE": () => (/* binding */ CHUNK_SIZE),
/* harmony export */   "FileBrowserModel": () => (/* binding */ FileBrowserModel),
/* harmony export */   "FilterFileBrowserModel": () => (/* binding */ FilterFileBrowserModel),
/* harmony export */   "LARGE_FILE_SIZE": () => (/* binding */ LARGE_FILE_SIZE),
/* harmony export */   "TogglableHiddenFileBrowserModel": () => (/* binding */ TogglableHiddenFileBrowserModel)
/* harmony export */ });
/* harmony import */ var _jupyterlab_apputils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @jupyterlab/apputils */ "webpack/sharing/consume/default/@jupyterlab/apputils");
/* harmony import */ var _jupyterlab_apputils__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_jupyterlab_apputils__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _jupyterlab_coreutils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @jupyterlab/coreutils */ "webpack/sharing/consume/default/@jupyterlab/coreutils");
/* harmony import */ var _jupyterlab_coreutils__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_jupyterlab_coreutils__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _jupyterlab_docmanager__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @jupyterlab/docmanager */ "webpack/sharing/consume/default/@jupyterlab/docmanager");
/* harmony import */ var _jupyterlab_docmanager__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_jupyterlab_docmanager__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _jupyterlab_translation__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @jupyterlab/translation */ "webpack/sharing/consume/default/@jupyterlab/translation");
/* harmony import */ var _jupyterlab_translation__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(_jupyterlab_translation__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var _lumino_algorithm__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @lumino/algorithm */ "webpack/sharing/consume/default/@lumino/algorithm");
/* harmony import */ var _lumino_algorithm__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(_lumino_algorithm__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _lumino_coreutils__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @lumino/coreutils */ "webpack/sharing/consume/default/@lumino/coreutils");
/* harmony import */ var _lumino_coreutils__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(_lumino_coreutils__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var _lumino_polling__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! @lumino/polling */ "./node_modules/@lumino/polling/dist/index.es6.js");
/* harmony import */ var _lumino_signaling__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! @lumino/signaling */ "webpack/sharing/consume/default/@lumino/signaling");
/* harmony import */ var _lumino_signaling__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(_lumino_signaling__WEBPACK_IMPORTED_MODULE_7__);
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.








/**
 * The default duration of the auto-refresh in ms
 */
const DEFAULT_REFRESH_INTERVAL = 10000;
/**
 * The maximum upload size (in bytes) for notebook version < 5.1.0
 */
const LARGE_FILE_SIZE = 15 * 1024 * 1024;
/**
 * The size (in bytes) of the biggest chunk we should upload at once.
 */
const CHUNK_SIZE = 1024 * 1024;
/**
 * An implementation of a file browser model.
 *
 * #### Notes
 * All paths parameters without a leading `'/'` are interpreted as relative to
 * the current directory.  Supports `'../'` syntax.
 */
class FileBrowserModel {
    /**
     * Construct a new file browser model.
     */
    constructor(options) {
        var _a;
        this._connectionFailure = new _lumino_signaling__WEBPACK_IMPORTED_MODULE_7__.Signal(this);
        this._fileChanged = new _lumino_signaling__WEBPACK_IMPORTED_MODULE_7__.Signal(this);
        this._items = [];
        this._key = '';
        this._pathChanged = new _lumino_signaling__WEBPACK_IMPORTED_MODULE_7__.Signal(this);
        this._paths = new Set();
        this._pending = null;
        this._pendingPath = null;
        this._refreshed = new _lumino_signaling__WEBPACK_IMPORTED_MODULE_7__.Signal(this);
        this._sessions = [];
        this._state = null;
        this._isDisposed = false;
        this._restored = new _lumino_coreutils__WEBPACK_IMPORTED_MODULE_5__.PromiseDelegate();
        this._uploads = [];
        this._uploadChanged = new _lumino_signaling__WEBPACK_IMPORTED_MODULE_7__.Signal(this);
        this.manager = options.manager;
        this.translator = options.translator || _jupyterlab_translation__WEBPACK_IMPORTED_MODULE_3__.nullTranslator;
        this._trans = this.translator.load('jupyterlab');
        this._driveName = options.driveName || '';
        this._model = {
            path: this.rootPath,
            name: _jupyterlab_coreutils__WEBPACK_IMPORTED_MODULE_1__.PathExt.basename(this.rootPath),
            type: 'directory',
            content: undefined,
            writable: false,
            created: 'unknown',
            last_modified: 'unknown',
            mimetype: 'text/plain',
            format: 'text'
        };
        this._state = options.state || null;
        const refreshInterval = options.refreshInterval || DEFAULT_REFRESH_INTERVAL;
        const { services } = options.manager;
        services.contents.fileChanged.connect(this.onFileChanged, this);
        services.sessions.runningChanged.connect(this.onRunningChanged, this);
        this._unloadEventListener = (e) => {
            if (this._uploads.length > 0) {
                const confirmationMessage = this._trans.__('Files still uploading');
                e.returnValue = confirmationMessage;
                return confirmationMessage;
            }
        };
        window.addEventListener('beforeunload', this._unloadEventListener);
        this._poll = new _lumino_polling__WEBPACK_IMPORTED_MODULE_6__.Poll({
            auto: (_a = options.auto) !== null && _a !== void 0 ? _a : true,
            name: '@jupyterlab/filebrowser:Model',
            factory: () => this.cd('.'),
            frequency: {
                interval: refreshInterval,
                backoff: true,
                max: 300 * 1000
            },
            standby: 'when-hidden'
        });
    }
    /**
     * A signal emitted when the file browser model loses connection.
     */
    get connectionFailure() {
        return this._connectionFailure;
    }
    /**
     * The drive name that gets prepended to the path.
     */
    get driveName() {
        return this._driveName;
    }
    /**
     * A promise that resolves when the model is first restored.
     */
    get restored() {
        return this._restored.promise;
    }
    /**
     * Get the file path changed signal.
     */
    get fileChanged() {
        return this._fileChanged;
    }
    /**
     * Get the current path.
     */
    get path() {
        return this._model ? this._model.path : '';
    }
    /**
     * Get the root path
     */
    get rootPath() {
        return this._driveName ? this._driveName + ':' : '';
    }
    /**
     * A signal emitted when the path changes.
     */
    get pathChanged() {
        return this._pathChanged;
    }
    /**
     * A signal emitted when the directory listing is refreshed.
     */
    get refreshed() {
        return this._refreshed;
    }
    /**
     * Get the kernel spec models.
     */
    get specs() {
        return this.manager.services.kernelspecs.specs;
    }
    /**
     * Get whether the model is disposed.
     */
    get isDisposed() {
        return this._isDisposed;
    }
    /**
     * A signal emitted when an upload progresses.
     */
    get uploadChanged() {
        return this._uploadChanged;
    }
    /**
     * Create an iterator over the status of all in progress uploads.
     */
    uploads() {
        return new _lumino_algorithm__WEBPACK_IMPORTED_MODULE_4__.ArrayIterator(this._uploads);
    }
    /**
     * Dispose of the resources held by the model.
     */
    dispose() {
        if (this.isDisposed) {
            return;
        }
        window.removeEventListener('beforeunload', this._unloadEventListener);
        this._isDisposed = true;
        this._poll.dispose();
        this._sessions.length = 0;
        this._items.length = 0;
        _lumino_signaling__WEBPACK_IMPORTED_MODULE_7__.Signal.clearData(this);
    }
    /**
     * Create an iterator over the model's items.
     *
     * @returns A new iterator over the model's items.
     */
    items() {
        return new _lumino_algorithm__WEBPACK_IMPORTED_MODULE_4__.ArrayIterator(this._items);
    }
    /**
     * Create an iterator over the active sessions in the directory.
     *
     * @returns A new iterator over the model's active sessions.
     */
    sessions() {
        return new _lumino_algorithm__WEBPACK_IMPORTED_MODULE_4__.ArrayIterator(this._sessions);
    }
    /**
     * Force a refresh of the directory contents.
     */
    async refresh() {
        await this._poll.refresh();
        await this._poll.tick;
        this._refreshed.emit(void 0);
    }
    /**
     * Change directory.
     *
     * @param path - The path to the file or directory.
     *
     * @returns A promise with the contents of the directory.
     */
    async cd(newValue = '.') {
        if (newValue !== '.') {
            newValue = this.manager.services.contents.resolvePath(this._model.path, newValue);
        }
        else {
            newValue = this._pendingPath || this._model.path;
        }
        if (this._pending) {
            // Collapse requests to the same directory.
            if (newValue === this._pendingPath) {
                return this._pending;
            }
            // Otherwise wait for the pending request to complete before continuing.
            await this._pending;
        }
        const oldValue = this.path;
        const options = { content: true };
        this._pendingPath = newValue;
        if (oldValue !== newValue) {
            this._sessions.length = 0;
        }
        const services = this.manager.services;
        this._pending = services.contents
            .get(newValue, options)
            .then(contents => {
            if (this.isDisposed) {
                return;
            }
            this.handleContents(contents);
            this._pendingPath = null;
            this._pending = null;
            if (oldValue !== newValue) {
                // If there is a state database and a unique key, save the new path.
                // We don't need to wait on the save to continue.
                if (this._state && this._key) {
                    void this._state.save(this._key, { path: newValue });
                }
                this._pathChanged.emit({
                    name: 'path',
                    oldValue,
                    newValue
                });
            }
            this.onRunningChanged(services.sessions, services.sessions.running());
            this._refreshed.emit(void 0);
        })
            .catch(error => {
            this._pendingPath = null;
            this._pending = null;
            if (error.response &&
                error.response.status === 404 &&
                newValue !== '/') {
                error.message = this._trans.__('Directory not found: "%1"', this._model.path);
                console.error(error);
                this._connectionFailure.emit(error);
                return this.cd('/');
            }
            else {
                this._connectionFailure.emit(error);
            }
        });
        return this._pending;
    }
    /**
     * Download a file.
     *
     * @param path - The path of the file to be downloaded.
     *
     * @returns A promise which resolves when the file has begun
     *   downloading.
     */
    async download(path) {
        const url = await this.manager.services.contents.getDownloadUrl(path);
        const element = document.createElement('a');
        element.href = url;
        element.download = '';
        document.body.appendChild(element);
        element.click();
        document.body.removeChild(element);
        return void 0;
    }
    /**
     * Restore the state of the file browser.
     *
     * @param id - The unique ID that is used to construct a state database key.
     *
     * @param populate - If `false`, the restoration ID will be set but the file
     * browser state will not be fetched from the state database.
     *
     * @returns A promise when restoration is complete.
     *
     * #### Notes
     * This function will only restore the model *once*. If it is called multiple
     * times, all subsequent invocations are no-ops.
     */
    async restore(id, populate = true) {
        const { manager } = this;
        const key = `file-browser-${id}:cwd`;
        const state = this._state;
        const restored = !!this._key;
        if (restored) {
            return;
        }
        // Set the file browser key for state database fetch/save.
        this._key = key;
        if (!populate || !state) {
            this._restored.resolve(undefined);
            return;
        }
        await manager.services.ready;
        try {
            const value = await state.fetch(key);
            if (!value) {
                this._restored.resolve(undefined);
                return;
            }
            const path = value['path'];
            // need to return to root path if preferred dir is set
            if (path) {
                await this.cd('/');
            }
            const localPath = manager.services.contents.localPath(path);
            await manager.services.contents.get(path);
            await this.cd(localPath);
        }
        catch (error) {
            await state.remove(key);
        }
        this._restored.resolve(undefined);
    }
    /**
     * Upload a `File` object.
     *
     * @param file - The `File` object to upload.
     *
     * @returns A promise containing the new file contents model.
     *
     * #### Notes
     * On Notebook version < 5.1.0, this will fail to upload files that are too
     * big to be sent in one request to the server. On newer versions, or on
     * Jupyter Server, it will ask for confirmation then upload the file in 1 MB
     * chunks.
     */
    async upload(file) {
        // We do not support Jupyter Notebook version less than 4, and Jupyter
        // Server advertises itself as version 1 and supports chunked
        // uploading. We assume any version less than 4.0.0 to be Jupyter Server
        // instead of Jupyter Notebook.
        const serverVersion = _jupyterlab_coreutils__WEBPACK_IMPORTED_MODULE_1__.PageConfig.getNotebookVersion();
        const supportsChunked = serverVersion < [4, 0, 0] /* Jupyter Server */ ||
            serverVersion >= [5, 1, 0]; /* Jupyter Notebook >= 5.1.0 */
        const largeFile = file.size > LARGE_FILE_SIZE;
        if (largeFile && !supportsChunked) {
            const msg = this._trans.__('Cannot upload file (>%1 MB). %2', LARGE_FILE_SIZE / (1024 * 1024), file.name);
            console.warn(msg);
            throw msg;
        }
        const err = 'File not uploaded';
        if (largeFile && !(await this._shouldUploadLarge(file))) {
            throw 'Cancelled large file upload';
        }
        await this._uploadCheckDisposed();
        await this.refresh();
        await this._uploadCheckDisposed();
        if ((0,_lumino_algorithm__WEBPACK_IMPORTED_MODULE_4__.find)(this._items, i => i.name === file.name) &&
            !(await (0,_jupyterlab_docmanager__WEBPACK_IMPORTED_MODULE_2__.shouldOverwrite)(file.name))) {
            throw err;
        }
        await this._uploadCheckDisposed();
        const chunkedUpload = supportsChunked && file.size > CHUNK_SIZE;
        return await this._upload(file, chunkedUpload);
    }
    async _shouldUploadLarge(file) {
        const { button } = await (0,_jupyterlab_apputils__WEBPACK_IMPORTED_MODULE_0__.showDialog)({
            title: this._trans.__('Large file size warning'),
            body: this._trans.__('The file size is %1 MB. Do you still want to upload it?', Math.round(file.size / (1024 * 1024))),
            buttons: [
                _jupyterlab_apputils__WEBPACK_IMPORTED_MODULE_0__.Dialog.cancelButton({ label: this._trans.__('Cancel') }),
                _jupyterlab_apputils__WEBPACK_IMPORTED_MODULE_0__.Dialog.warnButton({ label: this._trans.__('Upload') })
            ]
        });
        return button.accept;
    }
    /**
     * Perform the actual upload.
     */
    async _upload(file, chunked) {
        // Gather the file model parameters.
        let path = this._model.path;
        path = path ? path + '/' + file.name : file.name;
        const name = file.name;
        const type = 'file';
        const format = 'base64';
        const uploadInner = async (blob, chunk) => {
            await this._uploadCheckDisposed();
            const reader = new FileReader();
            reader.readAsDataURL(blob);
            await new Promise((resolve, reject) => {
                reader.onload = resolve;
                reader.onerror = event => reject(`Failed to upload "${file.name}":` + event);
            });
            await this._uploadCheckDisposed();
            // remove header https://stackoverflow.com/a/24289420/907060
            const content = reader.result.split(',')[1];
            const model = {
                type,
                format,
                name,
                chunk,
                content
            };
            return await this.manager.services.contents.save(path, model);
        };
        if (!chunked) {
            try {
                return await uploadInner(file);
            }
            catch (err) {
                _lumino_algorithm__WEBPACK_IMPORTED_MODULE_4__.ArrayExt.removeFirstWhere(this._uploads, uploadIndex => {
                    return file.name === uploadIndex.path;
                });
                throw err;
            }
        }
        let finalModel;
        let upload = { path, progress: 0 };
        this._uploadChanged.emit({
            name: 'start',
            newValue: upload,
            oldValue: null
        });
        for (let start = 0; !finalModel; start += CHUNK_SIZE) {
            const end = start + CHUNK_SIZE;
            const lastChunk = end >= file.size;
            const chunk = lastChunk ? -1 : end / CHUNK_SIZE;
            const newUpload = { path, progress: start / file.size };
            this._uploads.splice(this._uploads.indexOf(upload));
            this._uploads.push(newUpload);
            this._uploadChanged.emit({
                name: 'update',
                newValue: newUpload,
                oldValue: upload
            });
            upload = newUpload;
            let currentModel;
            try {
                currentModel = await uploadInner(file.slice(start, end), chunk);
            }
            catch (err) {
                _lumino_algorithm__WEBPACK_IMPORTED_MODULE_4__.ArrayExt.removeFirstWhere(this._uploads, uploadIndex => {
                    return file.name === uploadIndex.path;
                });
                this._uploadChanged.emit({
                    name: 'failure',
                    newValue: upload,
                    oldValue: null
                });
                throw err;
            }
            if (lastChunk) {
                finalModel = currentModel;
            }
        }
        this._uploads.splice(this._uploads.indexOf(upload));
        this._uploadChanged.emit({
            name: 'finish',
            newValue: null,
            oldValue: upload
        });
        return finalModel;
    }
    _uploadCheckDisposed() {
        if (this.isDisposed) {
            return Promise.reject('Filemanager disposed. File upload canceled');
        }
        return Promise.resolve();
    }
    /**
     * Handle an updated contents model.
     */
    handleContents(contents) {
        // Update our internal data.
        this._model = {
            name: contents.name,
            path: contents.path,
            type: contents.type,
            content: undefined,
            writable: contents.writable,
            created: contents.created,
            last_modified: contents.last_modified,
            mimetype: contents.mimetype,
            format: contents.format
        };
        this._items = contents.content;
        this._paths.clear();
        contents.content.forEach((model) => {
            this._paths.add(model.path);
        });
    }
    /**
     * Handle a change to the running sessions.
     */
    onRunningChanged(sender, models) {
        this._populateSessions(models);
        this._refreshed.emit(void 0);
    }
    /**
     * Handle a change on the contents manager.
     */
    onFileChanged(sender, change) {
        const path = this._model.path;
        const { sessions } = this.manager.services;
        const { oldValue, newValue } = change;
        const value = oldValue && oldValue.path && _jupyterlab_coreutils__WEBPACK_IMPORTED_MODULE_1__.PathExt.dirname(oldValue.path) === path
            ? oldValue
            : newValue && newValue.path && _jupyterlab_coreutils__WEBPACK_IMPORTED_MODULE_1__.PathExt.dirname(newValue.path) === path
                ? newValue
                : undefined;
        // If either the old value or the new value is in the current path, update.
        if (value) {
            void this._poll.refresh();
            this._populateSessions(sessions.running());
            this._fileChanged.emit(change);
            return;
        }
    }
    /**
     * Populate the model's sessions collection.
     */
    _populateSessions(models) {
        this._sessions.length = 0;
        (0,_lumino_algorithm__WEBPACK_IMPORTED_MODULE_4__.each)(models, model => {
            if (this._paths.has(model.path)) {
                this._sessions.push(model);
            }
        });
    }
}
/**
 * File browser model where hidden files inclusion can be toggled on/off.
 */
class TogglableHiddenFileBrowserModel extends FileBrowserModel {
    constructor(options) {
        super(options);
        this._includeHiddenFiles = options.includeHiddenFiles || false;
    }
    /**
     * Create an iterator over the model's items filtering hidden files out if necessary.
     *
     * @returns A new iterator over the model's items.
     */
    items() {
        return this._includeHiddenFiles
            ? super.items()
            : (0,_lumino_algorithm__WEBPACK_IMPORTED_MODULE_4__.filter)(super.items(), value => !value.name.startsWith('.'));
    }
    /**
     * Set the inclusion of hidden files. Triggers a model refresh.
     */
    showHiddenFiles(value) {
        this._includeHiddenFiles = value;
        void this.refresh();
    }
}
/**
 * File browser model with optional filter on element.
 */
class FilterFileBrowserModel extends TogglableHiddenFileBrowserModel {
    constructor(options) {
        super(options);
        this._filter = options.filter ? options.filter : model => true;
    }
    /**
     * Create an iterator over the filtered model's items.
     *
     * @returns A new iterator over the model's items.
     */
    items() {
        return (0,_lumino_algorithm__WEBPACK_IMPORTED_MODULE_4__.filter)(super.items(), (value, index) => {
            if (value.type === 'directory') {
                return true;
            }
            else {
                return this._filter(value);
            }
        });
    }
    setFilter(filter) {
        this._filter = filter;
        void this.refresh();
    }
}
//# sourceMappingURL=model.js.map

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/lib/icon/iconimports.js":
/*!************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/lib/icon/iconimports.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "addAboveIcon": () => (/* binding */ addAboveIcon),
/* harmony export */   "addBelowIcon": () => (/* binding */ addBelowIcon),
/* harmony export */   "addIcon": () => (/* binding */ addIcon),
/* harmony export */   "bugDotIcon": () => (/* binding */ bugDotIcon),
/* harmony export */   "bugIcon": () => (/* binding */ bugIcon),
/* harmony export */   "buildIcon": () => (/* binding */ buildIcon),
/* harmony export */   "caretDownEmptyIcon": () => (/* binding */ caretDownEmptyIcon),
/* harmony export */   "caretDownEmptyThinIcon": () => (/* binding */ caretDownEmptyThinIcon),
/* harmony export */   "caretDownIcon": () => (/* binding */ caretDownIcon),
/* harmony export */   "caretLeftIcon": () => (/* binding */ caretLeftIcon),
/* harmony export */   "caretRightIcon": () => (/* binding */ caretRightIcon),
/* harmony export */   "caretUpEmptyThinIcon": () => (/* binding */ caretUpEmptyThinIcon),
/* harmony export */   "caretUpIcon": () => (/* binding */ caretUpIcon),
/* harmony export */   "caseSensitiveIcon": () => (/* binding */ caseSensitiveIcon),
/* harmony export */   "checkIcon": () => (/* binding */ checkIcon),
/* harmony export */   "circleEmptyIcon": () => (/* binding */ circleEmptyIcon),
/* harmony export */   "circleIcon": () => (/* binding */ circleIcon),
/* harmony export */   "clearIcon": () => (/* binding */ clearIcon),
/* harmony export */   "closeIcon": () => (/* binding */ closeIcon),
/* harmony export */   "codeIcon": () => (/* binding */ codeIcon),
/* harmony export */   "consoleIcon": () => (/* binding */ consoleIcon),
/* harmony export */   "copyIcon": () => (/* binding */ copyIcon),
/* harmony export */   "copyrightIcon": () => (/* binding */ copyrightIcon),
/* harmony export */   "cutIcon": () => (/* binding */ cutIcon),
/* harmony export */   "deleteIcon": () => (/* binding */ deleteIcon),
/* harmony export */   "downloadIcon": () => (/* binding */ downloadIcon),
/* harmony export */   "duplicateIcon": () => (/* binding */ duplicateIcon),
/* harmony export */   "editIcon": () => (/* binding */ editIcon),
/* harmony export */   "ellipsesIcon": () => (/* binding */ ellipsesIcon),
/* harmony export */   "extensionIcon": () => (/* binding */ extensionIcon),
/* harmony export */   "fastForwardIcon": () => (/* binding */ fastForwardIcon),
/* harmony export */   "fileIcon": () => (/* binding */ fileIcon),
/* harmony export */   "fileUploadIcon": () => (/* binding */ fileUploadIcon),
/* harmony export */   "filterListIcon": () => (/* binding */ filterListIcon),
/* harmony export */   "folderFavoriteIcon": () => (/* binding */ folderFavoriteIcon),
/* harmony export */   "folderIcon": () => (/* binding */ folderIcon),
/* harmony export */   "homeIcon": () => (/* binding */ homeIcon),
/* harmony export */   "html5Icon": () => (/* binding */ html5Icon),
/* harmony export */   "imageIcon": () => (/* binding */ imageIcon),
/* harmony export */   "inspectorIcon": () => (/* binding */ inspectorIcon),
/* harmony export */   "jsonIcon": () => (/* binding */ jsonIcon),
/* harmony export */   "juliaIcon": () => (/* binding */ juliaIcon),
/* harmony export */   "jupyterFaviconIcon": () => (/* binding */ jupyterFaviconIcon),
/* harmony export */   "jupyterIcon": () => (/* binding */ jupyterIcon),
/* harmony export */   "jupyterlabWordmarkIcon": () => (/* binding */ jupyterlabWordmarkIcon),
/* harmony export */   "kernelIcon": () => (/* binding */ kernelIcon),
/* harmony export */   "keyboardIcon": () => (/* binding */ keyboardIcon),
/* harmony export */   "launchIcon": () => (/* binding */ launchIcon),
/* harmony export */   "launcherIcon": () => (/* binding */ launcherIcon),
/* harmony export */   "lineFormIcon": () => (/* binding */ lineFormIcon),
/* harmony export */   "linkIcon": () => (/* binding */ linkIcon),
/* harmony export */   "listIcon": () => (/* binding */ listIcon),
/* harmony export */   "listingsInfoIcon": () => (/* binding */ listingsInfoIcon),
/* harmony export */   "markdownIcon": () => (/* binding */ markdownIcon),
/* harmony export */   "moveDownIcon": () => (/* binding */ moveDownIcon),
/* harmony export */   "moveUpIcon": () => (/* binding */ moveUpIcon),
/* harmony export */   "newFolderIcon": () => (/* binding */ newFolderIcon),
/* harmony export */   "notTrustedIcon": () => (/* binding */ notTrustedIcon),
/* harmony export */   "notebookIcon": () => (/* binding */ notebookIcon),
/* harmony export */   "numberingIcon": () => (/* binding */ numberingIcon),
/* harmony export */   "offlineBoltIcon": () => (/* binding */ offlineBoltIcon),
/* harmony export */   "paletteIcon": () => (/* binding */ paletteIcon),
/* harmony export */   "pasteIcon": () => (/* binding */ pasteIcon),
/* harmony export */   "pdfIcon": () => (/* binding */ pdfIcon),
/* harmony export */   "pythonIcon": () => (/* binding */ pythonIcon),
/* harmony export */   "rKernelIcon": () => (/* binding */ rKernelIcon),
/* harmony export */   "reactIcon": () => (/* binding */ reactIcon),
/* harmony export */   "redoIcon": () => (/* binding */ redoIcon),
/* harmony export */   "refreshIcon": () => (/* binding */ refreshIcon),
/* harmony export */   "regexIcon": () => (/* binding */ regexIcon),
/* harmony export */   "runIcon": () => (/* binding */ runIcon),
/* harmony export */   "runningIcon": () => (/* binding */ runningIcon),
/* harmony export */   "saveIcon": () => (/* binding */ saveIcon),
/* harmony export */   "searchIcon": () => (/* binding */ searchIcon),
/* harmony export */   "settingsIcon": () => (/* binding */ settingsIcon),
/* harmony export */   "spreadsheetIcon": () => (/* binding */ spreadsheetIcon),
/* harmony export */   "stopIcon": () => (/* binding */ stopIcon),
/* harmony export */   "tabIcon": () => (/* binding */ tabIcon),
/* harmony export */   "tableRowsIcon": () => (/* binding */ tableRowsIcon),
/* harmony export */   "tagIcon": () => (/* binding */ tagIcon),
/* harmony export */   "terminalIcon": () => (/* binding */ terminalIcon),
/* harmony export */   "textEditorIcon": () => (/* binding */ textEditorIcon),
/* harmony export */   "tocIcon": () => (/* binding */ tocIcon),
/* harmony export */   "treeViewIcon": () => (/* binding */ treeViewIcon),
/* harmony export */   "trustedIcon": () => (/* binding */ trustedIcon),
/* harmony export */   "undoIcon": () => (/* binding */ undoIcon),
/* harmony export */   "vegaIcon": () => (/* binding */ vegaIcon),
/* harmony export */   "yamlIcon": () => (/* binding */ yamlIcon)
/* harmony export */ });
/* harmony import */ var _labicon__WEBPACK_IMPORTED_MODULE_88__ = __webpack_require__(/*! ./labicon */ "./node_modules/@jupyterlab/ui-components/lib/icon/labicon.js");
/* harmony import */ var _style_icons_toolbar_add_above_svg__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../style/icons/toolbar/add-above.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/add-above.svg");
/* harmony import */ var _style_icons_toolbar_add_below_svg__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../style/icons/toolbar/add-below.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/add-below.svg");
/* harmony import */ var _style_icons_toolbar_add_svg__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../../style/icons/toolbar/add.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/add.svg");
/* harmony import */ var _style_icons_toolbar_bug_dot_svg__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ../../style/icons/toolbar/bug-dot.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/bug-dot.svg");
/* harmony import */ var _style_icons_toolbar_bug_svg__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../style/icons/toolbar/bug.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/bug.svg");
/* harmony import */ var _style_icons_sidebar_build_svg__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../style/icons/sidebar/build.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/sidebar/build.svg");
/* harmony import */ var _style_icons_arrow_caret_down_empty_svg__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../style/icons/arrow/caret-down-empty.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-down-empty.svg");
/* harmony import */ var _style_icons_arrow_caret_down_empty_thin_svg__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../../style/icons/arrow/caret-down-empty-thin.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-down-empty-thin.svg");
/* harmony import */ var _style_icons_arrow_caret_down_svg__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../../style/icons/arrow/caret-down.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-down.svg");
/* harmony import */ var _style_icons_arrow_caret_left_svg__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ../../style/icons/arrow/caret-left.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-left.svg");
/* harmony import */ var _style_icons_arrow_caret_right_svg__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ../../style/icons/arrow/caret-right.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-right.svg");
/* harmony import */ var _style_icons_arrow_caret_up_empty_thin_svg__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ../../style/icons/arrow/caret-up-empty-thin.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-up-empty-thin.svg");
/* harmony import */ var _style_icons_arrow_caret_up_svg__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ../../style/icons/arrow/caret-up.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-up.svg");
/* harmony import */ var _style_icons_search_case_sensitive_svg__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ../../style/icons/search/case-sensitive.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/search/case-sensitive.svg");
/* harmony import */ var _style_icons_toolbar_check_svg__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ../../style/icons/toolbar/check.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/check.svg");
/* harmony import */ var _style_icons_toolbar_circle_empty_svg__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ../../style/icons/toolbar/circle-empty.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/circle-empty.svg");
/* harmony import */ var _style_icons_toolbar_circle_svg__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ../../style/icons/toolbar/circle.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/circle.svg");
/* harmony import */ var _style_icons_toolbar_clear_svg__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ../../style/icons/toolbar/clear.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/clear.svg");
/* harmony import */ var _style_icons_toolbar_close_svg__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ../../style/icons/toolbar/close.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/close.svg");
/* harmony import */ var _style_icons_toolbar_code_svg__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ../../style/icons/toolbar/code.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/code.svg");
/* harmony import */ var _style_icons_filetype_console_svg__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ../../style/icons/filetype/console.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/console.svg");
/* harmony import */ var _style_icons_toolbar_copy_svg__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ../../style/icons/toolbar/copy.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/copy.svg");
/* harmony import */ var _style_icons_licenses_copyright_svg__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ../../style/icons/licenses/copyright.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/licenses/copyright.svg");
/* harmony import */ var _style_icons_toolbar_cut_svg__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! ../../style/icons/toolbar/cut.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/cut.svg");
/* harmony import */ var _style_icons_toolbar_delete_svg__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! ../../style/icons/toolbar/delete.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/delete.svg");
/* harmony import */ var _style_icons_toolbar_download_svg__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(/*! ../../style/icons/toolbar/download.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/download.svg");
/* harmony import */ var _style_icons_toolbar_duplicate_svg__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(/*! ../../style/icons/toolbar/duplicate.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/duplicate.svg");
/* harmony import */ var _style_icons_toolbar_edit_svg__WEBPACK_IMPORTED_MODULE_27__ = __webpack_require__(/*! ../../style/icons/toolbar/edit.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/edit.svg");
/* harmony import */ var _style_icons_toolbar_ellipses_svg__WEBPACK_IMPORTED_MODULE_28__ = __webpack_require__(/*! ../../style/icons/toolbar/ellipses.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/ellipses.svg");
/* harmony import */ var _style_icons_sidebar_extension_svg__WEBPACK_IMPORTED_MODULE_29__ = __webpack_require__(/*! ../../style/icons/sidebar/extension.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/sidebar/extension.svg");
/* harmony import */ var _style_icons_toolbar_fast_forward_svg__WEBPACK_IMPORTED_MODULE_30__ = __webpack_require__(/*! ../../style/icons/toolbar/fast-forward.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/fast-forward.svg");
/* harmony import */ var _style_icons_filetype_file_svg__WEBPACK_IMPORTED_MODULE_31__ = __webpack_require__(/*! ../../style/icons/filetype/file.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/file.svg");
/* harmony import */ var _style_icons_toolbar_file_upload_svg__WEBPACK_IMPORTED_MODULE_32__ = __webpack_require__(/*! ../../style/icons/toolbar/file-upload.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/file-upload.svg");
/* harmony import */ var _style_icons_toolbar_filter_list_svg__WEBPACK_IMPORTED_MODULE_33__ = __webpack_require__(/*! ../../style/icons/toolbar/filter-list.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/filter-list.svg");
/* harmony import */ var _style_icons_filetype_folder_favorite_svg__WEBPACK_IMPORTED_MODULE_34__ = __webpack_require__(/*! ../../style/icons/filetype/folder-favorite.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/folder-favorite.svg");
/* harmony import */ var _style_icons_filetype_folder_svg__WEBPACK_IMPORTED_MODULE_35__ = __webpack_require__(/*! ../../style/icons/filetype/folder.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/folder.svg");
/* harmony import */ var _style_icons_filetype_home_svg__WEBPACK_IMPORTED_MODULE_36__ = __webpack_require__(/*! ../../style/icons/filetype/home.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/home.svg");
/* harmony import */ var _style_icons_filetype_html5_svg__WEBPACK_IMPORTED_MODULE_37__ = __webpack_require__(/*! ../../style/icons/filetype/html5.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/html5.svg");
/* harmony import */ var _style_icons_filetype_image_svg__WEBPACK_IMPORTED_MODULE_38__ = __webpack_require__(/*! ../../style/icons/filetype/image.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/image.svg");
/* harmony import */ var _style_icons_filetype_inspector_svg__WEBPACK_IMPORTED_MODULE_39__ = __webpack_require__(/*! ../../style/icons/filetype/inspector.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/inspector.svg");
/* harmony import */ var _style_icons_filetype_json_svg__WEBPACK_IMPORTED_MODULE_40__ = __webpack_require__(/*! ../../style/icons/filetype/json.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/json.svg");
/* harmony import */ var _style_icons_filetype_julia_svg__WEBPACK_IMPORTED_MODULE_41__ = __webpack_require__(/*! ../../style/icons/filetype/julia.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/julia.svg");
/* harmony import */ var _style_icons_jupyter_jupyter_favicon_svg__WEBPACK_IMPORTED_MODULE_42__ = __webpack_require__(/*! ../../style/icons/jupyter/jupyter-favicon.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/jupyter/jupyter-favicon.svg");
/* harmony import */ var _style_icons_jupyter_jupyter_svg__WEBPACK_IMPORTED_MODULE_43__ = __webpack_require__(/*! ../../style/icons/jupyter/jupyter.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/jupyter/jupyter.svg");
/* harmony import */ var _style_icons_jupyter_jupyterlab_wordmark_svg__WEBPACK_IMPORTED_MODULE_44__ = __webpack_require__(/*! ../../style/icons/jupyter/jupyterlab-wordmark.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/jupyter/jupyterlab-wordmark.svg");
/* harmony import */ var _style_icons_statusbar_kernel_svg__WEBPACK_IMPORTED_MODULE_45__ = __webpack_require__(/*! ../../style/icons/statusbar/kernel.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/statusbar/kernel.svg");
/* harmony import */ var _style_icons_filetype_keyboard_svg__WEBPACK_IMPORTED_MODULE_46__ = __webpack_require__(/*! ../../style/icons/filetype/keyboard.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/keyboard.svg");
/* harmony import */ var _style_icons_toolbar_launch_svg__WEBPACK_IMPORTED_MODULE_47__ = __webpack_require__(/*! ../../style/icons/toolbar/launch.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/launch.svg");
/* harmony import */ var _style_icons_filetype_launcher_svg__WEBPACK_IMPORTED_MODULE_48__ = __webpack_require__(/*! ../../style/icons/filetype/launcher.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/launcher.svg");
/* harmony import */ var _style_icons_statusbar_line_form_svg__WEBPACK_IMPORTED_MODULE_49__ = __webpack_require__(/*! ../../style/icons/statusbar/line-form.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/statusbar/line-form.svg");
/* harmony import */ var _style_icons_toolbar_link_svg__WEBPACK_IMPORTED_MODULE_50__ = __webpack_require__(/*! ../../style/icons/toolbar/link.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/link.svg");
/* harmony import */ var _style_icons_statusbar_list_svg__WEBPACK_IMPORTED_MODULE_51__ = __webpack_require__(/*! ../../style/icons/statusbar/list.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/statusbar/list.svg");
/* harmony import */ var _style_icons_listings_listings_info_svg__WEBPACK_IMPORTED_MODULE_52__ = __webpack_require__(/*! ../../style/icons/listings/listings-info.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/listings/listings-info.svg");
/* harmony import */ var _style_icons_filetype_markdown_svg__WEBPACK_IMPORTED_MODULE_53__ = __webpack_require__(/*! ../../style/icons/filetype/markdown.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/markdown.svg");
/* harmony import */ var _style_icons_toolbar_move_down_svg__WEBPACK_IMPORTED_MODULE_54__ = __webpack_require__(/*! ../../style/icons/toolbar/move-down.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/move-down.svg");
/* harmony import */ var _style_icons_toolbar_move_up_svg__WEBPACK_IMPORTED_MODULE_55__ = __webpack_require__(/*! ../../style/icons/toolbar/move-up.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/move-up.svg");
/* harmony import */ var _style_icons_toolbar_new_folder_svg__WEBPACK_IMPORTED_MODULE_56__ = __webpack_require__(/*! ../../style/icons/toolbar/new-folder.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/new-folder.svg");
/* harmony import */ var _style_icons_statusbar_not_trusted_svg__WEBPACK_IMPORTED_MODULE_57__ = __webpack_require__(/*! ../../style/icons/statusbar/not-trusted.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/statusbar/not-trusted.svg");
/* harmony import */ var _style_icons_filetype_notebook_svg__WEBPACK_IMPORTED_MODULE_58__ = __webpack_require__(/*! ../../style/icons/filetype/notebook.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/notebook.svg");
/* harmony import */ var _style_icons_toolbar_numbering_svg__WEBPACK_IMPORTED_MODULE_59__ = __webpack_require__(/*! ../../style/icons/toolbar/numbering.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/numbering.svg");
/* harmony import */ var _style_icons_toolbar_offline_bolt_svg__WEBPACK_IMPORTED_MODULE_60__ = __webpack_require__(/*! ../../style/icons/toolbar/offline-bolt.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/offline-bolt.svg");
/* harmony import */ var _style_icons_sidebar_palette_svg__WEBPACK_IMPORTED_MODULE_61__ = __webpack_require__(/*! ../../style/icons/sidebar/palette.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/sidebar/palette.svg");
/* harmony import */ var _style_icons_toolbar_paste_svg__WEBPACK_IMPORTED_MODULE_62__ = __webpack_require__(/*! ../../style/icons/toolbar/paste.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/paste.svg");
/* harmony import */ var _style_icons_filetype_pdf_svg__WEBPACK_IMPORTED_MODULE_63__ = __webpack_require__(/*! ../../style/icons/filetype/pdf.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/pdf.svg");
/* harmony import */ var _style_icons_filetype_python_svg__WEBPACK_IMPORTED_MODULE_64__ = __webpack_require__(/*! ../../style/icons/filetype/python.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/python.svg");
/* harmony import */ var _style_icons_filetype_r_kernel_svg__WEBPACK_IMPORTED_MODULE_65__ = __webpack_require__(/*! ../../style/icons/filetype/r-kernel.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/r-kernel.svg");
/* harmony import */ var _style_icons_filetype_react_svg__WEBPACK_IMPORTED_MODULE_66__ = __webpack_require__(/*! ../../style/icons/filetype/react.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/react.svg");
/* harmony import */ var _style_icons_toolbar_redo_svg__WEBPACK_IMPORTED_MODULE_67__ = __webpack_require__(/*! ../../style/icons/toolbar/redo.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/redo.svg");
/* harmony import */ var _style_icons_toolbar_refresh_svg__WEBPACK_IMPORTED_MODULE_68__ = __webpack_require__(/*! ../../style/icons/toolbar/refresh.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/refresh.svg");
/* harmony import */ var _style_icons_search_regex_svg__WEBPACK_IMPORTED_MODULE_69__ = __webpack_require__(/*! ../../style/icons/search/regex.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/search/regex.svg");
/* harmony import */ var _style_icons_toolbar_run_svg__WEBPACK_IMPORTED_MODULE_70__ = __webpack_require__(/*! ../../style/icons/toolbar/run.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/run.svg");
/* harmony import */ var _style_icons_sidebar_running_svg__WEBPACK_IMPORTED_MODULE_71__ = __webpack_require__(/*! ../../style/icons/sidebar/running.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/sidebar/running.svg");
/* harmony import */ var _style_icons_toolbar_save_svg__WEBPACK_IMPORTED_MODULE_72__ = __webpack_require__(/*! ../../style/icons/toolbar/save.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/save.svg");
/* harmony import */ var _style_icons_toolbar_search_svg__WEBPACK_IMPORTED_MODULE_73__ = __webpack_require__(/*! ../../style/icons/toolbar/search.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/search.svg");
/* harmony import */ var _style_icons_filetype_settings_svg__WEBPACK_IMPORTED_MODULE_74__ = __webpack_require__(/*! ../../style/icons/filetype/settings.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/settings.svg");
/* harmony import */ var _style_icons_filetype_spreadsheet_svg__WEBPACK_IMPORTED_MODULE_75__ = __webpack_require__(/*! ../../style/icons/filetype/spreadsheet.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/spreadsheet.svg");
/* harmony import */ var _style_icons_toolbar_stop_svg__WEBPACK_IMPORTED_MODULE_76__ = __webpack_require__(/*! ../../style/icons/toolbar/stop.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/stop.svg");
/* harmony import */ var _style_icons_sidebar_tab_svg__WEBPACK_IMPORTED_MODULE_77__ = __webpack_require__(/*! ../../style/icons/sidebar/tab.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/sidebar/tab.svg");
/* harmony import */ var _style_icons_toolbar_table_rows_svg__WEBPACK_IMPORTED_MODULE_78__ = __webpack_require__(/*! ../../style/icons/toolbar/table-rows.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/table-rows.svg");
/* harmony import */ var _style_icons_toolbar_tag_svg__WEBPACK_IMPORTED_MODULE_79__ = __webpack_require__(/*! ../../style/icons/toolbar/tag.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/tag.svg");
/* harmony import */ var _style_icons_statusbar_terminal_svg__WEBPACK_IMPORTED_MODULE_80__ = __webpack_require__(/*! ../../style/icons/statusbar/terminal.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/statusbar/terminal.svg");
/* harmony import */ var _style_icons_filetype_text_editor_svg__WEBPACK_IMPORTED_MODULE_81__ = __webpack_require__(/*! ../../style/icons/filetype/text-editor.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/text-editor.svg");
/* harmony import */ var _style_icons_sidebar_toc_svg__WEBPACK_IMPORTED_MODULE_82__ = __webpack_require__(/*! ../../style/icons/sidebar/toc.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/sidebar/toc.svg");
/* harmony import */ var _style_icons_toolbar_tree_view_svg__WEBPACK_IMPORTED_MODULE_83__ = __webpack_require__(/*! ../../style/icons/toolbar/tree-view.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/tree-view.svg");
/* harmony import */ var _style_icons_statusbar_trusted_svg__WEBPACK_IMPORTED_MODULE_84__ = __webpack_require__(/*! ../../style/icons/statusbar/trusted.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/statusbar/trusted.svg");
/* harmony import */ var _style_icons_toolbar_undo_svg__WEBPACK_IMPORTED_MODULE_85__ = __webpack_require__(/*! ../../style/icons/toolbar/undo.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/undo.svg");
/* harmony import */ var _style_icons_filetype_vega_svg__WEBPACK_IMPORTED_MODULE_86__ = __webpack_require__(/*! ../../style/icons/filetype/vega.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/vega.svg");
/* harmony import */ var _style_icons_filetype_yaml_svg__WEBPACK_IMPORTED_MODULE_87__ = __webpack_require__(/*! ../../style/icons/filetype/yaml.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/yaml.svg");
/*-----------------------------------------------------------------------------
| Copyright (c) Jupyter Development Team.
| Distributed under the terms of the Modified BSD License.
|----------------------------------------------------------------------------*/
/* This file was auto-generated by ensureUiComponents() in @jupyterlab/buildutils */

// icon svg import statements
























































































// LabIcon instance construction
const addAboveIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:add-above', svgstr: _style_icons_toolbar_add_above_svg__WEBPACK_IMPORTED_MODULE_0__["default"] });
const addBelowIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:add-below', svgstr: _style_icons_toolbar_add_below_svg__WEBPACK_IMPORTED_MODULE_1__["default"] });
const addIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:add', svgstr: _style_icons_toolbar_add_svg__WEBPACK_IMPORTED_MODULE_2__["default"] });
const bugDotIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:bug-dot', svgstr: _style_icons_toolbar_bug_dot_svg__WEBPACK_IMPORTED_MODULE_3__["default"] });
const bugIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:bug', svgstr: _style_icons_toolbar_bug_svg__WEBPACK_IMPORTED_MODULE_4__["default"] });
const buildIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:build', svgstr: _style_icons_sidebar_build_svg__WEBPACK_IMPORTED_MODULE_5__["default"] });
const caretDownEmptyIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:caret-down-empty', svgstr: _style_icons_arrow_caret_down_empty_svg__WEBPACK_IMPORTED_MODULE_6__["default"] });
const caretDownEmptyThinIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:caret-down-empty-thin', svgstr: _style_icons_arrow_caret_down_empty_thin_svg__WEBPACK_IMPORTED_MODULE_7__["default"] });
const caretDownIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:caret-down', svgstr: _style_icons_arrow_caret_down_svg__WEBPACK_IMPORTED_MODULE_8__["default"] });
const caretLeftIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:caret-left', svgstr: _style_icons_arrow_caret_left_svg__WEBPACK_IMPORTED_MODULE_9__["default"] });
const caretRightIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:caret-right', svgstr: _style_icons_arrow_caret_right_svg__WEBPACK_IMPORTED_MODULE_10__["default"] });
const caretUpEmptyThinIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:caret-up-empty-thin', svgstr: _style_icons_arrow_caret_up_empty_thin_svg__WEBPACK_IMPORTED_MODULE_11__["default"] });
const caretUpIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:caret-up', svgstr: _style_icons_arrow_caret_up_svg__WEBPACK_IMPORTED_MODULE_12__["default"] });
const caseSensitiveIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:case-sensitive', svgstr: _style_icons_search_case_sensitive_svg__WEBPACK_IMPORTED_MODULE_13__["default"] });
const checkIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:check', svgstr: _style_icons_toolbar_check_svg__WEBPACK_IMPORTED_MODULE_14__["default"] });
const circleEmptyIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:circle-empty', svgstr: _style_icons_toolbar_circle_empty_svg__WEBPACK_IMPORTED_MODULE_15__["default"] });
const circleIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:circle', svgstr: _style_icons_toolbar_circle_svg__WEBPACK_IMPORTED_MODULE_16__["default"] });
const clearIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:clear', svgstr: _style_icons_toolbar_clear_svg__WEBPACK_IMPORTED_MODULE_17__["default"] });
const closeIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:close', svgstr: _style_icons_toolbar_close_svg__WEBPACK_IMPORTED_MODULE_18__["default"] });
const codeIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:code', svgstr: _style_icons_toolbar_code_svg__WEBPACK_IMPORTED_MODULE_19__["default"] });
const consoleIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:console', svgstr: _style_icons_filetype_console_svg__WEBPACK_IMPORTED_MODULE_20__["default"] });
const copyIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:copy', svgstr: _style_icons_toolbar_copy_svg__WEBPACK_IMPORTED_MODULE_21__["default"] });
const copyrightIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:copyright', svgstr: _style_icons_licenses_copyright_svg__WEBPACK_IMPORTED_MODULE_22__["default"] });
const cutIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:cut', svgstr: _style_icons_toolbar_cut_svg__WEBPACK_IMPORTED_MODULE_23__["default"] });
const deleteIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:delete', svgstr: _style_icons_toolbar_delete_svg__WEBPACK_IMPORTED_MODULE_24__["default"] });
const downloadIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:download', svgstr: _style_icons_toolbar_download_svg__WEBPACK_IMPORTED_MODULE_25__["default"] });
const duplicateIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:duplicate', svgstr: _style_icons_toolbar_duplicate_svg__WEBPACK_IMPORTED_MODULE_26__["default"] });
const editIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:edit', svgstr: _style_icons_toolbar_edit_svg__WEBPACK_IMPORTED_MODULE_27__["default"] });
const ellipsesIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:ellipses', svgstr: _style_icons_toolbar_ellipses_svg__WEBPACK_IMPORTED_MODULE_28__["default"] });
const extensionIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:extension', svgstr: _style_icons_sidebar_extension_svg__WEBPACK_IMPORTED_MODULE_29__["default"] });
const fastForwardIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:fast-forward', svgstr: _style_icons_toolbar_fast_forward_svg__WEBPACK_IMPORTED_MODULE_30__["default"] });
const fileIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:file', svgstr: _style_icons_filetype_file_svg__WEBPACK_IMPORTED_MODULE_31__["default"] });
const fileUploadIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:file-upload', svgstr: _style_icons_toolbar_file_upload_svg__WEBPACK_IMPORTED_MODULE_32__["default"] });
const filterListIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:filter-list', svgstr: _style_icons_toolbar_filter_list_svg__WEBPACK_IMPORTED_MODULE_33__["default"] });
const folderFavoriteIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:folder-favorite', svgstr: _style_icons_filetype_folder_favorite_svg__WEBPACK_IMPORTED_MODULE_34__["default"] });
const folderIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:folder', svgstr: _style_icons_filetype_folder_svg__WEBPACK_IMPORTED_MODULE_35__["default"] });
const homeIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:home', svgstr: _style_icons_filetype_home_svg__WEBPACK_IMPORTED_MODULE_36__["default"] });
const html5Icon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:html5', svgstr: _style_icons_filetype_html5_svg__WEBPACK_IMPORTED_MODULE_37__["default"] });
const imageIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:image', svgstr: _style_icons_filetype_image_svg__WEBPACK_IMPORTED_MODULE_38__["default"] });
const inspectorIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:inspector', svgstr: _style_icons_filetype_inspector_svg__WEBPACK_IMPORTED_MODULE_39__["default"] });
const jsonIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:json', svgstr: _style_icons_filetype_json_svg__WEBPACK_IMPORTED_MODULE_40__["default"] });
const juliaIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:julia', svgstr: _style_icons_filetype_julia_svg__WEBPACK_IMPORTED_MODULE_41__["default"] });
const jupyterFaviconIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:jupyter-favicon', svgstr: _style_icons_jupyter_jupyter_favicon_svg__WEBPACK_IMPORTED_MODULE_42__["default"] });
const jupyterIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:jupyter', svgstr: _style_icons_jupyter_jupyter_svg__WEBPACK_IMPORTED_MODULE_43__["default"] });
const jupyterlabWordmarkIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:jupyterlab-wordmark', svgstr: _style_icons_jupyter_jupyterlab_wordmark_svg__WEBPACK_IMPORTED_MODULE_44__["default"] });
const kernelIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:kernel', svgstr: _style_icons_statusbar_kernel_svg__WEBPACK_IMPORTED_MODULE_45__["default"] });
const keyboardIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:keyboard', svgstr: _style_icons_filetype_keyboard_svg__WEBPACK_IMPORTED_MODULE_46__["default"] });
const launchIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:launch', svgstr: _style_icons_toolbar_launch_svg__WEBPACK_IMPORTED_MODULE_47__["default"] });
const launcherIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:launcher', svgstr: _style_icons_filetype_launcher_svg__WEBPACK_IMPORTED_MODULE_48__["default"] });
const lineFormIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:line-form', svgstr: _style_icons_statusbar_line_form_svg__WEBPACK_IMPORTED_MODULE_49__["default"] });
const linkIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:link', svgstr: _style_icons_toolbar_link_svg__WEBPACK_IMPORTED_MODULE_50__["default"] });
const listIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:list', svgstr: _style_icons_statusbar_list_svg__WEBPACK_IMPORTED_MODULE_51__["default"] });
const listingsInfoIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:listings-info', svgstr: _style_icons_listings_listings_info_svg__WEBPACK_IMPORTED_MODULE_52__["default"] });
const markdownIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:markdown', svgstr: _style_icons_filetype_markdown_svg__WEBPACK_IMPORTED_MODULE_53__["default"] });
const moveDownIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:move-down', svgstr: _style_icons_toolbar_move_down_svg__WEBPACK_IMPORTED_MODULE_54__["default"] });
const moveUpIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:move-up', svgstr: _style_icons_toolbar_move_up_svg__WEBPACK_IMPORTED_MODULE_55__["default"] });
const newFolderIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:new-folder', svgstr: _style_icons_toolbar_new_folder_svg__WEBPACK_IMPORTED_MODULE_56__["default"] });
const notTrustedIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:not-trusted', svgstr: _style_icons_statusbar_not_trusted_svg__WEBPACK_IMPORTED_MODULE_57__["default"] });
const notebookIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:notebook', svgstr: _style_icons_filetype_notebook_svg__WEBPACK_IMPORTED_MODULE_58__["default"] });
const numberingIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:numbering', svgstr: _style_icons_toolbar_numbering_svg__WEBPACK_IMPORTED_MODULE_59__["default"] });
const offlineBoltIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:offline-bolt', svgstr: _style_icons_toolbar_offline_bolt_svg__WEBPACK_IMPORTED_MODULE_60__["default"] });
const paletteIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:palette', svgstr: _style_icons_sidebar_palette_svg__WEBPACK_IMPORTED_MODULE_61__["default"] });
const pasteIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:paste', svgstr: _style_icons_toolbar_paste_svg__WEBPACK_IMPORTED_MODULE_62__["default"] });
const pdfIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:pdf', svgstr: _style_icons_filetype_pdf_svg__WEBPACK_IMPORTED_MODULE_63__["default"] });
const pythonIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:python', svgstr: _style_icons_filetype_python_svg__WEBPACK_IMPORTED_MODULE_64__["default"] });
const rKernelIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:r-kernel', svgstr: _style_icons_filetype_r_kernel_svg__WEBPACK_IMPORTED_MODULE_65__["default"] });
const reactIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:react', svgstr: _style_icons_filetype_react_svg__WEBPACK_IMPORTED_MODULE_66__["default"] });
const redoIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:redo', svgstr: _style_icons_toolbar_redo_svg__WEBPACK_IMPORTED_MODULE_67__["default"] });
const refreshIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:refresh', svgstr: _style_icons_toolbar_refresh_svg__WEBPACK_IMPORTED_MODULE_68__["default"] });
const regexIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:regex', svgstr: _style_icons_search_regex_svg__WEBPACK_IMPORTED_MODULE_69__["default"] });
const runIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:run', svgstr: _style_icons_toolbar_run_svg__WEBPACK_IMPORTED_MODULE_70__["default"] });
const runningIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:running', svgstr: _style_icons_sidebar_running_svg__WEBPACK_IMPORTED_MODULE_71__["default"] });
const saveIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:save', svgstr: _style_icons_toolbar_save_svg__WEBPACK_IMPORTED_MODULE_72__["default"] });
const searchIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:search', svgstr: _style_icons_toolbar_search_svg__WEBPACK_IMPORTED_MODULE_73__["default"] });
const settingsIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:settings', svgstr: _style_icons_filetype_settings_svg__WEBPACK_IMPORTED_MODULE_74__["default"] });
const spreadsheetIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:spreadsheet', svgstr: _style_icons_filetype_spreadsheet_svg__WEBPACK_IMPORTED_MODULE_75__["default"] });
const stopIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:stop', svgstr: _style_icons_toolbar_stop_svg__WEBPACK_IMPORTED_MODULE_76__["default"] });
const tabIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:tab', svgstr: _style_icons_sidebar_tab_svg__WEBPACK_IMPORTED_MODULE_77__["default"] });
const tableRowsIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:table-rows', svgstr: _style_icons_toolbar_table_rows_svg__WEBPACK_IMPORTED_MODULE_78__["default"] });
const tagIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:tag', svgstr: _style_icons_toolbar_tag_svg__WEBPACK_IMPORTED_MODULE_79__["default"] });
const terminalIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:terminal', svgstr: _style_icons_statusbar_terminal_svg__WEBPACK_IMPORTED_MODULE_80__["default"] });
const textEditorIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:text-editor', svgstr: _style_icons_filetype_text_editor_svg__WEBPACK_IMPORTED_MODULE_81__["default"] });
const tocIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:toc', svgstr: _style_icons_sidebar_toc_svg__WEBPACK_IMPORTED_MODULE_82__["default"] });
const treeViewIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:tree-view', svgstr: _style_icons_toolbar_tree_view_svg__WEBPACK_IMPORTED_MODULE_83__["default"] });
const trustedIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:trusted', svgstr: _style_icons_statusbar_trusted_svg__WEBPACK_IMPORTED_MODULE_84__["default"] });
const undoIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:undo', svgstr: _style_icons_toolbar_undo_svg__WEBPACK_IMPORTED_MODULE_85__["default"] });
const vegaIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:vega', svgstr: _style_icons_filetype_vega_svg__WEBPACK_IMPORTED_MODULE_86__["default"] });
const yamlIcon = new _labicon__WEBPACK_IMPORTED_MODULE_88__.LabIcon({ name: 'ui-components:yaml', svgstr: _style_icons_filetype_yaml_svg__WEBPACK_IMPORTED_MODULE_87__["default"] });
//# sourceMappingURL=iconimports.js.map

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/lib/icon/labicon.js":
/*!********************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/lib/icon/labicon.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "LabIcon": () => (/* binding */ LabIcon),
/* harmony export */   "badIcon": () => (/* binding */ badIcon),
/* harmony export */   "blankIcon": () => (/* binding */ blankIcon)
/* harmony export */ });
/* harmony import */ var _lumino_coreutils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @lumino/coreutils */ "webpack/sharing/consume/default/@lumino/coreutils");
/* harmony import */ var _lumino_coreutils__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_lumino_coreutils__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _lumino_signaling__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @lumino/signaling */ "webpack/sharing/consume/default/@lumino/signaling");
/* harmony import */ var _lumino_signaling__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_lumino_signaling__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! react */ "webpack/sharing/consume/default/react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! react-dom */ "webpack/sharing/consume/default/react-dom");
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var _style_debug_bad_svg__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../../style/debug/bad.svg */ "./node_modules/@jupyterlab/ui-components/style/debug/bad.svg");
/* harmony import */ var _style_debug_blank_svg__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../../style/debug/blank.svg */ "./node_modules/@jupyterlab/ui-components/style/debug/blank.svg");
/* harmony import */ var _style_icons_toolbar_refresh_svg__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../../style/icons/toolbar/refresh.svg */ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/refresh.svg");
/* harmony import */ var _style__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ../style */ "./node_modules/@jupyterlab/ui-components/lib/style/icon.js");
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ../utils */ "./node_modules/@jupyterlab/ui-components/lib/utils.js");
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
var __rest = (undefined && undefined.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};









class LabIcon {
    /** *********
     * members *
     ***********/
    constructor({ name, svgstr, render, unrender, _loading = false }) {
        this._props = {};
        this._svgReplaced = new _lumino_signaling__WEBPACK_IMPORTED_MODULE_1__.Signal(this);
        /**
         * Cache for svg parsing intermediates
         *   - undefined: the cache has not yet been populated
         *   - null: a valid, but empty, value
         */
        this._svgElement = undefined;
        this._svgInnerHTML = undefined;
        this._svgReactAttrs = undefined;
        if (!(name && svgstr)) {
            // sanity check failed
            console.error(`When defining a new LabIcon, name and svgstr must both be non-empty strings. name: ${name}, svgstr: ${svgstr}`);
            return badIcon;
        }
        // currently this needs to be set early, before checks for existing icons
        this._loading = _loading;
        // check to see if this is a redefinition of an existing icon
        if (LabIcon._instances.has(name)) {
            // fetch the existing icon, replace its svg, then return it
            const icon = LabIcon._instances.get(name);
            if (this._loading) {
                // replace the placeholder svg in icon
                icon.svgstr = svgstr;
                this._loading = false;
                return icon;
            }
            else {
                // already loaded icon svg exists; replace it and warn
                if (LabIcon._debug) {
                    console.warn(`Redefining previously loaded icon svgstr. name: ${name}, svgstrOld: ${icon.svgstr}, svgstr: ${svgstr}`);
                }
                icon.svgstr = svgstr;
                return icon;
            }
        }
        this.name = name;
        this.react = this._initReact(name);
        this.svgstr = svgstr;
        // setup custom render/unrender methods, if passed in
        this._initRender({ render, unrender });
        LabIcon._instances.set(this.name, this);
    }
    /** *********
     * statics *
     ***********/
    /**
     * Remove any rendered icon from the element that contains it
     *
     * @param container - a DOM node into which an icon was
     * previously rendered
     *
     * @returns the cleaned container
     */
    static remove(container) {
        // clean up all children
        while (container.firstChild) {
            container.firstChild.remove();
        }
        // remove all classes
        container.className = '';
        return container;
    }
    /**
     * Resolve an icon name or a {name, svgstr} pair into an
     * actual LabIcon.
     *
     * @param icon - either a string with the name of an existing icon
     * or an object with {name: string, svgstr: string} fields.
     *
     * @returns a LabIcon instance
     */
    static resolve({ icon }) {
        if (icon instanceof LabIcon) {
            // icon already is a LabIcon; nothing to do here
            return icon;
        }
        if (typeof icon === 'string') {
            // do a dynamic lookup of existing icon by name
            const resolved = LabIcon._instances.get(icon);
            if (resolved) {
                return resolved;
            }
            // lookup failed
            if (LabIcon._debug) {
                // fail noisily
                console.warn(`Lookup failed for icon, creating loading icon. icon: ${icon}`);
            }
            // no matching icon currently registered, create a new loading icon
            // TODO: find better icon (maybe animate?) for loading icon
            return new LabIcon({ name: icon, svgstr: _style_icons_toolbar_refresh_svg__WEBPACK_IMPORTED_MODULE_6__["default"], _loading: true });
        }
        // icon was provided as a non-LabIcon {name, svgstr} pair, communicating
        // an intention to create a new icon
        return new LabIcon(icon);
    }
    /**
     * Resolve an icon name or a {name, svgstr} pair into a DOM element.
     * If icon arg is undefined, the function will fall back to trying to render
     * the icon as a CSS background image, via the iconClass arg.
     * If both icon and iconClass are undefined, this function will return
     * an empty div.
     *
     * @param icon - optional, either a string with the name of an existing icon
     * or an object with {name: string, svgstr: string} fields
     *
     * @param iconClass - optional, if the icon arg is not set, the iconClass arg
     * should be a CSS class associated with an existing CSS background-image
     *
     * @deprecated fallback - don't use, optional, a LabIcon instance that will
     * be used if neither icon nor iconClass are defined
     *
     * @param props - any additional args are passed though to the element method
     * of the resolved icon on render
     *
     * @returns a DOM node with the resolved icon rendered into it
     */
    static resolveElement(_a) {
        var { icon, iconClass, fallback } = _a, props = __rest(_a, ["icon", "iconClass", "fallback"]);
        if (!Private.isResolvable(icon)) {
            if (!iconClass && fallback) {
                // if neither icon nor iconClass are defined/resolvable, use fallback
                return fallback.element(props);
            }
            // set the icon's class to iconClass plus props.className
            props.className = (0,_utils__WEBPACK_IMPORTED_MODULE_7__.classes)(iconClass, props.className);
            // render icon as css background image, assuming one is set on iconClass
            return Private.blankElement(props);
        }
        return LabIcon.resolve({ icon }).element(props);
    }
    /**
     * Resolve an icon name or a {name, svgstr} pair into a React component.
     * If icon arg is undefined, the function will fall back to trying to render
     * the icon as a CSS background image, via the iconClass arg.
     * If both icon and iconClass are undefined, the returned component
     * will simply render an empty div.
     *
     * @param icon - optional, either a string with the name of an existing icon
     * or an object with {name: string, svgstr: string} fields
     *
     * @param iconClass - optional, if the icon arg is not set, the iconClass arg
     * should be a CSS class associated with an existing CSS background-image
     *
     * @deprecated fallback - don't use, optional, a LabIcon instance that will
     * be used if neither icon nor iconClass are defined
     *
     * @param props - any additional args are passed though to the React component
     * of the resolved icon on render
     *
     * @returns a React component that will render the resolved icon
     */
    static resolveReact(_a) {
        var { icon, iconClass, fallback } = _a, props = __rest(_a, ["icon", "iconClass", "fallback"]);
        if (!Private.isResolvable(icon)) {
            if (!iconClass && fallback) {
                // if neither icon nor iconClass are defined/resolvable, use fallback
                return react__WEBPACK_IMPORTED_MODULE_2___default().createElement(fallback.react, Object.assign({}, props));
            }
            // set the icon's class to iconClass plus props.className
            props.className = (0,_utils__WEBPACK_IMPORTED_MODULE_7__.classes)(iconClass, props.className);
            // render icon as css background image, assuming one is set on iconClass
            return react__WEBPACK_IMPORTED_MODULE_2___default().createElement(Private.blankReact, Object.assign({}, props));
        }
        const resolved = LabIcon.resolve({ icon });
        return react__WEBPACK_IMPORTED_MODULE_2___default().createElement(resolved.react, Object.assign({}, props));
    }
    /**
     * Resolve a {name, svgstr} pair into an actual svg node.
     */
    static resolveSvg({ name, svgstr }) {
        const svgDoc = new DOMParser().parseFromString(Private.svgstrShim(svgstr), 'image/svg+xml');
        const svgError = svgDoc.querySelector('parsererror');
        // structure of error element varies by browser, search at top level
        if (svgError) {
            // parse failed, svgElement will be an error box
            const errmsg = `SVG HTML was malformed for LabIcon instance.\nname: ${name}, svgstr: ${svgstr}`;
            if (LabIcon._debug) {
                // fail noisily, render the error box
                console.error(errmsg);
                return svgError;
            }
            else {
                // bad svg is always a real error, fail silently but warn
                console.warn(errmsg);
                return null;
            }
        }
        else {
            // parse succeeded
            return svgDoc.documentElement;
        }
    }
    /**
     * Toggle icon debug from off-to-on, or vice-versa.
     *
     * @param debug - optional boolean to force debug on or off
     */
    static toggleDebug(debug) {
        LabIcon._debug = debug !== null && debug !== void 0 ? debug : !LabIcon._debug;
    }
    /**
     * Get a view of this icon that is bound to the specified icon/style props
     *
     * @param optional icon/style props (same as args for .element
     * and .react methods). These will be bound to the resulting view
     *
     * @returns a view of this LabIcon instance
     */
    bindprops(props) {
        const view = Object.create(this);
        view._props = props;
        view.react = view._initReact(view.name + '_bind');
        return view;
    }
    /**
     * Create an icon as a DOM element
     *
     * @param className - a string that will be used as the class
     * of the container element. Overrides any existing class
     *
     * @param container - a preexisting DOM element that
     * will be used as the container for the svg element
     *
     * @param label - text that will be displayed adjacent
     * to the icon
     *
     * @param title - a tooltip for the icon
     *
     * @param tag - if container is not explicitly
     * provided, this tag will be used when creating the container
     *
     * @param stylesheet - optional string naming a builtin icon
     * stylesheet, for example 'menuItem' or `statusBar`. Can also be an
     * object defining a custom icon stylesheet, or a list of builtin
     * stylesheet names and/or custom stylesheet objects. If array,
     * the given stylesheets will be merged.
     *
     *   See @jupyterlab/ui-components/src/style/icon.ts for details
     *
     * @param elementPosition - optional position for the inner svg element
     *
     * @param elementSize - optional size for the inner svg element.
     * Set to 'normal' to get a standard 16px x 16px icon
     *
     * @param ...elementCSS - all additional args are treated as
     * overrides for the CSS props applied to the inner svg element
     *
     * @returns A DOM element that contains an (inline) svg element
     * that displays an icon
     */
    element(props = {}) {
        var _a;
        let _b = Object.assign(Object.assign({}, this._props), props), { className, container, label, title, tag = 'div' } = _b, styleProps = __rest(_b, ["className", "container", "label", "title", "tag"]);
        // check if icon element is already set
        const maybeSvgElement = container === null || container === void 0 ? void 0 : container.firstChild;
        if (((_a = maybeSvgElement === null || maybeSvgElement === void 0 ? void 0 : maybeSvgElement.dataset) === null || _a === void 0 ? void 0 : _a.iconId) === this._uuid) {
            // return the existing icon element
            return maybeSvgElement;
        }
        // ensure that svg html is valid
        if (!this.svgElement) {
            // bail if failing silently, return blank element
            return document.createElement('div');
        }
        let returnSvgElement = true;
        if (container) {
            // take ownership by removing any existing children
            while (container.firstChild) {
                container.firstChild.remove();
            }
        }
        else {
            // create a container if needed
            container = document.createElement(tag);
            returnSvgElement = false;
        }
        if (label != null) {
            container.textContent = label;
        }
        Private.initContainer({ container, className, styleProps, title });
        // add the svg node to the container
        const svgElement = this.svgElement.cloneNode(true);
        container.appendChild(svgElement);
        return returnSvgElement ? svgElement : container;
    }
    render(container, options) {
        var _a;
        let label = (_a = options === null || options === void 0 ? void 0 : options.children) === null || _a === void 0 ? void 0 : _a[0];
        // narrow type of label
        if (typeof label !== 'string') {
            label = undefined;
        }
        this.element(Object.assign({ container,
            label }, options === null || options === void 0 ? void 0 : options.props));
    }
    get svgElement() {
        if (this._svgElement === undefined) {
            this._svgElement = this._initSvg({ uuid: this._uuid });
        }
        return this._svgElement;
    }
    get svgInnerHTML() {
        if (this._svgInnerHTML === undefined) {
            if (this.svgElement === null) {
                // the svg element resolved to null, mark this null too
                this._svgInnerHTML = null;
            }
            else {
                this._svgInnerHTML = this.svgElement.innerHTML;
            }
        }
        return this._svgInnerHTML;
    }
    get svgReactAttrs() {
        if (this._svgReactAttrs === undefined) {
            if (this.svgElement === null) {
                // the svg element resolved to null, mark this null too
                this._svgReactAttrs = null;
            }
            else {
                this._svgReactAttrs = (0,_utils__WEBPACK_IMPORTED_MODULE_7__.getReactAttrs)(this.svgElement, {
                    ignore: ['data-icon-id']
                });
            }
        }
        return this._svgReactAttrs;
    }
    get svgstr() {
        return this._svgstr;
    }
    set svgstr(svgstr) {
        this._svgstr = svgstr;
        // associate a new unique id with this particular svgstr
        const uuid = _lumino_coreutils__WEBPACK_IMPORTED_MODULE_0__.UUID.uuid4();
        const uuidOld = this._uuid;
        this._uuid = uuid;
        // empty the svg parsing intermediates cache
        this._svgElement = undefined;
        this._svgInnerHTML = undefined;
        this._svgReactAttrs = undefined;
        // update icon elements created using .element method
        document
            .querySelectorAll(`[data-icon-id="${uuidOld}"]`)
            .forEach(oldSvgElement => {
            if (this.svgElement) {
                oldSvgElement.replaceWith(this.svgElement.cloneNode(true));
            }
        });
        // trigger update of icon elements created using other methods
        this._svgReplaced.emit();
    }
    _initReact(displayName) {
        const component = react__WEBPACK_IMPORTED_MODULE_2___default().forwardRef((props = {}, ref) => {
            const _a = Object.assign(Object.assign({}, this._props), props), { className, container, label, title, tag = 'div' } = _a, styleProps = __rest(_a, ["className", "container", "label", "title", "tag"]);
            // set up component state via useState hook
            const [, setId] = react__WEBPACK_IMPORTED_MODULE_2___default().useState(this._uuid);
            // subscribe to svg replacement via useEffect hook
            react__WEBPACK_IMPORTED_MODULE_2___default().useEffect(() => {
                const onSvgReplaced = () => {
                    setId(this._uuid);
                };
                this._svgReplaced.connect(onSvgReplaced);
                // specify cleanup callback as hook return
                return () => {
                    this._svgReplaced.disconnect(onSvgReplaced);
                };
            });
            // make it so that tag can be used as a jsx component
            const Tag = tag;
            // ensure that svg html is valid
            if (!(this.svgInnerHTML && this.svgReactAttrs)) {
                // bail if failing silently
                return react__WEBPACK_IMPORTED_MODULE_2___default().createElement((react__WEBPACK_IMPORTED_MODULE_2___default().Fragment), null);
            }
            const svgComponent = (react__WEBPACK_IMPORTED_MODULE_2___default().createElement("svg", Object.assign({}, this.svgReactAttrs, { dangerouslySetInnerHTML: { __html: this.svgInnerHTML }, ref: ref })));
            if (container) {
                Private.initContainer({ container, className, styleProps, title });
                return (react__WEBPACK_IMPORTED_MODULE_2___default().createElement((react__WEBPACK_IMPORTED_MODULE_2___default().Fragment), null,
                    svgComponent,
                    label));
            }
            else {
                return (react__WEBPACK_IMPORTED_MODULE_2___default().createElement(Tag, { className: (0,_utils__WEBPACK_IMPORTED_MODULE_7__.classes)(className, _style__WEBPACK_IMPORTED_MODULE_8__.LabIconStyle.styleClass(styleProps)) },
                    svgComponent,
                    label));
            }
        });
        component.displayName = `LabIcon_${displayName}`;
        return component;
    }
    _initRender({ render, unrender }) {
        if (render) {
            this.render = render;
            if (unrender) {
                this.unrender = unrender;
            }
        }
        else if (unrender) {
            console.warn('In _initRender, ignoring unrender arg since render is undefined');
        }
    }
    _initSvg({ title, uuid } = {}) {
        const svgElement = LabIcon.resolveSvg(this);
        if (!svgElement) {
            // bail on null svg element
            return svgElement;
        }
        if (svgElement.tagName !== 'parsererror') {
            // svgElement is an actual svg node, augment it
            svgElement.dataset.icon = this.name;
            if (uuid) {
                svgElement.dataset.iconId = uuid;
            }
            if (title) {
                Private.setTitleSvg(svgElement, title);
            }
        }
        return svgElement;
    }
}
LabIcon._debug = false;
LabIcon._instances = new Map();
var Private;
(function (Private) {
    function blankElement(_a) {
        var { className = '', container, label, title, tag = 'div' } = _a, styleProps = __rest(_a, ["className", "container", "label", "title", "tag"]);
        if ((container === null || container === void 0 ? void 0 : container.className) === className) {
            // nothing needs doing, return the icon node
            return container;
        }
        if (container) {
            // take ownership by removing any existing children
            while (container.firstChild) {
                container.firstChild.remove();
            }
        }
        else {
            // create a container if needed
            container = document.createElement(tag);
        }
        if (label != null) {
            container.textContent = label;
        }
        Private.initContainer({ container, className, styleProps, title });
        return container;
    }
    Private.blankElement = blankElement;
    Private.blankReact = react__WEBPACK_IMPORTED_MODULE_2___default().forwardRef((_a, ref) => {
        var { className = '', container, label, title, tag = 'div' } = _a, styleProps = __rest(_a, ["className", "container", "label", "title", "tag"]);
        // make it so that tag can be used as a jsx component
        const Tag = tag;
        if (container) {
            initContainer({ container, className, styleProps, title });
            return react__WEBPACK_IMPORTED_MODULE_2___default().createElement((react__WEBPACK_IMPORTED_MODULE_2___default().Fragment), null);
        }
        else {
            // if ref is defined, we create a blank svg node and point ref to it
            return (react__WEBPACK_IMPORTED_MODULE_2___default().createElement(Tag, { className: (0,_utils__WEBPACK_IMPORTED_MODULE_7__.classes)(className, _style__WEBPACK_IMPORTED_MODULE_8__.LabIconStyle.styleClass(styleProps)) },
                ref && blankIcon.react({ ref }),
                label));
        }
    });
    Private.blankReact.displayName = 'BlankReact';
    function initContainer({ container, className, styleProps, title }) {
        if (title != null) {
            container.title = title;
        }
        const styleClass = _style__WEBPACK_IMPORTED_MODULE_8__.LabIconStyle.styleClass(styleProps);
        if (className != null) {
            // override the container class with explicitly passed-in class + style class
            const classResolved = (0,_utils__WEBPACK_IMPORTED_MODULE_7__.classes)(className, styleClass);
            container.className = classResolved;
            return classResolved;
        }
        else if (styleClass) {
            // add the style class to the container class
            container.classList.add(styleClass);
            return styleClass;
        }
        else {
            return '';
        }
    }
    Private.initContainer = initContainer;
    function isResolvable(icon) {
        return !!(icon &&
            (typeof icon === 'string' ||
                (icon.name && icon.svgstr)));
    }
    Private.isResolvable = isResolvable;
    function setTitleSvg(svgNode, title) {
        // add a title node to the top level svg node
        const titleNodes = svgNode.getElementsByTagName('title');
        if (titleNodes.length) {
            titleNodes[0].textContent = title;
        }
        else {
            const titleNode = document.createElement('title');
            titleNode.textContent = title;
            svgNode.appendChild(titleNode);
        }
    }
    Private.setTitleSvg = setTitleSvg;
    /**
     * A shim for svgstrs loaded using any loader other than raw-loader.
     * This function assumes that svgstr will look like one of:
     *
     * - the raw contents of an .svg file:
     *   <svg...</svg>
     *
     * - a data URL:
     *   data:[<mediatype>][;base64],<svg...</svg>
     *
     * See https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/Data_URIs
     */
    function svgstrShim(svgstr, strict = true) {
        // decode any uri escaping, condense leading/lagging whitespace,
        // then match to raw svg string
        const [, base64, raw] = decodeURIComponent(svgstr)
            .replace(/>\s*\n\s*</g, '><')
            .replace(/\s*\n\s*/g, ' ')
            .match(strict
            ? // match based on data url schema
                /^(?:data:.*?(;base64)?,)?(.*)/
            : // match based on open of svg tag
                /(?:(base64).*)?(<svg.*)/);
        // decode from base64, if needed
        return base64 ? atob(raw) : raw;
    }
    Private.svgstrShim = svgstrShim;
    /**
     * TODO: figure out story for independent Renderers.
     * Base implementation of IRenderer.
     */
    class Renderer {
        constructor(_icon, _rendererOptions) {
            this._icon = _icon;
            this._rendererOptions = _rendererOptions;
        }
        // eslint-disable-next-line
        render(container, options) { }
    }
    Private.Renderer = Renderer;
    /**
     * TODO: figure out story for independent Renderers.
     * Implementation of IRenderer that creates the icon svg node
     * as a DOM element.
     */
    class ElementRenderer extends Renderer {
        render(container, options) {
            var _a, _b;
            let label = (_a = options === null || options === void 0 ? void 0 : options.children) === null || _a === void 0 ? void 0 : _a[0];
            // narrow type of label
            if (typeof label !== 'string') {
                label = undefined;
            }
            this._icon.element(Object.assign(Object.assign({ container,
                label }, (_b = this._rendererOptions) === null || _b === void 0 ? void 0 : _b.props), options === null || options === void 0 ? void 0 : options.props));
        }
    }
    Private.ElementRenderer = ElementRenderer;
    /**
     * TODO: figure out story for independent Renderers.
     * Implementation of IRenderer that creates the icon svg node
     * as a React component.
     */
    class ReactRenderer extends Renderer {
        render(container, options) {
            var _a, _b;
            let label = (_a = options === null || options === void 0 ? void 0 : options.children) === null || _a === void 0 ? void 0 : _a[0];
            // narrow type of label
            if (typeof label !== 'string') {
                label = undefined;
            }
            react_dom__WEBPACK_IMPORTED_MODULE_3___default().render(react__WEBPACK_IMPORTED_MODULE_2___default().createElement(this._icon.react, Object.assign({ container: container, label: label }, Object.assign(Object.assign({}, (_b = this._rendererOptions) === null || _b === void 0 ? void 0 : _b.props), options === null || options === void 0 ? void 0 : options.props))), container);
        }
        unrender(container) {
            react_dom__WEBPACK_IMPORTED_MODULE_3___default().unmountComponentAtNode(container);
        }
    }
    Private.ReactRenderer = ReactRenderer;
})(Private || (Private = {}));
// need to be at the bottom since constructor depends on Private
const badIcon = new LabIcon({
    name: 'ui-components:bad',
    svgstr: _style_debug_bad_svg__WEBPACK_IMPORTED_MODULE_4__["default"]
});
const blankIcon = new LabIcon({
    name: 'ui-components:blank',
    svgstr: _style_debug_blank_svg__WEBPACK_IMPORTED_MODULE_5__["default"]
});
//# sourceMappingURL=labicon.js.map

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/lib/style/icon.js":
/*!******************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/lib/style/icon.js ***!
  \******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "LabIconStyle": () => (/* binding */ LabIconStyle)
/* harmony export */ });
/* harmony import */ var typestyle_lib__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! typestyle/lib */ "./node_modules/typestyle/lib/index.js");
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
var __rest = (undefined && undefined.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};

var LabIconStyle;
(function (LabIconStyle) {
    /**
     * The builtin stylesheets
     */
    const builtinSheets = {
        breadCrumb: {
            container: {
                $nest: {
                    // `&` will be substituted for the generated classname (interpolation)
                    '&:first-child svg': {
                        bottom: '1px',
                        marginLeft: '0px',
                        position: 'relative'
                    },
                    '&:hover': {
                        backgroundColor: 'var(--jp-layout-color2)'
                    },
                    ['.jp-mod-dropTarget&']: {
                        backgroundColor: 'var(--jp-brand-color2)',
                        opacity: 0.7
                    }
                }
            },
            element: {
                borderRadius: 'var(--jp-border-radius)',
                cursor: 'pointer',
                margin: '0px 2px',
                padding: '0px 2px',
                height: '16px',
                width: '16px',
                verticalAlign: 'middle'
            }
        },
        commandPaletteHeader: {
            container: {
                height: '14px',
                margin: '0 14px 0 auto'
            },
            element: {
                height: '14px',
                width: '14px'
            },
            options: {
                elementPosition: 'center'
            }
        },
        commandPaletteItem: {
            element: {
                height: '16px',
                width: '16px'
            },
            options: {
                elementPosition: 'center'
            }
        },
        launcherCard: {
            container: {
                height: '52px',
                width: '52px'
            },
            element: {
                height: '52px',
                width: '52px'
            },
            options: {
                elementPosition: 'center'
            }
        },
        launcherSection: {
            container: {
                boxSizing: 'border-box',
                marginRight: '12px',
                height: '32px',
                width: '32px'
            },
            element: {
                height: '32px',
                width: '32px'
            },
            options: {
                elementPosition: 'center'
            }
        },
        listing: {
            container: {
                flex: '0 0 20px',
                marginRight: '4px',
                position: 'relative'
            },
            element: {
                height: '16px',
                width: '16px'
            },
            options: {
                elementPosition: 'center'
            }
        },
        listingHeaderItem: {
            container: {
                display: 'inline',
                height: '16px',
                width: '16px'
            },
            element: {
                height: 'auto',
                margin: '-2px 0 0 0',
                width: '20px'
            },
            options: {
                elementPosition: 'center'
            }
        },
        mainAreaTab: {
            container: {
                $nest: {
                    '.lm-DockPanel-tabBar &': {
                        marginRight: '4px'
                    },
                    '#tab-manager &': {
                        marginRight: '2px',
                        position: 'relative'
                    }
                }
            },
            element: {
                $nest: {
                    '.lm-DockPanel-tabBar &': {
                        height: '14px',
                        width: '14px'
                    },
                    '#tab-manager &': {
                        height: '16px',
                        width: '16px'
                    }
                }
            },
            options: {
                elementPosition: 'center'
            }
        },
        menuItem: {
            container: {
                display: 'inline-block',
                verticalAlign: 'middle'
            },
            element: {
                height: '16px',
                width: '16px'
            },
            options: {
                elementPosition: 'center'
            }
        },
        runningItem: {
            container: {
                margin: '0px 4px 0px 4px'
            },
            element: {
                height: '16px',
                width: '16px'
            },
            options: {
                elementPosition: 'center'
            }
        },
        select: {
            container: {
                pointerEvents: 'none'
            },
            element: {
                position: 'absolute',
                height: 'auto',
                width: '16px'
            }
        },
        settingsEditor: {
            container: {
                display: 'flex',
                flex: '0 0 20px',
                margin: '0 3px 0 0',
                position: 'relative',
                height: '20px',
                width: '20px'
            },
            element: {
                height: '16px',
                width: '16px'
            },
            options: {
                elementPosition: 'center'
            }
        },
        sideBar: {
            container: {
                // `&` will be substituted for the generated classname (interpolation)
                $nest: {
                    // left sidebar tab divs
                    '.jp-SideBar.jp-mod-left .lm-TabBar-tab &': {
                        transform: 'rotate(90deg)'
                    },
                    // left sidebar currently selected tab div
                    '.jp-SideBar.jp-mod-left .lm-TabBar-tab.lm-mod-current &': {
                        transform: 'rotate(90deg)\n' +
                            '    translate(\n' +
                            '      calc(-0.5 * var(--jp-border-width)),\n' +
                            '      calc(-0.5 * var(--jp-border-width))\n' +
                            '    )'
                    },
                    // right sidebar tab divs
                    '.jp-SideBar.jp-mod-right .lm-TabBar-tab &': {
                        transform: 'rotate(-90deg)'
                    },
                    // right sidebar currently selected tab div
                    '.jp-SideBar.jp-mod-right .lm-TabBar-tab.lm-mod-current &': {
                        transform: 'rotate(-90deg)\n' +
                            '    translate(\n' +
                            '      calc(0.5 * var(--jp-border-width)),\n' +
                            '      calc(-0.5 * var(--jp-border-width))\n' +
                            '    )'
                    }
                }
            },
            element: {
                height: 'auto',
                width: '20px'
            },
            options: {
                elementPosition: 'center'
            }
        },
        splash: {
            container: {
                animation: '0.3s fade-in linear forwards',
                height: '100%',
                width: '100%',
                zIndex: 1
            },
            element: {
                // width no height
                width: '100px'
            },
            options: {
                elementPosition: 'center'
            }
        },
        statusBar: {
            element: {
                left: '0px',
                top: '0px',
                height: '18px',
                width: '20px',
                position: 'relative'
            }
        },
        toolbarButton: {
            container: {
                display: 'inline-block',
                verticalAlign: 'middle'
            },
            element: {
                height: '16px',
                width: '16px'
            },
            options: {
                elementPosition: 'center'
            }
        }
    };
    function _elementPositionFactory(extra) {
        return {
            container: {
                alignItems: 'center',
                display: 'flex'
            },
            element: Object.assign({ display: 'block' }, extra)
        };
    }
    /**
     * Styles to help with positioning
     */
    const positionSheets = {
        center: _elementPositionFactory({ margin: '0 auto', width: '100%' }),
        top: _elementPositionFactory({ margin: '0 0 auto 0' }),
        right: _elementPositionFactory({ margin: '0 0 0 auto' }),
        bottom: _elementPositionFactory({ margin: 'auto 0 0 0' }),
        left: _elementPositionFactory({ margin: '0 auto 0 0' }),
        'top right': _elementPositionFactory({ margin: '0 0 auto auto' }),
        'bottom right': _elementPositionFactory({ margin: 'auto 0 0 auto' }),
        'bottom left': _elementPositionFactory({ margin: 'auto auto 0 0' }),
        'top left': _elementPositionFactory({ margin: '0 auto 0 auto' })
    };
    function _elementSizeFactory(size) {
        return {
            element: {
                height: size,
                width: size
            }
        };
    }
    /**
     * sheets that establish some default sizes
     */
    const sizeSheets = {
        small: _elementSizeFactory('14px'),
        normal: _elementSizeFactory('16px'),
        large: _elementSizeFactory('20px'),
        xlarge: _elementSizeFactory('24px')
    };
    /**
     * Merge two or more icon sheets into a single "pure"
     * icon style (ie collections of CSS props only)
     */
    function mergeSheets(sheets) {
        return {
            container: Object.assign({}, ...sheets.map(s => s.container)),
            element: Object.assign({}, ...sheets.map(s => s.element))
        };
    }
    /**
     * Resolve one or more stylesheets that may just be a string naming
     * one of the builtin stylesheets to an array of proper ISheet objects
     */
    function resolveSheet(stylesheet) {
        if (!stylesheet) {
            return [];
        }
        if (!Array.isArray(stylesheet)) {
            // wrap in array
            stylesheet = [stylesheet];
        }
        return stylesheet.map(k => (typeof k === 'string' ? builtinSheets[k] : k));
    }
    /**
     * Resolve and merge multiple icon stylesheets
     */
    function applySheetOptions(sheets) {
        const options = Object.assign({}, ...sheets.map(s => s.options));
        if (options.elementPosition) {
            sheets.unshift(positionSheets[options.elementPosition]);
        }
        if (options.elementSize) {
            sheets.unshift(sizeSheets[options.elementSize]);
        }
        return mergeSheets(sheets);
    }
    /**
     * Resolve a pure icon stylesheet into a typestyle class
     */
    function resolveStyleClass(stylesheet) {
        var _a;
        return (0,typestyle_lib__WEBPACK_IMPORTED_MODULE_0__.style)(Object.assign(Object.assign({}, stylesheet.container), { $nest: Object.assign(Object.assign({}, (_a = stylesheet.container) === null || _a === void 0 ? void 0 : _a.$nest), { ['svg']: stylesheet.element }) }));
    }
    // cache style classes for builtin stylesheets
    const _styleClassCache = new Map();
    /**
     * Get a typestyle class, given a set of icon styling props
     */
    function styleClass(props) {
        if (!props || Object.keys(props).length === 0) {
            // props is empty
            return '';
        }
        let { elementPosition, elementSize, stylesheet, kind, justify } = props, elementCSS = __rest(props, ["elementPosition", "elementSize", "stylesheet", "kind", "justify"]);
        // DEPRECATED: alias kind => stylesheet
        if (!stylesheet) {
            stylesheet = kind;
        }
        // DEPRECATED: alias justify => elementPosition
        if (!elementPosition) {
            elementPosition = justify;
        }
        // add option args with defined values to overrides
        const options = Object.assign(Object.assign({}, (elementPosition && { elementPosition })), (elementSize && { elementSize }));
        // try to look up the style class in the cache
        const cacheable = typeof stylesheet === 'string' && Object.keys(elementCSS).length === 0;
        const cacheKey = cacheable
            ? [stylesheet, elementPosition, elementSize].join(',')
            : '';
        if (cacheable && _styleClassCache.has(cacheKey)) {
            return _styleClassCache.get(cacheKey);
        }
        // resolve kind to an array of sheets, then stick overrides on the end
        const sheets = resolveSheet(stylesheet);
        sheets.push({ element: elementCSS, options });
        // apply style options/merge sheets, then convert to typestyle class
        const cls = resolveStyleClass(applySheetOptions(sheets));
        if (cacheable) {
            // store in cache for later reuse
            _styleClassCache.set(cacheKey, cls);
        }
        return cls;
    }
    LabIconStyle.styleClass = styleClass;
})(LabIconStyle || (LabIconStyle = {}));
//# sourceMappingURL=icon.js.map

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/lib/utils.js":
/*!*************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/lib/utils.js ***!
  \*************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "classes": () => (/* binding */ classes),
/* harmony export */   "classesDedupe": () => (/* binding */ classesDedupe),
/* harmony export */   "getReactAttrs": () => (/* binding */ getReactAttrs)
/* harmony export */ });
/* harmony import */ var _jupyterlab_coreutils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @jupyterlab/coreutils */ "webpack/sharing/consume/default/@jupyterlab/coreutils");
/* harmony import */ var _jupyterlab_coreutils__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_jupyterlab_coreutils__WEBPACK_IMPORTED_MODULE_0__);
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.

/**
 * Inner works of class combining functions
 */
function _classes(classes) {
    return classes
        .map(c => c && typeof c === 'object'
        ? Object.keys(c).map(key => !!c[key] && key)
        : typeof c === 'string'
            ? c.split(/\s+/)
            : [])
        .reduce((flattened, c) => flattened.concat(c), [])
        .filter(c => !!c);
}
/**
 * Combines classNames.
 *
 * @param classes - A list of classNames
 *
 * @returns A single string with the combined className
 */
function classes(...classes) {
    return _classes(classes).join(' ');
}
/**
 * Combines classNames. Removes all duplicates
 *
 * @param classes - A list of classNames
 *
 * @returns A single string with the combined className
 */
function classesDedupe(...classes) {
    return [...new Set(_classes(classes))].join(' ');
}
/**
 * Translates the attributes of a DOM element into attributes that can
 * be understood by React. Currently not comprehensive, we will add special
 * cases as they become relevant.
 *
 * @param elem - A DOM element
 *
 * @param ignore - An optional list of attribute names to ignore
 *
 * @returns An object with key:value pairs that are the React-friendly
 * translation of elem's attributes
 */
function getReactAttrs(elem, { ignore = [] } = {}) {
    return elem.getAttributeNames().reduce((d, name) => {
        if (name === 'style' || ignore.includes(name)) {
            void 0;
        }
        else if (name.startsWith('data')) {
            d[name] = elem.getAttribute(name);
        }
        else {
            d[_jupyterlab_coreutils__WEBPACK_IMPORTED_MODULE_0__.Text.camelCase(name)] = elem.getAttribute(name);
        }
        return d;
    }, {});
}
//# sourceMappingURL=utils.js.map

/***/ }),

/***/ "./node_modules/@lumino/polling/dist/index.es6.js":
/*!********************************************************!*\
  !*** ./node_modules/@lumino/polling/dist/index.es6.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Debouncer": () => (/* binding */ Debouncer),
/* harmony export */   "Poll": () => (/* binding */ Poll),
/* harmony export */   "RateLimiter": () => (/* binding */ RateLimiter),
/* harmony export */   "Throttler": () => (/* binding */ Throttler)
/* harmony export */ });
/* harmony import */ var _lumino_coreutils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @lumino/coreutils */ "webpack/sharing/consume/default/@lumino/coreutils");
/* harmony import */ var _lumino_coreutils__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_lumino_coreutils__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _lumino_signaling__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @lumino/signaling */ "webpack/sharing/consume/default/@lumino/signaling");
/* harmony import */ var _lumino_signaling__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_lumino_signaling__WEBPACK_IMPORTED_MODULE_1__);



/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    if (typeof b !== "function" && b !== null)
        throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

// Copyright (c) Jupyter Development Team.
/**
 * A function to defer an action immediately.
 */
var defer = typeof requestAnimationFrame === 'function'
    ? requestAnimationFrame
    : setImmediate;
/**
 * A function to cancel a deferred action.
 */
var cancel = typeof cancelAnimationFrame === 'function'
    ? cancelAnimationFrame
    : clearImmediate;
/**
 * A class that wraps an asynchronous function to poll at a regular interval
 * with exponential increases to the interval length if the poll fails.
 *
 * @typeparam T - The resolved type of the factory's promises.
 * Defaults to `any`.
 *
 * @typeparam U - The rejected type of the factory's promises.
 * Defaults to `any`.
 *
 * @typeparam V - An optional type to extend the phases supported by a poll.
 * Defaults to `standby`, which already exists in the `Phase` type.
 */
var Poll = /** @class */ (function () {
    /**
     * Instantiate a new poll with exponential backoff in case of failure.
     *
     * @param options - The poll instantiation options.
     */
    function Poll(options) {
        var _this = this;
        this._disposed = new _lumino_signaling__WEBPACK_IMPORTED_MODULE_1__.Signal(this);
        this._tick = new _lumino_coreutils__WEBPACK_IMPORTED_MODULE_0__.PromiseDelegate();
        this._ticked = new _lumino_signaling__WEBPACK_IMPORTED_MODULE_1__.Signal(this);
        this._timeout = -1;
        this._factory = options.factory;
        this._standby = options.standby || Private.DEFAULT_STANDBY;
        this._state = __assign(__assign({}, Private.DEFAULT_STATE), { timestamp: new Date().getTime() });
        // Normalize poll frequency `max` to be the greater of
        // default `max`, `options.frequency.max`, or `options.frequency.interval`.
        var frequency = options.frequency || {};
        var max = Math.max(frequency.interval || 0, frequency.max || 0, Private.DEFAULT_FREQUENCY.max);
        this.frequency = __assign(__assign(__assign({}, Private.DEFAULT_FREQUENCY), frequency), { max: max });
        this.name = options.name || Private.DEFAULT_NAME;
        if ('auto' in options ? options.auto : true) {
            defer(function () { return void _this.start(); });
        }
    }
    Object.defineProperty(Poll.prototype, "disposed", {
        /**
         * A signal emitted when the poll is disposed.
         */
        get: function () {
            return this._disposed;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Poll.prototype, "frequency", {
        /**
         * The polling frequency parameters.
         */
        get: function () {
            return this._frequency;
        },
        set: function (frequency) {
            if (this.isDisposed || _lumino_coreutils__WEBPACK_IMPORTED_MODULE_0__.JSONExt.deepEqual(frequency, this.frequency || {})) {
                return;
            }
            var backoff = frequency.backoff, interval = frequency.interval, max = frequency.max;
            interval = Math.round(interval);
            max = Math.round(max);
            if (typeof backoff === 'number' && backoff < 1) {
                throw new Error('Poll backoff growth factor must be at least 1');
            }
            if ((interval < 0 || interval > max) && interval !== Poll.NEVER) {
                throw new Error('Poll interval must be between 0 and max');
            }
            if (max > Poll.MAX_INTERVAL && max !== Poll.NEVER) {
                throw new Error("Max interval must be less than " + Poll.MAX_INTERVAL);
            }
            this._frequency = { backoff: backoff, interval: interval, max: max };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Poll.prototype, "isDisposed", {
        /**
         * Whether the poll is disposed.
         */
        get: function () {
            return this.state.phase === 'disposed';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Poll.prototype, "standby", {
        /**
         * Indicates when the poll switches to standby.
         */
        get: function () {
            return this._standby;
        },
        set: function (standby) {
            if (this.isDisposed || this.standby === standby) {
                return;
            }
            this._standby = standby;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Poll.prototype, "state", {
        /**
         * The poll state, which is the content of the current poll tick.
         */
        get: function () {
            return this._state;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Poll.prototype, "tick", {
        /**
         * A promise that resolves when the poll next ticks.
         */
        get: function () {
            return this._tick.promise;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Poll.prototype, "ticked", {
        /**
         * A signal emitted when the poll ticks and fires off a new request.
         */
        get: function () {
            return this._ticked;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Dispose the poll.
     */
    Poll.prototype.dispose = function () {
        if (this.isDisposed) {
            return;
        }
        this._state = __assign(__assign({}, Private.DISPOSED_STATE), { timestamp: new Date().getTime() });
        this._tick.promise.catch(function (_) { return undefined; });
        this._tick.reject(new Error("Poll (" + this.name + ") is disposed."));
        this._disposed.emit(undefined);
        _lumino_signaling__WEBPACK_IMPORTED_MODULE_1__.Signal.clearData(this);
    };
    /**
     * Refreshes the poll. Schedules `refreshed` tick if necessary.
     *
     * @returns A promise that resolves after tick is scheduled and never rejects.
     *
     * #### Notes
     * The returned promise resolves after the tick is scheduled, but before
     * the polling action is run. To wait until after the poll action executes,
     * await the `poll.tick` promise: `await poll.refresh(); await poll.tick;`
     */
    Poll.prototype.refresh = function () {
        return this.schedule({
            cancel: function (_a) {
                var phase = _a.phase;
                return phase === 'refreshed';
            },
            interval: Poll.IMMEDIATE,
            phase: 'refreshed'
        });
    };
    /**
     * Schedule the next poll tick.
     *
     * @param next - The next poll state data to schedule. Defaults to standby.
     *
     * @param next.cancel - Cancels state transition if function returns `true`.
     *
     * @returns A promise that resolves when the next poll state is active.
     *
     * #### Notes
     * This method is not meant to be invoked by user code typically. It is public
     * to allow poll instances to be composed into classes that schedule ticks.
     */
    Poll.prototype.schedule = function (next) {
        if (next === void 0) { next = {}; }
        return __awaiter(this, void 0, void 0, function () {
            var last, pending, scheduled, state, execute;
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (this.isDisposed) {
                            return [2 /*return*/];
                        }
                        // Check if the phase transition should be canceled.
                        if (next.cancel && next.cancel(this.state)) {
                            return [2 /*return*/];
                        }
                        last = this.state;
                        pending = this._tick;
                        scheduled = new _lumino_coreutils__WEBPACK_IMPORTED_MODULE_0__.PromiseDelegate();
                        state = __assign({ interval: this.frequency.interval, payload: null, phase: 'standby', timestamp: new Date().getTime() }, next);
                        this._state = state;
                        this._tick = scheduled;
                        // Clear the schedule if possible.
                        if (last.interval === Poll.IMMEDIATE) {
                            cancel(this._timeout);
                        }
                        else {
                            clearTimeout(this._timeout);
                        }
                        // Emit ticked signal, resolve pending promise, and await its settlement.
                        this._ticked.emit(this.state);
                        pending.resolve(this);
                        return [4 /*yield*/, pending.promise];
                    case 1:
                        _a.sent();
                        execute = function () {
                            if (_this.isDisposed || _this.tick !== scheduled.promise) {
                                return;
                            }
                            _this._execute();
                        };
                        this._timeout =
                            state.interval === Poll.IMMEDIATE
                                ? defer(execute)
                                : state.interval === Poll.NEVER
                                    ? -1
                                    : setTimeout(execute, state.interval);
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Starts the poll. Schedules `started` tick if necessary.
     *
     * @returns A promise that resolves after tick is scheduled and never rejects.
     */
    Poll.prototype.start = function () {
        return this.schedule({
            cancel: function (_a) {
                var phase = _a.phase;
                return phase !== 'constructed' && phase !== 'standby' && phase !== 'stopped';
            },
            interval: Poll.IMMEDIATE,
            phase: 'started'
        });
    };
    /**
     * Stops the poll. Schedules `stopped` tick if necessary.
     *
     * @returns A promise that resolves after tick is scheduled and never rejects.
     */
    Poll.prototype.stop = function () {
        return this.schedule({
            cancel: function (_a) {
                var phase = _a.phase;
                return phase === 'stopped';
            },
            interval: Poll.NEVER,
            phase: 'stopped'
        });
    };
    /**
     * Execute a new poll factory promise or stand by if necessary.
     */
    Poll.prototype._execute = function () {
        var _this = this;
        var standby = typeof this.standby === 'function' ? this.standby() : this.standby;
        standby =
            standby === 'never'
                ? false
                : standby === 'when-hidden'
                    ? !!(typeof document !== 'undefined' && document && document.hidden)
                    : standby;
        // If in standby mode schedule next tick without calling the factory.
        if (standby) {
            void this.schedule();
            return;
        }
        var pending = this.tick;
        this._factory(this.state)
            .then(function (resolved) {
            if (_this.isDisposed || _this.tick !== pending) {
                return;
            }
            void _this.schedule({
                payload: resolved,
                phase: _this.state.phase === 'rejected' ? 'reconnected' : 'resolved'
            });
        })
            .catch(function (rejected) {
            if (_this.isDisposed || _this.tick !== pending) {
                return;
            }
            void _this.schedule({
                interval: Private.sleep(_this.frequency, _this.state),
                payload: rejected,
                phase: 'rejected'
            });
        });
    };
    return Poll;
}());
/**
 * A namespace for `Poll` types, interfaces, and statics.
 */
(function (Poll) {
    /**
     * An interval value that indicates the poll should tick immediately.
     */
    Poll.IMMEDIATE = 0;
    /**
     * Delays are 32-bit integers in many browsers so intervals need to be capped.
     *
     * #### Notes
     * https://developer.mozilla.org/en-US/docs/Web/API/WindowOrWorkerGlobalScope/setTimeout#Maximum_delay_value
     */
    Poll.MAX_INTERVAL = 2147483647;
    /**
     * An interval value that indicates the poll should never tick.
     */
    Poll.NEVER = Infinity;
})(Poll || (Poll = {}));
/**
 * A namespace for private module data.
 */
var Private;
(function (Private) {
    /**
     * The default backoff growth rate if `backoff` is `true`.
     */
    Private.DEFAULT_BACKOFF = 3;
    /**
     * The default polling frequency.
     */
    Private.DEFAULT_FREQUENCY = {
        backoff: true,
        interval: 1000,
        max: 30 * 1000
    };
    /**
     * The default poll name.
     */
    Private.DEFAULT_NAME = 'unknown';
    /**
     * The default poll standby behavior.
     */
    Private.DEFAULT_STANDBY = 'when-hidden';
    /**
     * The first poll tick state's default values superseded in constructor.
     */
    Private.DEFAULT_STATE = {
        interval: Poll.NEVER,
        payload: null,
        phase: 'constructed',
        timestamp: new Date(0).getTime()
    };
    /**
     * The disposed tick state values.
     */
    Private.DISPOSED_STATE = {
        interval: Poll.NEVER,
        payload: null,
        phase: 'disposed',
        timestamp: new Date(0).getTime()
    };
    /**
     * Get a random integer between min and max, inclusive of both.
     *
     * #### Notes
     * From
     * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Math/random#Getting_a_random_integer_between_two_values_inclusive
     *
     * From the MDN page: It might be tempting to use Math.round() to accomplish
     * that, but doing so would cause your random numbers to follow a non-uniform
     * distribution, which may not be acceptable for your needs.
     */
    function getRandomIntInclusive(min, max) {
        min = Math.ceil(min);
        max = Math.floor(max);
        return Math.floor(Math.random() * (max - min + 1)) + min;
    }
    /**
     * Returns the number of milliseconds to sleep before the next tick.
     *
     * @param frequency - The poll's base frequency.
     * @param last - The poll's last tick.
     */
    function sleep(frequency, last) {
        var backoff = frequency.backoff, interval = frequency.interval, max = frequency.max;
        if (interval === Poll.NEVER) {
            return interval;
        }
        var growth = backoff === true ? Private.DEFAULT_BACKOFF : backoff === false ? 1 : backoff;
        var random = getRandomIntInclusive(interval, last.interval * growth);
        return Math.min(max, random);
    }
    Private.sleep = sleep;
})(Private || (Private = {}));

// Copyright (c) Jupyter Development Team.
/**
 * A base class to implement rate limiters with different invocation strategies.
 *
 * @typeparam T - The resolved type of the underlying function.
 *
 * @typeparam U - The rejected type of the underlying function.
 */
var RateLimiter = /** @class */ (function () {
    /**
     * Instantiate a rate limiter.
     *
     * @param fn - The function to rate limit.
     *
     * @param limit - The rate limit; defaults to 500ms.
     */
    function RateLimiter(fn, limit) {
        var _this = this;
        if (limit === void 0) { limit = 500; }
        /**
         * A promise that resolves on each successful invocation.
         */
        this.payload = null;
        this.limit = limit;
        this.poll = new Poll({
            auto: false,
            factory: function () { return __awaiter(_this, void 0, void 0, function () { return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, fn()];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            }); }); },
            frequency: { backoff: false, interval: Poll.NEVER, max: Poll.NEVER },
            standby: 'never'
        });
        this.payload = new _lumino_coreutils__WEBPACK_IMPORTED_MODULE_0__.PromiseDelegate();
        this.poll.ticked.connect(function (_, state) {
            var payload = _this.payload;
            if (state.phase === 'resolved') {
                _this.payload = new _lumino_coreutils__WEBPACK_IMPORTED_MODULE_0__.PromiseDelegate();
                payload.resolve(state.payload);
                return;
            }
            if (state.phase === 'rejected' || state.phase === 'stopped') {
                _this.payload = new _lumino_coreutils__WEBPACK_IMPORTED_MODULE_0__.PromiseDelegate();
                payload.promise.catch(function (_) { return undefined; });
                payload.reject(state.payload);
                return;
            }
        }, this);
    }
    Object.defineProperty(RateLimiter.prototype, "isDisposed", {
        /**
         * Whether the rate limiter is disposed.
         */
        get: function () {
            return this.payload === null;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Disposes the rate limiter.
     */
    RateLimiter.prototype.dispose = function () {
        if (this.isDisposed) {
            return;
        }
        this.payload = null;
        this.poll.dispose();
    };
    /**
     * Stop the function if it is mid-flight.
     */
    RateLimiter.prototype.stop = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.poll.stop()];
            });
        });
    };
    return RateLimiter;
}());
/**
 * Wraps and debounces a function that can be called multiple times and only
 * executes the underlying function one `interval` after the last invocation.
 *
 * @typeparam T - The resolved type of the underlying function. Defaults to any.
 *
 * @typeparam U - The rejected type of the underlying function. Defaults to any.
 */
var Debouncer = /** @class */ (function (_super) {
    __extends(Debouncer, _super);
    function Debouncer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Invokes the function and only executes after rate limit has elapsed.
     * Each invocation resets the timer.
     */
    Debouncer.prototype.invoke = function () {
        void this.poll.schedule({ interval: this.limit, phase: 'invoked' });
        return this.payload.promise;
    };
    return Debouncer;
}(RateLimiter));
/**
 * Wraps and throttles a function that can be called multiple times and only
 * executes the underlying function once per `interval`.
 *
 * @typeparam T - The resolved type of the underlying function. Defaults to any.
 *
 * @typeparam U - The rejected type of the underlying function. Defaults to any.
 */
var Throttler = /** @class */ (function (_super) {
    __extends(Throttler, _super);
    /**
     * Instantiate a throttler.
     *
     * @param fn - The function being throttled.
     *
     * @param options - Throttling configuration or throttling limit in ms.
     *
     * #### Notes
     * The `edge` defaults to `leading`; the `limit` defaults to `500`.
     */
    function Throttler(fn, options) {
        var _this = _super.call(this, fn, typeof options === 'number' ? options : options && options.limit) || this;
        var edge = 'leading';
        if (typeof options !== 'number') {
            options = options || {};
            edge = 'edge' in options ? options.edge : edge;
        }
        _this._interval = edge === 'trailing' ? _this.limit : Poll.IMMEDIATE;
        return _this;
    }
    /**
     * Throttles function invocations if one is currently in flight.
     */
    Throttler.prototype.invoke = function () {
        if (this.poll.state.phase !== 'invoked') {
            void this.poll.schedule({ interval: this._interval, phase: 'invoked' });
        }
        return this.payload.promise;
    };
    return Throttler;
}(RateLimiter));


//# sourceMappingURL=index.es6.js.map


/***/ }),

/***/ "./node_modules/@mui/icons-material/AccessAlarmRounded.js":
/*!****************************************************************!*\
  !*** ./node_modules/@mui/icons-material/AccessAlarmRounded.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "m15.87 15.25-3.37-2V8.72c0-.4-.32-.72-.72-.72h-.06c-.4 0-.72.32-.72.72v4.72c0 .35.18.68.49.86l3.65 2.19c.34.2.78.1.98-.24.21-.35.1-.8-.25-1zm5.31-10.24L18.1 2.45c-.42-.35-1.05-.3-1.41.13-.35.42-.29 1.05.13 1.41l3.07 2.56c.42.35 1.05.3 1.41-.13.36-.42.3-1.05-.12-1.41zM4.1 6.55l3.07-2.56c.43-.36.49-.99.13-1.41-.35-.43-.98-.48-1.4-.13L2.82 5.01c-.42.36-.48.99-.12 1.41.35.43.98.48 1.4.13zM12 4c-4.97 0-9 4.03-9 9s4.03 9 9 9 9-4.03 9-9-4.03-9-9-9zm0 16c-3.86 0-7-3.14-7-7s3.14-7 7-7 7 3.14 7 7-3.14 7-7 7z"
}), 'AccessAlarmRounded');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/Add.js":
/*!*************************************************!*\
  !*** ./node_modules/@mui/icons-material/Add.js ***!
  \*************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M19 13h-6v6h-2v-6H5v-2h6V5h2v6h6v2z"
}), 'Add');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/AddBox.js":
/*!****************************************************!*\
  !*** ./node_modules/@mui/icons-material/AddBox.js ***!
  \****************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M19 3H5c-1.11 0-2 .9-2 2v14c0 1.1.89 2 2 2h14c1.1 0 2-.9 2-2V5c0-1.1-.9-2-2-2zm-2 10h-4v4h-2v-4H7v-2h4V7h2v4h4v2z"
}), 'AddBox');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/CancelOutlined.js":
/*!************************************************************!*\
  !*** ./node_modules/@mui/icons-material/CancelOutlined.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M12 2C6.47 2 2 6.47 2 12s4.47 10 10 10 10-4.47 10-10S17.53 2 12 2zm0 18c-4.41 0-8-3.59-8-8s3.59-8 8-8 8 3.59 8 8-3.59 8-8 8zm3.59-13L12 10.59 8.41 7 7 8.41 10.59 12 7 15.59 8.41 17 12 13.41 15.59 17 17 15.59 13.41 12 17 8.41z"
}), 'CancelOutlined');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/ChatRounded.js":
/*!*********************************************************!*\
  !*** ./node_modules/@mui/icons-material/ChatRounded.js ***!
  \*********************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M20 2H4c-1.1 0-1.99.9-1.99 2L2 22l4-4h14c1.1 0 2-.9 2-2V4c0-1.1-.9-2-2-2zM7 9h10c.55 0 1 .45 1 1s-.45 1-1 1H7c-.55 0-1-.45-1-1s.45-1 1-1zm6 5H7c-.55 0-1-.45-1-1s.45-1 1-1h6c.55 0 1 .45 1 1s-.45 1-1 1zm4-6H7c-.55 0-1-.45-1-1s.45-1 1-1h10c.55 0 1 .45 1 1s-.45 1-1 1z"
}), 'ChatRounded');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/Check.js":
/*!***************************************************!*\
  !*** ./node_modules/@mui/icons-material/Check.js ***!
  \***************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M9 16.17 4.83 12l-1.42 1.41L9 19 21 7l-1.41-1.41z"
}), 'Check');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/CheckCircleOutlineOutlined.js":
/*!************************************************************************!*\
  !*** ./node_modules/@mui/icons-material/CheckCircleOutlineOutlined.js ***!
  \************************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M12 2C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm0 18c-4.41 0-8-3.59-8-8s3.59-8 8-8 8 3.59 8 8-3.59 8-8 8zm4.59-12.42L10 14.17l-2.59-2.58L6 13l4 4 8-8z"
}), 'CheckCircleOutlineOutlined');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/Close.js":
/*!***************************************************!*\
  !*** ./node_modules/@mui/icons-material/Close.js ***!
  \***************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M19 6.41 17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12z"
}), 'Close');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/CloudDoneRounded.js":
/*!**************************************************************!*\
  !*** ./node_modules/@mui/icons-material/CloudDoneRounded.js ***!
  \**************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M19.35 10.04C18.67 6.59 15.64 4 12 4 9.11 4 6.6 5.64 5.35 8.04 2.34 8.36 0 10.91 0 14c0 3.31 2.69 6 6 6h13c2.76 0 5-2.24 5-5 0-2.64-2.05-4.78-4.65-4.96zm-8.64 6.25c-.39.39-1.02.39-1.41 0L7.2 14.2a.9959.9959 0 0 1 0-1.41c.39-.39 1.02-.39 1.41 0L10 14.18l4.48-4.48c.39-.39 1.02-.39 1.41 0 .39.39.39 1.02 0 1.41l-5.18 5.18z"
}), 'CloudDoneRounded');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/Dashboard.js":
/*!*******************************************************!*\
  !*** ./node_modules/@mui/icons-material/Dashboard.js ***!
  \*******************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M3 13h8V3H3v10zm0 8h8v-6H3v6zm10 0h8V11h-8v10zm0-18v6h8V3h-8z"
}), 'Dashboard');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/Edit.js":
/*!**************************************************!*\
  !*** ./node_modules/@mui/icons-material/Edit.js ***!
  \**************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M3 17.25V21h3.75L17.81 9.94l-3.75-3.75L3 17.25zM20.71 7.04c.39-.39.39-1.02 0-1.41l-2.34-2.34a.9959.9959 0 0 0-1.41 0l-1.83 1.83 3.75 3.75 1.83-1.83z"
}), 'Edit');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/ErrorOutline.js":
/*!**********************************************************!*\
  !*** ./node_modules/@mui/icons-material/ErrorOutline.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M11 15h2v2h-2zm0-8h2v6h-2zm.99-5C6.47 2 2 6.48 2 12s4.47 10 9.99 10C17.52 22 22 17.52 22 12S17.52 2 11.99 2zM12 20c-4.42 0-8-3.58-8-8s3.58-8 8-8 8 3.58 8 8-3.58 8-8 8z"
}), 'ErrorOutline');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/FileDownload.js":
/*!**********************************************************!*\
  !*** ./node_modules/@mui/icons-material/FileDownload.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M19 9h-4V3H9v6H5l7 7 7-7zM5 18v2h14v-2H5z"
}), 'FileDownload');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/FormatListNumbered.js":
/*!****************************************************************!*\
  !*** ./node_modules/@mui/icons-material/FormatListNumbered.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M2 17h2v.5H3v1h1v.5H2v1h3v-4H2v1zm1-9h1V4H2v1h1v3zm-1 3h1.8L2 13.1v.9h3v-1H3.2L5 10.9V10H2v1zm5-6v2h14V5H7zm0 14h14v-2H7v2zm0-6h14v-2H7v2z"
}), 'FormatListNumbered');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/GetAppRounded.js":
/*!***********************************************************!*\
  !*** ./node_modules/@mui/icons-material/GetAppRounded.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M16.59 9H15V4c0-.55-.45-1-1-1h-4c-.55 0-1 .45-1 1v5H7.41c-.89 0-1.34 1.08-.71 1.71l4.59 4.59c.39.39 1.02.39 1.41 0l4.59-4.59c.63-.63.19-1.71-.7-1.71zM5 19c0 .55.45 1 1 1h12c.55 0 1-.45 1-1s-.45-1-1-1H6c-.55 0-1 .45-1 1z"
}), 'GetAppRounded');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/Grading.js":
/*!*****************************************************!*\
  !*** ./node_modules/@mui/icons-material/Grading.js ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M4 7h16v2H4V7zm0 6h16v-2H4v2zm0 4h7v-2H4v2zm0 4h7v-2H4v2zm11.41-2.83L14 16.75l-1.41 1.41L15.41 21 20 16.42 18.58 15l-3.17 3.17zM4 3v2h16V3H4z"
}), 'Grading');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/HelpOutlineOutlined.js":
/*!*****************************************************************!*\
  !*** ./node_modules/@mui/icons-material/HelpOutlineOutlined.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M11 18h2v-2h-2v2zm1-16C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm0 18c-4.41 0-8-3.59-8-8s3.59-8 8-8 8 3.59 8 8-3.59 8-8 8zm0-14c-2.21 0-4 1.79-4 4h2c0-1.1.9-2 2-2s2 .9 2 2c0 2-3 1.75-3 5h2c0-2.25 3-2.5 3-5 0-2.21-1.79-4-4-4z"
}), 'HelpOutlineOutlined');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/InsertDriveFileRounded.js":
/*!********************************************************************!*\
  !*** ./node_modules/@mui/icons-material/InsertDriveFileRounded.js ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M6 2c-1.1 0-1.99.9-1.99 2L4 20c0 1.1.89 2 1.99 2H18c1.1 0 2-.9 2-2V8.83c0-.53-.21-1.04-.59-1.41l-4.83-4.83c-.37-.38-.88-.59-1.41-.59H6zm7 6V3.5L18.5 9H14c-.55 0-1-.45-1-1z"
}), 'InsertDriveFileRounded');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/NavigateNext.js":
/*!**********************************************************!*\
  !*** ./node_modules/@mui/icons-material/NavigateNext.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M10 6 8.59 7.41 13.17 12l-4.58 4.59L10 18l6-6z"
}), 'NavigateNext');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/NewReleasesRounded.js":
/*!****************************************************************!*\
  !*** ./node_modules/@mui/icons-material/NewReleasesRounded.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "m22.42 11.34-1.86-2.12.26-2.81c.05-.5-.29-.96-.77-1.07l-2.76-.63-1.44-2.43c-.26-.43-.79-.61-1.25-.41L12 3 9.41 1.89c-.46-.2-1-.02-1.25.41L6.71 4.72l-2.75.62c-.49.11-.83.56-.78 1.07l.26 2.8-1.86 2.13c-.33.38-.33.94 0 1.32l1.86 2.12-.26 2.82c-.05.5.29.96.77 1.07l2.76.63 1.44 2.42c.26.43.79.61 1.26.41L12 21l2.59 1.11c.46.2 1 .02 1.25-.41l1.44-2.43 2.76-.63c.49-.11.82-.57.77-1.07l-.26-2.81 1.86-2.12c.34-.36.34-.92.01-1.3zM13 17h-2v-2h2v2zm-1-4c-.55 0-1-.45-1-1V8c0-.55.45-1 1-1s1 .45 1 1v4c0 .55-.45 1-1 1z"
}), 'NewReleasesRounded');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/OpenInBrowser.js":
/*!***********************************************************!*\
  !*** ./node_modules/@mui/icons-material/OpenInBrowser.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M19 4H5c-1.11 0-2 .9-2 2v12c0 1.1.89 2 2 2h4v-2H5V8h14v10h-4v2h4c1.1 0 2-.9 2-2V6c0-1.1-.89-2-2-2zm-7 6-4 4h3v6h2v-6h3l-4-4z"
}), 'OpenInBrowser');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/PublishRounded.js":
/*!************************************************************!*\
  !*** ./node_modules/@mui/icons-material/PublishRounded.js ***!
  \************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M5 5c0 .55.45 1 1 1h12c.55 0 1-.45 1-1s-.45-1-1-1H6c-.55 0-1 .45-1 1zm2.41 9H9v5c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-5h1.59c.89 0 1.34-1.08.71-1.71L12.71 7.7a.9959.9959 0 0 0-1.41 0l-4.59 4.59c-.63.63-.19 1.71.7 1.71z"
}), 'PublishRounded');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/QueryStats.js":
/*!********************************************************!*\
  !*** ./node_modules/@mui/icons-material/QueryStats.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M19.88 18.47c.44-.7.7-1.51.7-2.39 0-2.49-2.01-4.5-4.5-4.5s-4.5 2.01-4.5 4.5 2.01 4.5 4.49 4.5c.88 0 1.7-.26 2.39-.7L21.58 23 23 21.58l-3.12-3.11zm-3.8.11c-1.38 0-2.5-1.12-2.5-2.5s1.12-2.5 2.5-2.5 2.5 1.12 2.5 2.5-1.12 2.5-2.5 2.5zm-.36-8.5c-.74.02-1.45.18-2.1.45l-.55-.83-3.8 6.18-3.01-3.52-3.63 5.81L1 17l5-8 3 3.5L13 6l2.72 4.08zm2.59.5c-.64-.28-1.33-.45-2.05-.49L21.38 2 23 3.18l-4.69 7.4z"
}), 'QueryStats');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/Replay.js":
/*!****************************************************!*\
  !*** ./node_modules/@mui/icons-material/Replay.js ***!
  \****************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M12 5V1L7 6l5 5V7c3.31 0 6 2.69 6 6s-2.69 6-6 6-6-2.69-6-6H4c0 4.42 3.58 8 8 8s8-3.58 8-8-3.58-8-8-8z"
}), 'Replay');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/RestartAlt.js":
/*!********************************************************!*\
  !*** ./node_modules/@mui/icons-material/RestartAlt.js ***!
  \********************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M12 5V2L8 6l4 4V7c3.31 0 6 2.69 6 6 0 2.97-2.17 5.43-5 5.91v2.02c3.95-.49 7-3.85 7-7.93 0-4.42-3.58-8-8-8zm-6 8c0-1.65.67-3.15 1.76-4.24L6.34 7.34C4.9 8.79 4 10.79 4 13c0 4.08 3.05 7.44 7 7.93v-2.02c-2.83-.48-5-2.94-5-5.91z"
}), 'RestartAlt');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/Task.js":
/*!**************************************************!*\
  !*** ./node_modules/@mui/icons-material/Task.js ***!
  \**************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M14 2H6c-1.1 0-1.99.9-1.99 2L4 20c0 1.1.89 2 1.99 2H18c1.1 0 2-.9 2-2V8l-6-6zm-3.06 16L7.4 14.46l1.41-1.41 2.12 2.12 4.24-4.24 1.41 1.41L10.94 18zM13 9V3.5L18.5 9H13z"
}), 'Task');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/Terminal.js":
/*!******************************************************!*\
  !*** ./node_modules/@mui/icons-material/Terminal.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M20 4H4c-1.11 0-2 .9-2 2v12c0 1.1.89 2 2 2h16c1.1 0 2-.9 2-2V6c0-1.1-.89-2-2-2zm0 14H4V8h16v10zm-2-1h-6v-2h6v2zM7.5 17l-1.41-1.41L8.67 13l-2.59-2.59L7.5 9l4 4-4 4z"
}), 'Terminal');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/Undo.js":
/*!**************************************************!*\
  !*** ./node_modules/@mui/icons-material/Undo.js ***!
  \**************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


var _interopRequireDefault = __webpack_require__(/*! @babel/runtime/helpers/interopRequireDefault */ "./node_modules/@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var _createSvgIcon = _interopRequireDefault(__webpack_require__(/*! ./utils/createSvgIcon */ "./node_modules/@mui/icons-material/utils/createSvgIcon.js"));

var _jsxRuntime = __webpack_require__(/*! react/jsx-runtime */ "./node_modules/react/jsx-runtime.js");

var _default = (0, _createSvgIcon.default)( /*#__PURE__*/(0, _jsxRuntime.jsx)("path", {
  d: "M12.5 8c-2.65 0-5.05.99-6.9 2.6L2 7v9h9l-3.62-3.62c1.39-1.16 3.16-1.88 5.12-1.88 3.54 0 6.55 2.31 7.6 5.5l2.37-.78C21.08 11.03 17.15 8 12.5 8z"
}), 'Undo');

exports["default"] = _default;

/***/ }),

/***/ "./node_modules/@mui/icons-material/utils/createSvgIcon.js":
/*!*****************************************************************!*\
  !*** ./node_modules/@mui/icons-material/utils/createSvgIcon.js ***!
  \*****************************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";


Object.defineProperty(exports, "__esModule", ({
  value: true
}));
Object.defineProperty(exports, "default", ({
  enumerable: true,
  get: function () {
    return _utils.createSvgIcon;
  }
}));

var _utils = __webpack_require__(/*! @mui/material/utils */ "./node_modules/@mui/material/utils/index.js");

/***/ }),

/***/ "./node_modules/@mui/material/utils/createChainedFunction.js":
/*!*******************************************************************!*\
  !*** ./node_modules/@mui/material/utils/createChainedFunction.js ***!
  \*******************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _mui_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @mui/utils */ "./node_modules/@mui/utils/esm/createChainedFunction.js");

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_mui_utils__WEBPACK_IMPORTED_MODULE_0__["default"]);

/***/ }),

/***/ "./node_modules/@mui/material/utils/deprecatedPropType.js":
/*!****************************************************************!*\
  !*** ./node_modules/@mui/material/utils/deprecatedPropType.js ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _mui_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @mui/utils */ "./node_modules/@mui/utils/esm/deprecatedPropType.js");

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_mui_utils__WEBPACK_IMPORTED_MODULE_0__["default"]);

/***/ }),

/***/ "./node_modules/@mui/material/utils/index.js":
/*!***************************************************!*\
  !*** ./node_modules/@mui/material/utils/index.js ***!
  \***************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "capitalize": () => (/* reexport safe */ _capitalize__WEBPACK_IMPORTED_MODULE_0__["default"]),
/* harmony export */   "createChainedFunction": () => (/* reexport safe */ _createChainedFunction__WEBPACK_IMPORTED_MODULE_1__["default"]),
/* harmony export */   "createSvgIcon": () => (/* reexport safe */ _createSvgIcon__WEBPACK_IMPORTED_MODULE_2__["default"]),
/* harmony export */   "debounce": () => (/* reexport safe */ _debounce__WEBPACK_IMPORTED_MODULE_3__["default"]),
/* harmony export */   "deprecatedPropType": () => (/* reexport safe */ _deprecatedPropType__WEBPACK_IMPORTED_MODULE_4__["default"]),
/* harmony export */   "isMuiElement": () => (/* reexport safe */ _isMuiElement__WEBPACK_IMPORTED_MODULE_5__["default"]),
/* harmony export */   "ownerDocument": () => (/* reexport safe */ _ownerDocument__WEBPACK_IMPORTED_MODULE_6__["default"]),
/* harmony export */   "ownerWindow": () => (/* reexport safe */ _ownerWindow__WEBPACK_IMPORTED_MODULE_7__["default"]),
/* harmony export */   "requirePropFactory": () => (/* reexport safe */ _requirePropFactory__WEBPACK_IMPORTED_MODULE_8__["default"]),
/* harmony export */   "setRef": () => (/* reexport safe */ _setRef__WEBPACK_IMPORTED_MODULE_9__["default"]),
/* harmony export */   "unstable_ClassNameGenerator": () => (/* binding */ unstable_ClassNameGenerator),
/* harmony export */   "unstable_useEnhancedEffect": () => (/* reexport safe */ _useEnhancedEffect__WEBPACK_IMPORTED_MODULE_10__["default"]),
/* harmony export */   "unstable_useId": () => (/* reexport safe */ _useId__WEBPACK_IMPORTED_MODULE_11__["default"]),
/* harmony export */   "unsupportedProp": () => (/* reexport safe */ _unsupportedProp__WEBPACK_IMPORTED_MODULE_12__["default"]),
/* harmony export */   "useControlled": () => (/* reexport safe */ _useControlled__WEBPACK_IMPORTED_MODULE_13__["default"]),
/* harmony export */   "useEventCallback": () => (/* reexport safe */ _useEventCallback__WEBPACK_IMPORTED_MODULE_14__["default"]),
/* harmony export */   "useForkRef": () => (/* reexport safe */ _useForkRef__WEBPACK_IMPORTED_MODULE_15__["default"]),
/* harmony export */   "useIsFocusVisible": () => (/* reexport safe */ _useIsFocusVisible__WEBPACK_IMPORTED_MODULE_16__["default"])
/* harmony export */ });
/* harmony import */ var _mui_base_className__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! @mui/base/className */ "./node_modules/@mui/private-classnames/ClassNameGenerator/ClassNameGenerator.js");
/* harmony import */ var _capitalize__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./capitalize */ "./node_modules/@mui/material/utils/capitalize.js");
/* harmony import */ var _createChainedFunction__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./createChainedFunction */ "./node_modules/@mui/material/utils/createChainedFunction.js");
/* harmony import */ var _createSvgIcon__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./createSvgIcon */ "./node_modules/@mui/material/utils/createSvgIcon.js");
/* harmony import */ var _debounce__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./debounce */ "./node_modules/@mui/material/utils/debounce.js");
/* harmony import */ var _deprecatedPropType__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./deprecatedPropType */ "./node_modules/@mui/material/utils/deprecatedPropType.js");
/* harmony import */ var _isMuiElement__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./isMuiElement */ "./node_modules/@mui/material/utils/isMuiElement.js");
/* harmony import */ var _ownerDocument__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./ownerDocument */ "./node_modules/@mui/material/utils/ownerDocument.js");
/* harmony import */ var _ownerWindow__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./ownerWindow */ "./node_modules/@mui/material/utils/ownerWindow.js");
/* harmony import */ var _requirePropFactory__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./requirePropFactory */ "./node_modules/@mui/material/utils/requirePropFactory.js");
/* harmony import */ var _setRef__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./setRef */ "./node_modules/@mui/material/utils/setRef.js");
/* harmony import */ var _useEnhancedEffect__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./useEnhancedEffect */ "./node_modules/@mui/material/utils/useEnhancedEffect.js");
/* harmony import */ var _useId__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./useId */ "./node_modules/@mui/material/utils/useId.js");
/* harmony import */ var _unsupportedProp__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./unsupportedProp */ "./node_modules/@mui/material/utils/unsupportedProp.js");
/* harmony import */ var _useControlled__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./useControlled */ "./node_modules/@mui/material/utils/useControlled.js");
/* harmony import */ var _useEventCallback__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./useEventCallback */ "./node_modules/@mui/material/utils/useEventCallback.js");
/* harmony import */ var _useForkRef__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./useForkRef */ "./node_modules/@mui/material/utils/useForkRef.js");
/* harmony import */ var _useIsFocusVisible__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./useIsFocusVisible */ "./node_modules/@mui/material/utils/useIsFocusVisible.js");

















 // TODO: remove this export once ClassNameGenerator is stable
// eslint-disable-next-line @typescript-eslint/naming-convention

const unstable_ClassNameGenerator = {
  configure: generator => {
    console.warn(['MUI: `ClassNameGenerator` import from `@mui/material/utils` is outdated and might cause unexpected issues.', '', "You should use `import { unstable_ClassNameGenerator } from '@mui/material/className'` instead", '', 'The detail of the issue: https://github.com/mui/material-ui/issues/30011#issuecomment-1024993401', '', 'The updated documentation: https://mui.com/guides/classname-generator/'].join('\n'));
    _mui_base_className__WEBPACK_IMPORTED_MODULE_17__["default"].configure(generator);
  }
};

/***/ }),

/***/ "./node_modules/@mui/material/utils/setRef.js":
/*!****************************************************!*\
  !*** ./node_modules/@mui/material/utils/setRef.js ***!
  \****************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony import */ var _mui_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @mui/utils */ "./node_modules/@mui/utils/esm/setRef.js");

/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_mui_utils__WEBPACK_IMPORTED_MODULE_0__["default"]);

/***/ }),

/***/ "./node_modules/@mui/utils/esm/deprecatedPropType.js":
/*!***********************************************************!*\
  !*** ./node_modules/@mui/utils/esm/deprecatedPropType.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (/* binding */ deprecatedPropType)
/* harmony export */ });
function deprecatedPropType(validator, reason) {
  if (false) {}

  return (props, propName, componentName, location, propFullName) => {
    const componentNameSafe = componentName || '<<anonymous>>';
    const propFullNameSafe = propFullName || propName;

    if (typeof props[propName] !== 'undefined') {
      return new Error(`The ${location} \`${propFullNameSafe}\` of ` + `\`${componentNameSafe}\` is deprecated. ${reason}`);
    }

    return null;
  };
}

/***/ }),

/***/ "./node_modules/free-style/dist.es2015/index.js":
/*!******************************************************!*\
  !*** ./node_modules/free-style/dist.es2015/index.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Cache": () => (/* binding */ Cache),
/* harmony export */   "FreeStyle": () => (/* binding */ FreeStyle),
/* harmony export */   "Rule": () => (/* binding */ Rule),
/* harmony export */   "Selector": () => (/* binding */ Selector),
/* harmony export */   "Style": () => (/* binding */ Style),
/* harmony export */   "create": () => (/* binding */ create)
/* harmony export */ });
/**
 * The unique id is used for unique hashes.
 */
let uniqueId = 0;
/**
 * Quick dictionary lookup for unit-less numbers.
 */
const CSS_NUMBER = Object.create(null);
/**
 * CSS properties that are valid unit-less numbers.
 *
 * Ref: https://github.com/facebook/react/blob/master/packages/react-dom/src/shared/CSSProperty.js
 */
const CSS_NUMBER_KEYS = [
    "animation-iteration-count",
    "border-image-outset",
    "border-image-slice",
    "border-image-width",
    "box-flex",
    "box-flex-group",
    "box-ordinal-group",
    "column-count",
    "columns",
    "counter-increment",
    "counter-reset",
    "flex",
    "flex-grow",
    "flex-positive",
    "flex-shrink",
    "flex-negative",
    "flex-order",
    "font-weight",
    "grid-area",
    "grid-column",
    "grid-column-end",
    "grid-column-span",
    "grid-column-start",
    "grid-row",
    "grid-row-end",
    "grid-row-span",
    "grid-row-start",
    "line-clamp",
    "line-height",
    "opacity",
    "order",
    "orphans",
    "tab-size",
    "widows",
    "z-index",
    "zoom",
    // SVG properties.
    "fill-opacity",
    "flood-opacity",
    "stop-opacity",
    "stroke-dasharray",
    "stroke-dashoffset",
    "stroke-miterlimit",
    "stroke-opacity",
    "stroke-width"
];
// Add vendor prefixes to all unit-less properties.
for (const property of CSS_NUMBER_KEYS) {
    for (const prefix of ["-webkit-", "-ms-", "-moz-", "-o-", ""]) {
        CSS_NUMBER[prefix + property] = true;
    }
}
/**
 * Escape a CSS class name.
 */
function escape(str) {
    return str.replace(/[ !#$%&()*+,./;<=>?@[\]^`{|}~"'\\]/g, "\\$&");
}
/**
 * Transform a JavaScript property into a CSS property.
 */
function hyphenate(propertyName) {
    return propertyName
        .replace(/[A-Z]/g, (m) => `-${m.toLowerCase()}`)
        .replace(/^ms-/, "-ms-"); // Internet Explorer vendor prefix.
}
/**
 * Generate a hash value from a string.
 */
function stringHash(str) {
    let value = 5381;
    let len = str.length;
    while (len--)
        value = (value * 33) ^ str.charCodeAt(len);
    return (value >>> 0).toString(36);
}
/**
 * Transform a style string to a CSS string.
 */
function styleToString(key, value) {
    if (value && typeof value === "number" && !CSS_NUMBER[key]) {
        return `${key}:${value}px`;
    }
    return `${key}:${value}`;
}
/**
 * Sort an array of tuples by first value.
 */
function sortTuples(value) {
    return value.sort((a, b) => (a[0] > b[0] ? 1 : -1));
}
/**
 * Categorize user styles.
 */
function parseStyles(styles, hasNestedStyles) {
    const properties = [];
    const nestedStyles = [];
    // Sort keys before adding to styles.
    for (const key of Object.keys(styles)) {
        const name = key.trim();
        const value = styles[key];
        if (name.charCodeAt(0) !== 36 /* $ */ && value != null) {
            if (typeof value === "object" && !Array.isArray(value)) {
                nestedStyles.push([name, value]);
            }
            else {
                properties.push([hyphenate(name), value]);
            }
        }
    }
    return {
        style: stringifyProperties(sortTuples(properties)),
        nested: hasNestedStyles ? nestedStyles : sortTuples(nestedStyles),
        isUnique: !!styles.$unique
    };
}
/**
 * Stringify an array of property tuples.
 */
function stringifyProperties(properties) {
    return properties
        .map(([name, value]) => {
        if (!Array.isArray(value))
            return styleToString(name, value);
        return value.map(x => styleToString(name, x)).join(";");
    })
        .join(";");
}
/**
 * Interpolate CSS selectors.
 */
function interpolate(selector, parent) {
    if (selector.indexOf("&") === -1)
        return `${parent} ${selector}`;
    return selector.replace(/&/g, parent);
}
/**
 * Recursive loop building styles with deferred selectors.
 */
function stylize(selector, styles, rulesList, stylesList, parent) {
    const { style, nested, isUnique } = parseStyles(styles, selector !== "");
    let pid = style;
    if (selector.charCodeAt(0) === 64 /* @ */) {
        const child = {
            selector,
            styles: [],
            rules: [],
            style: parent ? "" : style
        };
        rulesList.push(child);
        // Nested styles support (e.g. `.foo > @media > .bar`).
        if (style && parent) {
            child.styles.push({ selector: parent, style, isUnique });
        }
        for (const [name, value] of nested) {
            pid += name + stylize(name, value, child.rules, child.styles, parent);
        }
    }
    else {
        const key = parent ? interpolate(selector, parent) : selector;
        if (style)
            stylesList.push({ selector: key, style, isUnique });
        for (const [name, value] of nested) {
            pid += name + stylize(name, value, rulesList, stylesList, key);
        }
    }
    return pid;
}
/**
 * Transform `stylize` tree into style objects.
 */
function composeStylize(cache, pid, rulesList, stylesList, className, isStyle) {
    for (const { selector, style, isUnique } of stylesList) {
        const key = isStyle ? interpolate(selector, className) : selector;
        const id = isUnique
            ? `u\0${(++uniqueId).toString(36)}`
            : `s\0${pid}\0${style}`;
        const item = new Style(style, id);
        item.add(new Selector(key, `k\0${pid}\0${key}`));
        cache.add(item);
    }
    for (const { selector, style, rules, styles } of rulesList) {
        const item = new Rule(selector, style, `r\0${pid}\0${selector}\0${style}`);
        composeStylize(item, pid, rules, styles, className, isStyle);
        cache.add(item);
    }
}
/**
 * Cache to list to styles.
 */
function join(arr) {
    let res = "";
    for (let i = 0; i < arr.length; i++)
        res += arr[i];
    return res;
}
/**
 * Noop changes.
 */
const noopChanges = {
    add: () => undefined,
    change: () => undefined,
    remove: () => undefined
};
/**
 * Implement a cache/event emitter.
 */
class Cache {
    constructor(changes = noopChanges) {
        this.changes = changes;
        this.sheet = [];
        this.changeId = 0;
        this._keys = [];
        this._children = Object.create(null);
        this._counters = Object.create(null);
    }
    add(style) {
        const count = this._counters[style.id] || 0;
        const item = this._children[style.id] || style.clone();
        this._counters[style.id] = count + 1;
        if (count === 0) {
            this._children[item.id] = item;
            this._keys.push(item.id);
            this.sheet.push(item.getStyles());
            this.changeId++;
            this.changes.add(item, this._keys.length - 1);
        }
        else if (item instanceof Cache && style instanceof Cache) {
            const curIndex = this._keys.indexOf(style.id);
            const prevItemChangeId = item.changeId;
            item.merge(style);
            if (item.changeId !== prevItemChangeId) {
                this.sheet.splice(curIndex, 1, item.getStyles());
                this.changeId++;
                this.changes.change(item, curIndex, curIndex);
            }
        }
    }
    remove(style) {
        const count = this._counters[style.id];
        if (count) {
            this._counters[style.id] = count - 1;
            const item = this._children[style.id];
            const index = this._keys.indexOf(item.id);
            if (count === 1) {
                delete this._counters[style.id];
                delete this._children[style.id];
                this._keys.splice(index, 1);
                this.sheet.splice(index, 1);
                this.changeId++;
                this.changes.remove(item, index);
            }
            else if (item instanceof Cache && style instanceof Cache) {
                const prevChangeId = item.changeId;
                item.unmerge(style);
                if (item.changeId !== prevChangeId) {
                    this.sheet.splice(index, 1, item.getStyles());
                    this.changeId++;
                    this.changes.change(item, index, index);
                }
            }
        }
    }
    values() {
        return this._keys.map(key => this._children[key]);
    }
    merge(cache) {
        for (const item of cache.values())
            this.add(item);
        return this;
    }
    unmerge(cache) {
        for (const item of cache.values())
            this.remove(item);
        return this;
    }
    clone() {
        return new Cache().merge(this);
    }
}
/**
 * Selector is a dumb class made to represent nested CSS selectors.
 */
class Selector {
    constructor(selector, id) {
        this.selector = selector;
        this.id = id;
    }
    getStyles() {
        return this.selector;
    }
    clone() {
        return this;
    }
}
/**
 * The style container registers a style string with selectors.
 */
class Style extends Cache {
    constructor(style, id) {
        super();
        this.style = style;
        this.id = id;
    }
    getStyles() {
        return `${this.sheet.join(",")}{${this.style}}`;
    }
    clone() {
        return new Style(this.style, this.id).merge(this);
    }
}
/**
 * Implement rule logic for style output.
 */
class Rule extends Cache {
    constructor(rule, style, id) {
        super();
        this.rule = rule;
        this.style = style;
        this.id = id;
    }
    getStyles() {
        return `${this.rule}{${this.style}${join(this.sheet)}}`;
    }
    clone() {
        return new Rule(this.rule, this.style, this.id).merge(this);
    }
}
function key(pid, styles) {
    const key = `f${stringHash(pid)}`;
    if ( false || !styles.$displayName)
        return key;
    return `${styles.$displayName}_${key}`;
}
/**
 * The FreeStyle class implements the API for everything else.
 */
class FreeStyle extends Cache {
    constructor(id, changes) {
        super(changes);
        this.id = id;
    }
    registerStyle(styles) {
        const rulesList = [];
        const stylesList = [];
        const pid = stylize("&", styles, rulesList, stylesList);
        const id = key(pid, styles);
        const selector = `.${ false ? 0 : escape(id)}`;
        composeStylize(this, pid, rulesList, stylesList, selector, true);
        return id;
    }
    registerKeyframes(keyframes) {
        return this.registerHashRule("@keyframes", keyframes);
    }
    registerHashRule(prefix, styles) {
        const rulesList = [];
        const stylesList = [];
        const pid = stylize("", styles, rulesList, stylesList);
        const id = key(pid, styles);
        const selector = `${prefix} ${ false ? 0 : escape(id)}`;
        const rule = new Rule(selector, "", `h\0${pid}\0${prefix}`);
        composeStylize(rule, pid, rulesList, stylesList, "", false);
        this.add(rule);
        return id;
    }
    registerRule(rule, styles) {
        const rulesList = [];
        const stylesList = [];
        const pid = stylize(rule, styles, rulesList, stylesList);
        composeStylize(this, pid, rulesList, stylesList, "", false);
    }
    registerCss(styles) {
        return this.registerRule("", styles);
    }
    getStyles() {
        return join(this.sheet);
    }
    clone() {
        return new FreeStyle(this.id, this.changes).merge(this);
    }
}
/**
 * Exports a simple function to create a new instance.
 */
function create(changes) {
    return new FreeStyle(`f${(++uniqueId).toString(36)}`, changes);
}
//# sourceMappingURL=index.js.map

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/debug/bad.svg":
/*!********************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/debug/bad.svg ***!
  \********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"24\" height=\"24\" viewBox=\"0 0 24 24\">\n    <path\n        class=\"jp-icon0\"\n        fill=\"#000\"\n        d=\"M24 20.188l-8.315-8.209 8.2-8.282-3.697-3.697-8.212 8.318-8.31-8.203-3.666 3.666 8.321 8.24-8.206 8.313 3.666 3.666 8.237-8.318 8.285 8.203z\"\n    />\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/debug/blank.svg":
/*!**********************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/debug/blank.svg ***!
  \**********************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"24\" height=\"24\" viewBox=\"0 0 24 24\">\n    <path\n        fill=\"#000\"\n        fill-opacity=\"0.0\"\n        d=\"M24 20.188l-8.315-8.209 8.2-8.282-3.697-3.697-8.212 8.318-8.31-8.203-3.666 3.666 8.321 8.24-8.206 8.313 3.666 3.666 8.237-8.318 8.285 8.203z\"\n    />\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-down-empty-thin.svg":
/*!********************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-down-empty-thin.svg ***!
  \********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 20 20\">\n\t<g class=\"jp-icon3\" fill=\"#616161\" shape-rendering=\"geometricPrecision\">\n\t\t<polygon class=\"st1\" points=\"9.9,13.6 3.6,7.4 4.4,6.6 9.9,12.2 15.4,6.7 16.1,7.4 \"/>\n\t</g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-down-empty.svg":
/*!***************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-down-empty.svg ***!
  \***************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 18 18\">\n  <g class=\"jp-icon3\" fill=\"#616161\" shape-rendering=\"geometricPrecision\">\n    <path d=\"M5.2,5.9L9,9.7l3.8-3.8l1.2,1.2l-4.9,5l-4.9-5L5.2,5.9z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-down.svg":
/*!*********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-down.svg ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 18 18\">\n  <g class=\"jp-icon3\" fill=\"#616161\" shape-rendering=\"geometricPrecision\">\n    <path d=\"M5.2,7.5L9,11.2l3.8-3.8H5.2z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-left.svg":
/*!*********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-left.svg ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 18 18\">\n\t<g class=\"jp-icon3\" fill=\"#616161\" shape-rendering=\"geometricPrecision\">\n\t\t<path d=\"M10.8,12.8L7.1,9l3.8-3.8l0,7.6H10.8z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-right.svg":
/*!**********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-right.svg ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 18 18\">\n  <g class=\"jp-icon3\" fill=\"#616161\" shape-rendering=\"geometricPrecision\">\n    <path d=\"M7.2,5.2L10.9,9l-3.8,3.8V5.2H7.2z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-up-empty-thin.svg":
/*!******************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-up-empty-thin.svg ***!
  \******************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 20 20\">\n\t<g class=\"jp-icon3\" fill=\"#616161\" shape-rendering=\"geometricPrecision\">\n\t\t<polygon class=\"st1\" points=\"15.4,13.3 9.9,7.7 4.4,13.2 3.6,12.5 9.9,6.3 16.1,12.6 \"/>\n\t</g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-up.svg":
/*!*******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/arrow/caret-up.svg ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 18 18\">\n\t<g class=\"jp-icon3\" fill=\"#616161\" shape-rendering=\"geometricPrecision\">\n\t\t<path d=\"M5.2,10.5L9,6.8l3.8,3.8H5.2z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/console.svg":
/*!*********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/console.svg ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 200 200\">\n  <g class=\"jp-icon-brand1 jp-icon-selectable\" fill=\"#0288D1\">\n    <path d=\"M20 19.8h160v159.9H20z\"/>\n  </g>\n  <g class=\"jp-icon-selectable-inverse\" fill=\"#fff\">\n    <path d=\"M105 127.3h40v12.8h-40zM51.1 77L74 99.9l-23.3 23.3 10.5 10.5 23.3-23.3L95 99.9 84.5 89.4 61.6 66.5z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/file.svg":
/*!******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/file.svg ***!
  \******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 22 22\">\n  <path class=\"jp-icon3 jp-icon-selectable\" fill=\"#616161\" d=\"M19.3 8.2l-5.5-5.5c-.3-.3-.7-.5-1.2-.5H3.9c-.8.1-1.6.9-1.6 1.8v14.1c0 .9.7 1.6 1.6 1.6h14.2c.9 0 1.6-.7 1.6-1.6V9.4c.1-.5-.1-.9-.4-1.2zm-5.8-3.3l3.4 3.6h-3.4V4.9zm3.9 12.7H4.7c-.1 0-.2 0-.2-.2V4.7c0-.2.1-.3.2-.3h7.2v4.4s0 .8.3 1.1c.3.3 1.1.3 1.1.3h4.3v7.2s-.1.2-.2.2z\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/folder-favorite.svg":
/*!*****************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/folder-favorite.svg ***!
  \*****************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" height=\"24px\" viewBox=\"0 0 24 24\" width=\"24px\" fill=\"#000000\">\n  <path d=\"M0 0h24v24H0V0z\" fill=\"none\"/><path class=\"jp-icon3 jp-icon-selectable\" fill=\"#616161\" d=\"M20 6h-8l-2-2H4c-1.1 0-2 .9-2 2v12c0 1.1.9 2 2 2h16c1.1 0 2-.9 2-2V8c0-1.1-.9-2-2-2zm-2.06 11L15 15.28 12.06 17l.78-3.33-2.59-2.24 3.41-.29L15 8l1.34 3.14 3.41.29-2.59 2.24.78 3.33z\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/folder.svg":
/*!********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/folder.svg ***!
  \********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n  <path class=\"jp-icon3 jp-icon-selectable\" fill=\"#616161\" d=\"M10 4H4c-1.1 0-1.99.9-1.99 2L2 18c0 1.1.9 2 2 2h16c1.1 0 2-.9 2-2V8c0-1.1-.9-2-2-2h-8l-2-2z\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/home.svg":
/*!******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/home.svg ***!
  \******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" height=\"24px\" viewBox=\"0 0 24 24\" width=\"24px\" fill=\"#000000\">\n  <path d=\"M0 0h24v24H0z\" fill=\"none\"/><path class=\"jp-icon3 jp-icon-selectable\" fill=\"#616161\" d=\"M10 20v-6h4v6h5v-8h3L12 3 2 12h3v8z\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/html5.svg":
/*!*******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/html5.svg ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 512 512\">\n  <path class=\"jp-icon0 jp-icon-selectable\" fill=\"#000\" d=\"M108.4 0h23v22.8h21.2V0h23v69h-23V46h-21v23h-23.2M206 23h-20.3V0h63.7v23H229v46h-23m53.5-69h24.1l14.8 24.3L313.2 0h24.1v69h-23V34.8l-16.1 24.8-16.1-24.8V69h-22.6m89.2-69h23v46.2h32.6V69h-55.6\"/>\n  <path class=\"jp-icon-selectable\" fill=\"#e44d26\" d=\"M107.6 471l-33-370.4h362.8l-33 370.2L255.7 512\"/>\n  <path class=\"jp-icon-selectable\" fill=\"#f16529\" d=\"M256 480.5V131h148.3L376 447\"/>\n  <path class=\"jp-icon-selectable-inverse\" fill=\"#ebebeb\" d=\"M142 176.3h114v45.4h-64.2l4.2 46.5h60v45.3H154.4m2 22.8H202l3.2 36.3 50.8 13.6v47.4l-93.2-26\"/>\n  <path class=\"jp-icon-selectable-inverse\" fill=\"#fff\" d=\"M369.6 176.3H255.8v45.4h109.6m-4.1 46.5H255.8v45.4h56l-5.3 59-50.7 13.6v47.2l93-25.8\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/image.svg":
/*!*******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/image.svg ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 22 22\">\n  <path class=\"jp-icon-brand4 jp-icon-selectable-inverse\" fill=\"#FFF\" d=\"M2.2 2.2h17.5v17.5H2.2z\"/>\n  <path class=\"jp-icon-brand0 jp-icon-selectable\" fill=\"#3F51B5\" d=\"M2.2 2.2v17.5h17.5l.1-17.5H2.2zm12.1 2.2c1.2 0 2.2 1 2.2 2.2s-1 2.2-2.2 2.2-2.2-1-2.2-2.2 1-2.2 2.2-2.2zM4.4 17.6l3.3-8.8 3.3 6.6 2.2-3.2 4.4 5.4H4.4z\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/inspector.svg":
/*!***********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/inspector.svg ***!
  \***********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n  <path class=\"jp-icon3 jp-icon-selectable\" fill=\"#616161\" d=\"M20 4H4c-1.1 0-1.99.9-1.99 2L2 18c0 1.1.9 2 2 2h16c1.1 0 2-.9 2-2V6c0-1.1-.9-2-2-2zm-5 14H4v-4h11v4zm0-5H4V9h11v4zm5 5h-4V9h4v9z\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/json.svg":
/*!******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/json.svg ***!
  \******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 22 22\">\n  <g class=\"jp-icon-warn1 jp-icon-selectable\" fill=\"#F9A825\">\n    <path d=\"M20.2 11.8c-1.6 0-1.7.5-1.7 1 0 .4.1.9.1 1.3.1.5.1.9.1 1.3 0 1.7-1.4 2.3-3.5 2.3h-.9v-1.9h.5c1.1 0 1.4 0 1.4-.8 0-.3 0-.6-.1-1 0-.4-.1-.8-.1-1.2 0-1.3 0-1.8 1.3-2-1.3-.2-1.3-.7-1.3-2 0-.4.1-.8.1-1.2.1-.4.1-.7.1-1 0-.8-.4-.7-1.4-.8h-.5V4.1h.9c2.2 0 3.5.7 3.5 2.3 0 .4-.1.9-.1 1.3-.1.5-.1.9-.1 1.3 0 .5.2 1 1.7 1v1.8zM1.8 10.1c1.6 0 1.7-.5 1.7-1 0-.4-.1-.9-.1-1.3-.1-.5-.1-.9-.1-1.3 0-1.6 1.4-2.3 3.5-2.3h.9v1.9h-.5c-1 0-1.4 0-1.4.8 0 .3 0 .6.1 1 0 .2.1.6.1 1 0 1.3 0 1.8-1.3 2C6 11.2 6 11.7 6 13c0 .4-.1.8-.1 1.2-.1.3-.1.7-.1 1 0 .8.3.8 1.4.8h.5v1.9h-.9c-2.1 0-3.5-.6-3.5-2.3 0-.4.1-.9.1-1.3.1-.5.1-.9.1-1.3 0-.5-.2-1-1.7-1v-1.9z\"/>\n    <circle cx=\"11\" cy=\"13.8\" r=\"2.1\"/>\n    <circle cx=\"11\" cy=\"8.2\" r=\"2.1\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/julia.svg":
/*!*******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/julia.svg ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 325 300\">\n  <g class=\"jp-brand0 jp-icon-selectable\" fill=\"#cb3c33\">\n    <path d=\"M 150.898438 225 C 150.898438 266.421875 117.320312 300 75.898438 300 C 34.476562 300 0.898438 266.421875 0.898438 225 C 0.898438 183.578125 34.476562 150 75.898438 150 C 117.320312 150 150.898438 183.578125 150.898438 225\"/>\n  </g>\n  <g class=\"jp-brand0 jp-icon-selectable\" fill=\"#389826\">\n    <path d=\"M 237.5 75 C 237.5 116.421875 203.921875 150 162.5 150 C 121.078125 150 87.5 116.421875 87.5 75 C 87.5 33.578125 121.078125 0 162.5 0 C 203.921875 0 237.5 33.578125 237.5 75\"/>\n  </g>\n  <g class=\"jp-brand0 jp-icon-selectable\" fill=\"#9558b2\">\n    <path d=\"M 324.101562 225 C 324.101562 266.421875 290.523438 300 249.101562 300 C 207.679688 300 174.101562 266.421875 174.101562 225 C 174.101562 183.578125 207.679688 150 249.101562 150 C 290.523438 150 324.101562 183.578125 324.101562 225\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/keyboard.svg":
/*!**********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/keyboard.svg ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n  <path class=\"jp-icon3 jp-icon-selectable\" fill=\"#616161\" d=\"M20 5H4c-1.1 0-1.99.9-1.99 2L2 17c0 1.1.9 2 2 2h16c1.1 0 2-.9 2-2V7c0-1.1-.9-2-2-2zm-9 3h2v2h-2V8zm0 3h2v2h-2v-2zM8 8h2v2H8V8zm0 3h2v2H8v-2zm-1 2H5v-2h2v2zm0-3H5V8h2v2zm9 7H8v-2h8v2zm0-4h-2v-2h2v2zm0-3h-2V8h2v2zm3 3h-2v-2h2v2zm0-3h-2V8h2v2z\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/launcher.svg":
/*!**********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/launcher.svg ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n  <path class=\"jp-icon3 jp-icon-selectable\" fill=\"#616161\" d=\"M19 19H5V5h7V3H5a2 2 0 00-2 2v14a2 2 0 002 2h14c1.1 0 2-.9 2-2v-7h-2v7zM14 3v2h3.59l-9.83 9.83 1.41 1.41L19 6.41V10h2V3h-7z\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/markdown.svg":
/*!**********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/markdown.svg ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 22 22\">\n  <path class=\"jp-icon-contrast0 jp-icon-selectable\" fill=\"#7B1FA2\" d=\"M5 14.9h12l-6.1 6zm9.4-6.8c0-1.3-.1-2.9-.1-4.5-.4 1.4-.9 2.9-1.3 4.3l-1.3 4.3h-2L8.5 7.9c-.4-1.3-.7-2.9-1-4.3-.1 1.6-.1 3.2-.2 4.6L7 12.4H4.8l.7-11h3.3L10 5c.4 1.2.7 2.7 1 3.9.3-1.2.7-2.6 1-3.9l1.2-3.7h3.3l.6 11h-2.4l-.3-4.2z\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/notebook.svg":
/*!**********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/notebook.svg ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 22 22\">\n  <g class=\"jp-icon-warn0 jp-icon-selectable\" fill=\"#EF6C00\">\n    <path d=\"M18.7 3.3v15.4H3.3V3.3h15.4m1.5-1.5H1.8v18.3h18.3l.1-18.3z\"/>\n    <path d=\"M16.5 16.5l-5.4-4.3-5.6 4.3v-11h11z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/pdf.svg":
/*!*****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/pdf.svg ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg\n   xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 22 22\" width=\"16\">\n    <path transform=\"rotate(45)\" class=\"jp-icon-selectable\" fill=\"#FF2A2A\"\n       d=\"m 22.344369,-3.0163642 h 5.638604 v 1.5792433 h -3.549227 v 1.50869299 h 3.337576 V 1.6508154 h -3.337576 v 3.4352613 h -2.089377 z m -7.136444,1.5792433 v 4.9439543 h 0.74892 q 1.280761,0 1.953703,-0.6349535 0.678369,-0.6349535 0.678369,-1.8451641 0,-1.20478355 -0.672942,-1.83431011 -0.672942,-0.62952659 -1.95913,-0.62952659 z m -2.089377,-1.5792433 h 2.203343 q 1.845164,0 2.746039,0.2659207 0.906301,0.2604937 1.552108,0.8900203 0.56983,0.5481223 0.846605,1.26448006 0.276774,0.71635781 0.276774,1.62265894 0,0.9171551 -0.276774,1.6389399 -0.276775,0.7163578 -0.846605,1.26448 -0.651234,0.6295266 -1.562962,0.8954473 -0.911728,0.2604937 -2.735185,0.2604937 h -2.203343 z m -8.1458565,0 h 3.467823 q 1.5466816,0 2.3715785,0.689223 0.830324,0.6837961 0.830324,1.95370314 0,1.27533397 -0.830324,1.96455706 Q 9.9871961,2.274915 8.4405145,2.274915 H 7.0620684 V 5.0860767 H 4.9726915 Z m 2.0893769,1.5141199 v 2.26303943 h 1.155941 q 0.6078188,0 0.9388629,-0.29305547 0.3310441,-0.29848241 0.3310441,-0.84117772 0,-0.54269531 -0.3310441,-0.83575074 -0.3310441,-0.2930555 -0.9388629,-0.2930555 z\"\n/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/python.svg":
/*!********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/python.svg ***!
  \********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 22 22\">\n  <g class=\"jp-icon-brand0 jp-icon-selectable\" fill=\"#0D47A1\">\n    <path d=\"M11.1 6.9V5.8H6.9c0-.5 0-1.3.2-1.6.4-.7.8-1.1 1.7-1.4 1.7-.3 2.5-.3 3.9-.1 1 .1 1.9.9 1.9 1.9v4.2c0 .5-.9 1.6-2 1.6H8.8c-1.5 0-2.4 1.4-2.4 2.8v2.2H4.7C3.5 15.1 3 14 3 13.1V9c-.1-1 .6-2 1.8-2 1.5-.1 6.3-.1 6.3-.1z\"/>\n    <path d=\"M10.9 15.1v1.1h4.2c0 .5 0 1.3-.2 1.6-.4.7-.8 1.1-1.7 1.4-1.7.3-2.5.3-3.9.1-1-.1-1.9-.9-1.9-1.9v-4.2c0-.5.9-1.6 2-1.6h3.8c1.5 0 2.4-1.4 2.4-2.8V6.6h1.7C18.5 6.9 19 8 19 8.9V13c0 1-.7 2.1-1.9 2.1h-6.2z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/r-kernel.svg":
/*!**********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/r-kernel.svg ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 22 22\">\n  <path class=\"jp-icon-contrast3 jp-icon-selectable\" fill=\"#2196F3\" d=\"M4.4 2.5c1.2-.1 2.9-.3 4.9-.3 2.5 0 4.1.4 5.2 1.3 1 .7 1.5 1.9 1.5 3.5 0 2-1.4 3.5-2.9 4.1 1.2.4 1.7 1.6 2.2 3 .6 1.9 1 3.9 1.3 4.6h-3.8c-.3-.4-.8-1.7-1.2-3.7s-1.2-2.6-2.6-2.6h-.9v6.4H4.4V2.5zm3.7 6.9h1.4c1.9 0 2.9-.9 2.9-2.3s-1-2.3-2.8-2.3c-.7 0-1.3 0-1.6.2v4.5h.1v-.1z\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/react.svg":
/*!*******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/react.svg ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"150 150 541.9 295.3\">\n  <g class=\"jp-icon-brand2 jp-icon-selectable\" fill=\"#61DAFB\">\n    <path d=\"M666.3 296.5c0-32.5-40.7-63.3-103.1-82.4 14.4-63.6 8-114.2-20.2-130.4-6.5-3.8-14.1-5.6-22.4-5.6v22.3c4.6 0 8.3.9 11.4 2.6 13.6 7.8 19.5 37.5 14.9 75.7-1.1 9.4-2.9 19.3-5.1 29.4-19.6-4.8-41-8.5-63.5-10.9-13.5-18.5-27.5-35.3-41.6-50 32.6-30.3 63.2-46.9 84-46.9V78c-27.5 0-63.5 19.6-99.9 53.6-36.4-33.8-72.4-53.2-99.9-53.2v22.3c20.7 0 51.4 16.5 84 46.6-14 14.7-28 31.4-41.3 49.9-22.6 2.4-44 6.1-63.6 11-2.3-10-4-19.7-5.2-29-4.7-38.2 1.1-67.9 14.6-75.8 3-1.8 6.9-2.6 11.5-2.6V78.5c-8.4 0-16 1.8-22.6 5.6-28.1 16.2-34.4 66.7-19.9 130.1-62.2 19.2-102.7 49.9-102.7 82.3 0 32.5 40.7 63.3 103.1 82.4-14.4 63.6-8 114.2 20.2 130.4 6.5 3.8 14.1 5.6 22.5 5.6 27.5 0 63.5-19.6 99.9-53.6 36.4 33.8 72.4 53.2 99.9 53.2 8.4 0 16-1.8 22.6-5.6 28.1-16.2 34.4-66.7 19.9-130.1 62-19.1 102.5-49.9 102.5-82.3zm-130.2-66.7c-3.7 12.9-8.3 26.2-13.5 39.5-4.1-8-8.4-16-13.1-24-4.6-8-9.5-15.8-14.4-23.4 14.2 2.1 27.9 4.7 41 7.9zm-45.8 106.5c-7.8 13.5-15.8 26.3-24.1 38.2-14.9 1.3-30 2-45.2 2-15.1 0-30.2-.7-45-1.9-8.3-11.9-16.4-24.6-24.2-38-7.6-13.1-14.5-26.4-20.8-39.8 6.2-13.4 13.2-26.8 20.7-39.9 7.8-13.5 15.8-26.3 24.1-38.2 14.9-1.3 30-2 45.2-2 15.1 0 30.2.7 45 1.9 8.3 11.9 16.4 24.6 24.2 38 7.6 13.1 14.5 26.4 20.8 39.8-6.3 13.4-13.2 26.8-20.7 39.9zm32.3-13c5.4 13.4 10 26.8 13.8 39.8-13.1 3.2-26.9 5.9-41.2 8 4.9-7.7 9.8-15.6 14.4-23.7 4.6-8 8.9-16.1 13-24.1zM421.2 430c-9.3-9.6-18.6-20.3-27.8-32 9 .4 18.2.7 27.5.7 9.4 0 18.7-.2 27.8-.7-9 11.7-18.3 22.4-27.5 32zm-74.4-58.9c-14.2-2.1-27.9-4.7-41-7.9 3.7-12.9 8.3-26.2 13.5-39.5 4.1 8 8.4 16 13.1 24 4.7 8 9.5 15.8 14.4 23.4zM420.7 163c9.3 9.6 18.6 20.3 27.8 32-9-.4-18.2-.7-27.5-.7-9.4 0-18.7.2-27.8.7 9-11.7 18.3-22.4 27.5-32zm-74 58.9c-4.9 7.7-9.8 15.6-14.4 23.7-4.6 8-8.9 16-13 24-5.4-13.4-10-26.8-13.8-39.8 13.1-3.1 26.9-5.8 41.2-7.9zm-90.5 125.2c-35.4-15.1-58.3-34.9-58.3-50.6 0-15.7 22.9-35.6 58.3-50.6 8.6-3.7 18-7 27.7-10.1 5.7 19.6 13.2 40 22.5 60.9-9.2 20.8-16.6 41.1-22.2 60.6-9.9-3.1-19.3-6.5-28-10.2zM310 490c-13.6-7.8-19.5-37.5-14.9-75.7 1.1-9.4 2.9-19.3 5.1-29.4 19.6 4.8 41 8.5 63.5 10.9 13.5 18.5 27.5 35.3 41.6 50-32.6 30.3-63.2 46.9-84 46.9-4.5-.1-8.3-1-11.3-2.7zm237.2-76.2c4.7 38.2-1.1 67.9-14.6 75.8-3 1.8-6.9 2.6-11.5 2.6-20.7 0-51.4-16.5-84-46.6 14-14.7 28-31.4 41.3-49.9 22.6-2.4 44-6.1 63.6-11 2.3 10.1 4.1 19.8 5.2 29.1zm38.5-66.7c-8.6 3.7-18 7-27.7 10.1-5.7-19.6-13.2-40-22.5-60.9 9.2-20.8 16.6-41.1 22.2-60.6 9.9 3.1 19.3 6.5 28.1 10.2 35.4 15.1 58.3 34.9 58.3 50.6-.1 15.7-23 35.6-58.4 50.6zM320.8 78.4z\"/>\n    <circle cx=\"420.9\" cy=\"296.5\" r=\"45.7\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/settings.svg":
/*!**********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/settings.svg ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n  <path class=\"jp-icon3 jp-icon-selectable\" fill=\"#616161\" d=\"M19.43 12.98c.04-.32.07-.64.07-.98s-.03-.66-.07-.98l2.11-1.65c.19-.15.24-.42.12-.64l-2-3.46c-.12-.22-.39-.3-.61-.22l-2.49 1c-.52-.4-1.08-.73-1.69-.98l-.38-2.65A.488.488 0 0014 2h-4c-.25 0-.46.18-.49.42l-.38 2.65c-.61.25-1.17.59-1.69.98l-2.49-1c-.23-.09-.49 0-.61.22l-2 3.46c-.13.22-.07.49.12.64l2.11 1.65c-.04.32-.07.65-.07.98s.03.66.07.98l-2.11 1.65c-.19.15-.24.42-.12.64l2 3.46c.12.22.39.3.61.22l2.49-1c.52.4 1.08.73 1.69.98l.38 2.65c.03.24.24.42.49.42h4c.25 0 .46-.18.49-.42l.38-2.65c.61-.25 1.17-.59 1.69-.98l2.49 1c.23.09.49 0 .61-.22l2-3.46c.12-.22.07-.49-.12-.64l-2.11-1.65zM12 15.5c-1.93 0-3.5-1.57-3.5-3.5s1.57-3.5 3.5-3.5 3.5 1.57 3.5 3.5-1.57 3.5-3.5 3.5z\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/spreadsheet.svg":
/*!*************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/spreadsheet.svg ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 22 22\">\n  <path class=\"jp-icon-contrast1 jp-icon-selectable\" fill=\"#4CAF50\" d=\"M2.2 2.2v17.6h17.6V2.2H2.2zm15.4 7.7h-5.5V4.4h5.5v5.5zM9.9 4.4v5.5H4.4V4.4h5.5zm-5.5 7.7h5.5v5.5H4.4v-5.5zm7.7 5.5v-5.5h5.5v5.5h-5.5z\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/text-editor.svg":
/*!*************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/text-editor.svg ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n  <path class=\"jp-icon3 jp-icon-selectable\" fill=\"#616161\" d=\"M15 15H3v2h12v-2zm0-8H3v2h12V7zM3 13h18v-2H3v2zm0 8h18v-2H3v2zM3 3v2h18V3H3z\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/vega.svg":
/*!******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/vega.svg ***!
  \******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 22 22\">\n  <g class=\"jp-icon1 jp-icon-selectable\" fill=\"#212121\">\n    <path d=\"M10.6 5.4l2.2-3.2H2.2v7.3l4-6.6z\"/>\n    <path d=\"M15.8 2.2l-4.4 6.6L7 6.3l-4.8 8v5.5h17.6V2.2h-4zm-7 15.4H5.5v-4.4h3.3v4.4zm4.4 0H9.8V9.8h3.4v7.8zm4.4 0h-3.4V6.5h3.4v11.1z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/filetype/yaml.svg":
/*!******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/filetype/yaml.svg ***!
  \******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 22 22\">\n  <g class=\"jp-icon-contrast2 jp-icon-selectable\" fill=\"#D81B60\">\n    <path d=\"M7.2 18.6v-5.4L3 5.6h3.3l1.4 3.1c.3.9.6 1.6 1 2.5.3-.8.6-1.6 1-2.5l1.4-3.1h3.4l-4.4 7.6v5.5l-2.9-.1z\"/>\n    <circle class=\"st0\" cx=\"17.6\" cy=\"16.5\" r=\"2.1\"/>\n    <circle class=\"st0\" cx=\"17.6\" cy=\"11\" r=\"2.1\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/jupyter/jupyter-favicon.svg":
/*!****************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/jupyter/jupyter-favicon.svg ***!
  \****************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg width=\"152\" height=\"165\" viewBox=\"0 0 152 165\" version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\">\n  <g class=\"jp-icon-warn0\" fill=\"#F37726\">\n    <path transform=\"translate(0.078947, 110.582927)\" d=\"M75.9422842,29.5804561 C43.3023947,29.5804561 14.7967832,17.6534634 0,0 C5.51083211,15.8406829 15.7815389,29.5667732 29.3904947,39.2784171 C42.9997,48.9898537 59.2737,54.2067805 75.9605789,54.2067805 C92.6474579,54.2067805 108.921458,48.9898537 122.530663,39.2784171 C136.139453,29.5667732 146.410284,15.8406829 151.921158,0 C137.087868,17.6534634 108.582589,29.5804561 75.9422842,29.5804561 L75.9422842,29.5804561 Z\" />\n    <path transform=\"translate(0.037368, 0.704878)\" d=\"M75.9784579,24.6264073 C108.618763,24.6264073 137.124458,36.5534415 151.921158,54.2067805 C146.410284,38.366222 136.139453,24.6401317 122.530663,14.9284878 C108.921458,5.2168439 92.6474579,0 75.9605789,0 C59.2737,0 42.9997,5.2168439 29.3904947,14.9284878 C15.7815389,24.6401317 5.51083211,38.366222 0,54.2067805 C14.8330816,36.5899293 43.3385684,24.6264073 75.9784579,24.6264073 L75.9784579,24.6264073 Z\" />\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/jupyter/jupyter.svg":
/*!********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/jupyter/jupyter.svg ***!
  \********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg width=\"39\" height=\"51\" viewBox=\"0 0 39 51\" xmlns=\"http://www.w3.org/2000/svg\">\n  <g transform=\"translate(-1638 -2281)\">\n    <g class=\"jp-icon-warn0\" fill=\"#F37726\">\n      <path transform=\"translate(1639.74 2311.98)\" d=\"M 18.2646 7.13411C 10.4145 7.13411 3.55872 4.2576 0 0C 1.32539 3.8204 3.79556 7.13081 7.0686 9.47303C 10.3417 11.8152 14.2557 13.0734 18.269 13.0734C 22.2823 13.0734 26.1963 11.8152 29.4694 9.47303C 32.7424 7.13081 35.2126 3.8204 36.538 0C 32.9705 4.2576 26.1148 7.13411 18.2646 7.13411Z\"/>\n      <path transform=\"translate(1639.73 2285.48)\" d=\"M 18.2733 5.93931C 26.1235 5.93931 32.9793 8.81583 36.538 13.0734C 35.2126 9.25303 32.7424 5.94262 29.4694 3.6004C 26.1963 1.25818 22.2823 0 18.269 0C 14.2557 0 10.3417 1.25818 7.0686 3.6004C 3.79556 5.94262 1.32539 9.25303 0 13.0734C 3.56745 8.82463 10.4232 5.93931 18.2733 5.93931Z\"/>\n    </g>\n    <g class=\"jp-icon3\" fill=\"#616161\">\n      <path transform=\"translate(1669.3 2281.31)\" d=\"M 5.89353 2.844C 5.91889 3.43165 5.77085 4.01367 5.46815 4.51645C 5.16545 5.01922 4.72168 5.42015 4.19299 5.66851C 3.6643 5.91688 3.07444 6.00151 2.49805 5.91171C 1.92166 5.8219 1.38463 5.5617 0.954898 5.16401C 0.52517 4.76633 0.222056 4.24903 0.0839037 3.67757C -0.0542483 3.10611 -0.02123 2.50617 0.178781 1.95364C 0.378793 1.4011 0.736809 0.920817 1.20754 0.573538C 1.67826 0.226259 2.24055 0.0275919 2.82326 0.00267229C 3.60389 -0.0307115 4.36573 0.249789 4.94142 0.782551C 5.51711 1.31531 5.85956 2.05676 5.89353 2.844Z\"/>\n      <path transform=\"translate(1639.8 2323.81)\" d=\"M 7.42789 3.58338C 7.46008 4.3243 7.27355 5.05819 6.89193 5.69213C 6.51031 6.32607 5.95075 6.83156 5.28411 7.1446C 4.61747 7.45763 3.87371 7.56414 3.14702 7.45063C 2.42032 7.33712 1.74336 7.0087 1.20184 6.50695C 0.660328 6.0052 0.27861 5.35268 0.105017 4.63202C -0.0685757 3.91135 -0.0262361 3.15494 0.226675 2.45856C 0.479587 1.76217 0.931697 1.15713 1.52576 0.720033C 2.11983 0.282935 2.82914 0.0334395 3.56389 0.00313344C 4.54667 -0.0374033 5.50529 0.316706 6.22961 0.987835C 6.95393 1.65896 7.38484 2.59235 7.42789 3.58338L 7.42789 3.58338Z\"/>\n      <path transform=\"translate(1638.36 2286.06)\" d=\"M 2.27471 4.39629C 1.84363 4.41508 1.41671 4.30445 1.04799 4.07843C 0.679268 3.8524 0.385328 3.52114 0.203371 3.12656C 0.0214136 2.73198 -0.0403798 2.29183 0.0258116 1.86181C 0.0920031 1.4318 0.283204 1.03126 0.575213 0.710883C 0.867222 0.39051 1.24691 0.164708 1.66622 0.0620592C 2.08553 -0.0405897 2.52561 -0.0154714 2.93076 0.134235C 3.33591 0.283941 3.68792 0.551505 3.94222 0.90306C 4.19652 1.25462 4.34169 1.67436 4.35935 2.10916C 4.38299 2.69107 4.17678 3.25869 3.78597 3.68746C 3.39516 4.11624 2.85166 4.37116 2.27471 4.39629L 2.27471 4.39629Z\"/>\n    </g>\n  </g>>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/jupyter/jupyterlab-wordmark.svg":
/*!********************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/jupyter/jupyterlab-wordmark.svg ***!
  \********************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"200\" viewBox=\"0 0 1860.8 475\">\n  <g class=\"jp-icon2\" fill=\"#4E4E4E\" transform=\"translate(480.136401, 64.271493)\">\n    <g transform=\"translate(0.000000, 58.875566)\">\n      <g transform=\"translate(0.087603, 0.140294)\">\n        <path d=\"M-426.9,169.8c0,48.7-3.7,64.7-13.6,76.4c-10.8,10-25,15.5-39.7,15.5l3.7,29 c22.8,0.3,44.8-7.9,61.9-23.1c17.8-18.5,24-44.1,24-83.3V0H-427v170.1L-426.9,169.8L-426.9,169.8z\"/>\n      </g>\n    </g>\n    <g transform=\"translate(155.045296, 56.837104)\">\n      <g transform=\"translate(1.562453, 1.799842)\">\n        <path d=\"M-312,148c0,21,0,39.5,1.7,55.4h-31.8l-2.1-33.3h-0.8c-6.7,11.6-16.4,21.3-28,27.9 c-11.6,6.6-24.8,10-38.2,9.8c-31.4,0-69-17.7-69-89V0h36.4v112.7c0,38.7,11.6,64.7,44.6,64.7c10.3-0.2,20.4-3.5,28.9-9.4 c8.5-5.9,15.1-14.3,18.9-23.9c2.2-6.1,3.3-12.5,3.3-18.9V0.2h36.4V148H-312L-312,148z\"/>\n      </g>\n    </g>\n    <g transform=\"translate(390.013322, 53.479638)\">\n      <g transform=\"translate(1.706458, 0.231425)\">\n        <path d=\"M-478.6,71.4c0-26-0.8-47-1.7-66.7h32.7l1.7,34.8h0.8c7.1-12.5,17.5-22.8,30.1-29.7 c12.5-7,26.7-10.3,41-9.8c48.3,0,84.7,41.7,84.7,103.3c0,73.1-43.7,109.2-91,109.2c-12.1,0.5-24.2-2.2-35-7.8 c-10.8-5.6-19.9-13.9-26.6-24.2h-0.8V291h-36v-220L-478.6,71.4L-478.6,71.4z M-442.6,125.6c0.1,5.1,0.6,10.1,1.7,15.1 c3,12.3,9.9,23.3,19.8,31.1c9.9,7.8,22.1,12.1,34.7,12.1c38.5,0,60.7-31.9,60.7-78.5c0-40.7-21.1-75.6-59.5-75.6 c-12.9,0.4-25.3,5.1-35.3,13.4c-9.9,8.3-16.9,19.7-19.6,32.4c-1.5,4.9-2.3,10-2.5,15.1V125.6L-442.6,125.6L-442.6,125.6z\"/>\n      </g>\n    </g>\n    <g transform=\"translate(606.740726, 56.837104)\">\n      <g transform=\"translate(0.751226, 1.989299)\">\n        <path d=\"M-440.8,0l43.7,120.1c4.5,13.4,9.5,29.4,12.8,41.7h0.8c3.7-12.2,7.9-27.7,12.8-42.4 l39.7-119.2h38.5L-346.9,145c-26,69.7-43.7,105.4-68.6,127.2c-12.5,11.7-27.9,20-44.6,23.9l-9.1-31.1 c11.7-3.9,22.5-10.1,31.8-18.1c13.2-11.1,23.7-25.2,30.6-41.2c1.5-2.8,2.5-5.7,2.9-8.8c-0.3-3.3-1.2-6.6-2.5-9.7L-480.2,0.1 h39.7L-440.8,0L-440.8,0z\"/>\n      </g>\n    </g>\n    <g transform=\"translate(822.748104, 0.000000)\">\n      <g transform=\"translate(1.464050, 0.378914)\">\n        <path d=\"M-413.7,0v58.3h52v28.2h-52V196c0,25,7,39.5,27.3,39.5c7.1,0.1,14.2-0.7,21.1-2.5 l1.7,27.7c-10.3,3.7-21.3,5.4-32.2,5c-7.3,0.4-14.6-0.7-21.3-3.4c-6.8-2.7-12.9-6.8-17.9-12.1c-10.3-10.9-14.1-29-14.1-52.9 V86.5h-31V58.3h31V9.6L-413.7,0L-413.7,0z\"/>\n      </g>\n    </g>\n    <g transform=\"translate(974.433286, 53.479638)\">\n      <g transform=\"translate(0.990034, 0.610339)\">\n        <path d=\"M-445.8,113c0.8,50,32.2,70.6,68.6,70.6c19,0.6,37.9-3,55.3-10.5l6.2,26.4 c-20.9,8.9-43.5,13.1-66.2,12.6c-61.5,0-98.3-41.2-98.3-102.5C-480.2,48.2-444.7,0-386.5,0c65.2,0,82.7,58.3,82.7,95.7 c-0.1,5.8-0.5,11.5-1.2,17.2h-140.6H-445.8L-445.8,113z M-339.2,86.6c0.4-23.5-9.5-60.1-50.4-60.1 c-36.8,0-52.8,34.4-55.7,60.1H-339.2L-339.2,86.6L-339.2,86.6z\"/>\n      </g>\n    </g>\n    <g transform=\"translate(1201.961058, 53.479638)\">\n      <g transform=\"translate(1.179640, 0.705068)\">\n        <path d=\"M-478.6,68c0-23.9-0.4-44.5-1.7-63.4h31.8l1.2,39.9h1.7c9.1-27.3,31-44.5,55.3-44.5 c3.5-0.1,7,0.4,10.3,1.2v34.8c-4.1-0.9-8.2-1.3-12.4-1.2c-25.6,0-43.7,19.7-48.7,47.4c-1,5.7-1.6,11.5-1.7,17.2v108.3h-36V68 L-478.6,68z\"/>\n      </g>\n    </g>\n  </g>\n\n  <g class=\"jp-icon-warn0\" fill=\"#F37726\">\n    <path d=\"M1352.3,326.2h37V28h-37V326.2z M1604.8,326.2c-2.5-13.9-3.4-31.1-3.4-48.7v-76 c0-40.7-15.1-83.1-77.3-83.1c-25.6,0-50,7.1-66.8,18.1l8.4,24.4c14.3-9.2,34-15.1,53-15.1c41.6,0,46.2,30.2,46.2,47v4.2 c-78.6-0.4-122.3,26.5-122.3,75.6c0,29.4,21,58.4,62.2,58.4c29,0,50.9-14.3,62.2-30.2h1.3l2.9,25.6H1604.8z M1565.7,257.7 c0,3.8-0.8,8-2.1,11.8c-5.9,17.2-22.7,34-49.2,34c-18.9,0-34.9-11.3-34.9-35.3c0-39.5,45.8-46.6,86.2-45.8V257.7z M1698.5,326.2 l1.7-33.6h1.3c15.1,26.9,38.7,38.2,68.1,38.2c45.4,0,91.2-36.1,91.2-108.8c0.4-61.7-35.3-103.7-85.7-103.7 c-32.8,0-56.3,14.7-69.3,37.4h-0.8V28h-36.6v245.7c0,18.1-0.8,38.6-1.7,52.5H1698.5z M1704.8,208.2c0-5.9,1.3-10.9,2.1-15.1 c7.6-28.1,31.1-45.4,56.3-45.4c39.5,0,60.5,34.9,60.5,75.6c0,46.6-23.1,78.1-61.8,78.1c-26.9,0-48.3-17.6-55.5-43.3 c-0.8-4.2-1.7-8.8-1.7-13.4V208.2z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/licenses/copyright.svg":
/*!***********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/licenses/copyright.svg ***!
  \***********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" enable-background=\"new 0 0 24 24\" height=\"24\" viewBox=\"0 0 24 24\" width=\"24\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M11.88,9.14c1.28,0.06,1.61,1.15,1.63,1.66h1.79c-0.08-1.98-1.49-3.19-3.45-3.19C9.64,7.61,8,9,8,12.14 c0,1.94,0.93,4.24,3.84,4.24c2.22,0,3.41-1.65,3.44-2.95h-1.79c-0.03,0.59-0.45,1.38-1.63,1.44C10.55,14.83,10,13.81,10,12.14 C10,9.25,11.28,9.16,11.88,9.14z M12,2C6.48,2,2,6.48,2,12s4.48,10,10,10s10-4.48,10-10S17.52,2,12,2z M12,20c-4.41,0-8-3.59-8-8 s3.59-8,8-8s8,3.59,8,8S16.41,20,12,20z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/listings/listings-info.svg":
/*!***************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/listings/listings-info.svg ***!
  \***************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 50.978 50.978\" style=\"enable-background:new 0 0 50.978 50.978;\" xml:space=\"preserve\">\n\t<g>\n\t\t<path style=\"fill:#010002;\" d=\"M43.52,7.458C38.711,2.648,32.307,0,25.489,0C18.67,0,12.266,2.648,7.458,7.458\n\t\t\tc-9.943,9.941-9.943,26.119,0,36.062c4.809,4.809,11.212,7.456,18.031,7.458c0,0,0.001,0,0.002,0\n\t\t\tc6.816,0,13.221-2.648,18.029-7.458c4.809-4.809,7.457-11.212,7.457-18.03C50.977,18.67,48.328,12.266,43.52,7.458z\n\t\t\t M42.106,42.105c-4.432,4.431-10.332,6.872-16.615,6.872h-0.002c-6.285-0.001-12.187-2.441-16.617-6.872\n\t\t\tc-9.162-9.163-9.162-24.071,0-33.233C13.303,4.44,19.204,2,25.489,2c6.284,0,12.186,2.44,16.617,6.872\n\t\t\tc4.431,4.431,6.871,10.332,6.871,16.617C48.977,31.772,46.536,37.675,42.106,42.105z\"/>\n\t\t<path style=\"fill:#010002;\" d=\"M23.578,32.218c-0.023-1.734,0.143-3.059,0.496-3.972c0.353-0.913,1.11-1.997,2.272-3.253\n\t\t\tc0.468-0.536,0.923-1.062,1.367-1.575c0.626-0.753,1.104-1.478,1.436-2.175c0.331-0.707,0.495-1.541,0.495-2.5\n\t\t\tc0-1.096-0.26-2.088-0.779-2.979c-0.565-0.879-1.501-1.336-2.806-1.369c-1.802,0.057-2.985,0.667-3.55,1.832\n\t\t\tc-0.301,0.535-0.503,1.141-0.607,1.814c-0.139,0.707-0.207,1.432-0.207,2.174h-2.937c-0.091-2.208,0.407-4.114,1.493-5.719\n\t\t\tc1.062-1.64,2.855-2.481,5.378-2.527c2.16,0.023,3.874,0.608,5.141,1.758c1.278,1.16,1.929,2.764,1.95,4.811\n\t\t\tc0,1.142-0.137,2.111-0.41,2.911c-0.309,0.845-0.731,1.593-1.268,2.243c-0.492,0.65-1.068,1.318-1.73,2.002\n\t\t\tc-0.65,0.697-1.313,1.479-1.987,2.346c-0.239,0.377-0.429,0.777-0.565,1.199c-0.16,0.959-0.217,1.951-0.171,2.979\n\t\t\tC26.589,32.218,23.578,32.218,23.578,32.218z M23.578,38.22v-3.484h3.076v3.484H23.578z\"/>\n\t</g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/search/case-sensitive.svg":
/*!**************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/search/case-sensitive.svg ***!
  \**************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 20 20\">\n  <g class=\"jp-icon2\" fill=\"#414141\">\n    <rect x=\"2\" y=\"2\" width=\"16\" height=\"16\"/>\n  </g>\n  <g class=\"jp-icon-accent2\" fill=\"#FFF\">\n    <path d=\"M7.6,8h0.9l3.5,8h-1.1L10,14H6l-0.9,2H4L7.6,8z M8,9.1L6.4,13h3.2L8,9.1z\"/>\n    <path d=\"M16.6,9.8c-0.2,0.1-0.4,0.1-0.7,0.1c-0.2,0-0.4-0.1-0.6-0.2c-0.1-0.1-0.2-0.4-0.2-0.7 c-0.3,0.3-0.6,0.5-0.9,0.7c-0.3,0.1-0.7,0.2-1.1,0.2c-0.3,0-0.5,0-0.7-0.1c-0.2-0.1-0.4-0.2-0.6-0.3c-0.2-0.1-0.3-0.3-0.4-0.5 c-0.1-0.2-0.1-0.4-0.1-0.7c0-0.3,0.1-0.6,0.2-0.8c0.1-0.2,0.3-0.4,0.4-0.5C12,7,12.2,6.9,12.5,6.8c0.2-0.1,0.5-0.1,0.7-0.2 c0.3-0.1,0.5-0.1,0.7-0.1c0.2,0,0.4-0.1,0.6-0.1c0.2,0,0.3-0.1,0.4-0.2c0.1-0.1,0.2-0.2,0.2-0.4c0-1-1.1-1-1.3-1 c-0.4,0-1.4,0-1.4,1.2h-0.9c0-0.4,0.1-0.7,0.2-1c0.1-0.2,0.3-0.4,0.5-0.6c0.2-0.2,0.5-0.3,0.8-0.3C13.3,4,13.6,4,13.9,4 c0.3,0,0.5,0,0.8,0.1c0.3,0,0.5,0.1,0.7,0.2c0.2,0.1,0.4,0.3,0.5,0.5C16,5,16,5.2,16,5.6v2.9c0,0.2,0,0.4,0,0.5 c0,0.1,0.1,0.2,0.3,0.2c0.1,0,0.2,0,0.3,0V9.8z M15.2,6.9c-1.2,0.6-3.1,0.2-3.1,1.4c0,1.4,3.1,1,3.1-0.5V6.9z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/search/regex.svg":
/*!*****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/search/regex.svg ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 20 20\">\n  <g class=\"jp-icon2\" fill=\"#414141\">\n    <rect x=\"2\" y=\"2\" width=\"16\" height=\"16\"/>\n  </g>\n\n  <g class=\"jp-icon-accent2\" fill=\"#FFF\">\n    <circle class=\"st2\" cx=\"5.5\" cy=\"14.5\" r=\"1.5\"/>\n    <rect x=\"12\" y=\"4\" class=\"st2\" width=\"1\" height=\"8\"/>\n    <rect x=\"8.5\" y=\"7.5\" transform=\"matrix(0.866 -0.5 0.5 0.866 -2.3255 7.3219)\" class=\"st2\" width=\"8\" height=\"1\"/>\n    <rect x=\"12\" y=\"4\" transform=\"matrix(0.5 -0.866 0.866 0.5 -0.6779 14.8252)\" class=\"st2\" width=\"1\" height=\"8\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/sidebar/build.svg":
/*!******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/sidebar/build.svg ***!
  \******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg width=\"16\" viewBox=\"0 0 24 24\" xmlns=\"http://www.w3.org/2000/svg\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M14.9 17.45C16.25 17.45 17.35 16.35 17.35 15C17.35 13.65 16.25 12.55 14.9 12.55C13.54 12.55 12.45 13.65 12.45 15C12.45 16.35 13.54 17.45 14.9 17.45ZM20.1 15.68L21.58 16.84C21.71 16.95 21.75 17.13 21.66 17.29L20.26 19.71C20.17 19.86 20 19.92 19.83 19.86L18.09 19.16C17.73 19.44 17.33 19.67 16.91 19.85L16.64 21.7C16.62 21.87 16.47 22 16.3 22H13.5C13.32 22 13.18 21.87 13.15 21.7L12.89 19.85C12.46 19.67 12.07 19.44 11.71 19.16L9.96002 19.86C9.81002 19.92 9.62002 19.86 9.54002 19.71L8.14002 17.29C8.05002 17.13 8.09002 16.95 8.22002 16.84L9.70002 15.68L9.65001 15L9.70002 14.31L8.22002 13.16C8.09002 13.05 8.05002 12.86 8.14002 12.71L9.54002 10.29C9.62002 10.13 9.81002 10.07 9.96002 10.13L11.71 10.84C12.07 10.56 12.46 10.32 12.89 10.15L13.15 8.28998C13.18 8.12998 13.32 7.99998 13.5 7.99998H16.3C16.47 7.99998 16.62 8.12998 16.64 8.28998L16.91 10.15C17.33 10.32 17.73 10.56 18.09 10.84L19.83 10.13C20 10.07 20.17 10.13 20.26 10.29L21.66 12.71C21.75 12.86 21.71 13.05 21.58 13.16L20.1 14.31L20.15 15L20.1 15.68Z\"/>\n    <path d=\"M7.32966 7.44454C8.0831 7.00954 8.33932 6.05332 7.90432 5.29988C7.46932 4.54643 6.5081 4.28156 5.75466 4.71656C5.39176 4.92608 5.12695 5.27118 5.01849 5.67594C4.91004 6.08071 4.96682 6.51198 5.17634 6.87488C5.61134 7.62832 6.57622 7.87954 7.32966 7.44454ZM9.65718 4.79593L10.8672 4.95179C10.9628 4.97741 11.0402 5.07133 11.0382 5.18793L11.0388 6.98893C11.0455 7.10054 10.9616 7.19518 10.855 7.21054L9.66001 7.38083L9.23915 8.13188L9.66961 9.25745C9.70729 9.36271 9.66934 9.47699 9.57408 9.53199L8.01523 10.432C7.91131 10.492 7.79337 10.4677 7.72105 10.3824L6.98748 9.43188L6.10931 9.43083L5.34704 10.3905C5.28909 10.4702 5.17383 10.4905 5.07187 10.4339L3.51245 9.53293C3.41049 9.47633 3.37647 9.35741 3.41075 9.25679L3.86347 8.14093L3.61749 7.77488L3.42347 7.37883L2.23075 7.21297C2.12647 7.19235 2.04049 7.10342 2.04245 6.98682L2.04187 5.18582C2.04383 5.06922 2.11909 4.97958 2.21704 4.96922L3.42065 4.79393L3.86749 4.02788L3.41105 2.91731C3.37337 2.81204 3.41131 2.69776 3.51523 2.63776L5.07408 1.73776C5.16934 1.68276 5.28729 1.70704 5.35961 1.79231L6.11915 2.72788L6.98001 2.73893L7.72496 1.78922C7.79156 1.70458 7.91548 1.67922 8.00879 1.74082L9.56821 2.64182C9.67017 2.69842 9.71285 2.81234 9.68723 2.90797L9.21718 4.03383L9.46316 4.39988L9.65718 4.79593Z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/sidebar/extension.svg":
/*!**********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/sidebar/extension.svg ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M20.5 11H19V7c0-1.1-.9-2-2-2h-4V3.5C13 2.12 11.88 1 10.5 1S8 2.12 8 3.5V5H4c-1.1 0-1.99.9-1.99 2v3.8H3.5c1.49 0 2.7 1.21 2.7 2.7s-1.21 2.7-2.7 2.7H2V20c0 1.1.9 2 2 2h3.8v-1.5c0-1.49 1.21-2.7 2.7-2.7 1.49 0 2.7 1.21 2.7 2.7V22H17c1.1 0 2-.9 2-2v-4h1.5c1.38 0 2.5-1.12 2.5-2.5S21.88 11 20.5 11z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/sidebar/palette.svg":
/*!********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/sidebar/palette.svg ***!
  \********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M18 13V20H4V6H9.02C9.07 5.29 9.24 4.62 9.5 4H4C2.9 4 2 4.9 2 6V20C2 21.1 2.9 22 4 22H18C19.1 22 20 21.1 20 20V15L18 13ZM19.3 8.89C19.74 8.19 20 7.38 20 6.5C20 4.01 17.99 2 15.5 2C13.01 2 11 4.01 11 6.5C11 8.99 13.01 11 15.49 11C16.37 11 17.19 10.74 17.88 10.3L21 13.42L22.42 12L19.3 8.89ZM15.5 9C14.12 9 13 7.88 13 6.5C13 5.12 14.12 4 15.5 4C16.88 4 18 5.12 18 6.5C18 7.88 16.88 9 15.5 9Z\"/>\n    <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M4 6H9.01894C9.00639 6.16502 9 6.33176 9 6.5C9 8.81577 10.211 10.8487 12.0343 12H9V14H16V12.9811C16.5703 12.9377 17.12 12.8207 17.6396 12.6396L18 13V20H4V6ZM8 8H6V10H8V8ZM6 12H8V14H6V12ZM8 16H6V18H8V16ZM9 16H16V18H9V16Z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/sidebar/running.svg":
/*!********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/sidebar/running.svg ***!
  \********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 512 512\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M256 8C119 8 8 119 8 256s111 248 248 248 248-111 248-248S393 8 256 8zm96 328c0 8.8-7.2 16-16 16H176c-8.8 0-16-7.2-16-16V176c0-8.8 7.2-16 16-16h160c8.8 0 16 7.2 16 16v160z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/sidebar/tab.svg":
/*!****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/sidebar/tab.svg ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M21 3H3c-1.1 0-2 .9-2 2v14c0 1.1.9 2 2 2h18c1.1 0 2-.9 2-2V5c0-1.1-.9-2-2-2zm0 16H3V5h10v4h8v10z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/sidebar/toc.svg":
/*!****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/sidebar/toc.svg ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"24\" height=\"24\" viewBox=\"0 0 24 24\">\n  <g class=\"jp-icon3 jp-icon-selectable\" fill=\"#616161\">\n    <path d=\"M7,5H21V7H7V5M7,13V11H21V13H7M4,4.5A1.5,1.5 0 0,1 5.5,6A1.5,1.5 0 0,1 4,7.5A1.5,1.5 0 0,1 2.5,6A1.5,1.5 0 0,1 4,4.5M4,10.5A1.5,1.5 0 0,1 5.5,12A1.5,1.5 0 0,1 4,13.5A1.5,1.5 0 0,1 2.5,12A1.5,1.5 0 0,1 4,10.5M7,19V17H21V19H7M4,16.5A1.5,1.5 0 0,1 5.5,18A1.5,1.5 0 0,1 4,19.5A1.5,1.5 0 0,1 2.5,18A1.5,1.5 0 0,1 4,16.5Z\" />\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/statusbar/kernel.svg":
/*!*********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/statusbar/kernel.svg ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n    <path class=\"jp-icon2\" fill=\"#616161\" d=\"M15 9H9v6h6V9zm-2 4h-2v-2h2v2zm8-2V9h-2V7c0-1.1-.9-2-2-2h-2V3h-2v2h-2V3H9v2H7c-1.1 0-2 .9-2 2v2H3v2h2v2H3v2h2v2c0 1.1.9 2 2 2h2v2h2v-2h2v2h2v-2h2c1.1 0 2-.9 2-2v-2h2v-2h-2v-2h2zm-4 6H7V7h10v10z\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/statusbar/line-form.svg":
/*!************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/statusbar/line-form.svg ***!
  \************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n    <path fill=\"white\" d=\"M5.88 4.12L13.76 12l-7.88 7.88L8 22l10-10L8 2z\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/statusbar/list.svg":
/*!*******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/statusbar/list.svg ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n    <path class=\"jp-icon2 jp-icon-selectable\" fill=\"#616161\" d=\"M19 5v14H5V5h14m1.1-2H3.9c-.5 0-.9.4-.9.9v16.2c0 .4.4.9.9.9h16.2c.4 0 .9-.5.9-.9V3.9c0-.5-.5-.9-.9-.9zM11 7h6v2h-6V7zm0 4h6v2h-6v-2zm0 4h6v2h-6zM7 7h2v2H7zm0 4h2v2H7zm0 4h2v2H7z\"/>\n</svg>");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/statusbar/not-trusted.svg":
/*!**************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/statusbar/not-trusted.svg ***!
  \**************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 25 25\">\n    <path class=\"jp-icon2\" stroke=\"#333333\" stroke-width=\"2\" transform=\"translate(3 3)\" d=\"M1.86094 11.4409C0.826448 8.77027 0.863779 6.05764 1.24907 4.19932C2.48206 3.93347 4.08068 3.40347 5.60102 2.8449C7.23549 2.2444 8.85666 1.5815 9.9876 1.09539C11.0597 1.58341 12.6094 2.2444 14.218 2.84339C15.7503 3.41394 17.3995 3.95258 18.7539 4.21385C19.1364 6.07177 19.1709 8.77722 18.139 11.4409C17.0303 14.3032 14.6668 17.1844 9.99999 18.9354C5.33319 17.1844 2.96968 14.3032 1.86094 11.4409Z\"/>\n    <path class=\"jp-icon2\" stroke=\"#333333\" stroke-width=\"2\" transform=\"translate(9.31592 9.32031)\" d=\"M7.36842 0L0 7.36479\"/>\n    <path class=\"jp-icon2\" stroke=\"#333333\" stroke-width=\"2\" transform=\"translate(9.31592 16.6836) scale(1 -1)\" d=\"M7.36842 0L0 7.36479\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/statusbar/terminal.svg":
/*!***********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/statusbar/terminal.svg ***!
  \***********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\" >\n    <rect class=\"jp-icon2 jp-icon-selectable\" width=\"20\" height=\"20\" transform=\"translate(2 2)\" fill=\"#333333\"/>\n    <path class=\"jp-icon-accent2 jp-icon-selectable-inverse\" d=\"M5.05664 8.76172C5.05664 8.59766 5.03125 8.45312 4.98047 8.32812C4.93359 8.19922 4.85547 8.08203 4.74609 7.97656C4.64062 7.87109 4.5 7.77539 4.32422 7.68945C4.15234 7.59961 3.94336 7.51172 3.69727 7.42578C3.30273 7.28516 2.94336 7.13672 2.61914 6.98047C2.29492 6.82422 2.01758 6.64258 1.78711 6.43555C1.56055 6.22852 1.38477 5.98828 1.25977 5.71484C1.13477 5.4375 1.07227 5.10938 1.07227 4.73047C1.07227 4.39844 1.12891 4.0957 1.24219 3.82227C1.35547 3.54492 1.51562 3.30469 1.72266 3.10156C1.92969 2.89844 2.17969 2.73437 2.47266 2.60938C2.76562 2.48438 3.0918 2.4043 3.45117 2.36914V1.10938H4.38867V2.38086C4.74023 2.42773 5.05664 2.52344 5.33789 2.66797C5.61914 2.8125 5.85742 3.00195 6.05273 3.23633C6.25195 3.4668 6.4043 3.74023 6.50977 4.05664C6.61914 4.36914 6.67383 4.7207 6.67383 5.11133H5.04492C5.04492 4.63867 4.9375 4.28125 4.72266 4.03906C4.50781 3.79297 4.2168 3.66992 3.84961 3.66992C3.65039 3.66992 3.47656 3.69727 3.32812 3.75195C3.18359 3.80273 3.06445 3.87695 2.9707 3.97461C2.87695 4.06836 2.80664 4.17969 2.75977 4.30859C2.7168 4.4375 2.69531 4.57812 2.69531 4.73047C2.69531 4.88281 2.7168 5.01953 2.75977 5.14062C2.80664 5.25781 2.88281 5.36719 2.98828 5.46875C3.09766 5.57031 3.24023 5.66797 3.41602 5.76172C3.5918 5.85156 3.81055 5.94336 4.07227 6.03711C4.4668 6.18555 4.82422 6.33984 5.14453 6.5C5.46484 6.65625 5.73828 6.83984 5.96484 7.05078C6.19531 7.25781 6.37109 7.5 6.49219 7.77734C6.61719 8.05078 6.67969 8.375 6.67969 8.75C6.67969 9.09375 6.62305 9.4043 6.50977 9.68164C6.39648 9.95508 6.23438 10.1914 6.02344 10.3906C5.8125 10.5898 5.55859 10.75 5.26172 10.8711C4.96484 10.9883 4.63281 11.0645 4.26562 11.0996V12.248H3.33398V11.0996C3.00195 11.0684 2.67969 10.9961 2.36719 10.8828C2.05469 10.7656 1.77734 10.5977 1.53516 10.3789C1.29688 10.1602 1.10547 9.88477 0.960938 9.55273C0.816406 9.2168 0.744141 8.81445 0.744141 8.3457H2.37891C2.37891 8.62695 2.41992 8.86328 2.50195 9.05469C2.58398 9.24219 2.68945 9.39258 2.81836 9.50586C2.95117 9.61523 3.10156 9.69336 3.26953 9.74023C3.4375 9.78711 3.60938 9.81055 3.78516 9.81055C4.20312 9.81055 4.51953 9.71289 4.73438 9.51758C4.94922 9.32227 5.05664 9.07031 5.05664 8.76172ZM13.418 12.2715H8.07422V11H13.418V12.2715Z\" transform=\"translate(3.95264 6)\" fill=\"white\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/statusbar/trusted.svg":
/*!**********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/statusbar/trusted.svg ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 25\">\n    <path class=\"jp-icon2\" stroke=\"#333333\" stroke-width=\"2\" transform=\"translate(2 3)\" d=\"M1.86094 11.4409C0.826448 8.77027 0.863779 6.05764 1.24907 4.19932C2.48206 3.93347 4.08068 3.40347 5.60102 2.8449C7.23549 2.2444 8.85666 1.5815 9.9876 1.09539C11.0597 1.58341 12.6094 2.2444 14.218 2.84339C15.7503 3.41394 17.3995 3.95258 18.7539 4.21385C19.1364 6.07177 19.1709 8.77722 18.139 11.4409C17.0303 14.3032 14.6668 17.1844 9.99999 18.9354C5.3332 17.1844 2.96968 14.3032 1.86094 11.4409Z\"/>\n    <path class=\"jp-icon2\" fill=\"#333333\" stroke=\"#333333\" transform=\"translate(8 9.86719)\" d=\"M2.86015 4.86535L0.726549 2.99959L0 3.63045L2.86015 6.13157L8 0.630872L7.27857 0L2.86015 4.86535Z\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/add-above.svg":
/*!**********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/add-above.svg ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg width=\"14\" height=\"14\" viewBox=\"0 0 14 14\" fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\">\n<g clip-path=\"url(#clip0_137_19492)\">\n<path class=\"jp-icon3\" d=\"M4.75 4.93066H6.625V6.80566C6.625 7.01191 6.79375 7.18066 7 7.18066C7.20625 7.18066 7.375 7.01191 7.375 6.80566V4.93066H9.25C9.45625 4.93066 9.625 4.76191 9.625 4.55566C9.625 4.34941 9.45625 4.18066 9.25 4.18066H7.375V2.30566C7.375 2.09941 7.20625 1.93066 7 1.93066C6.79375 1.93066 6.625 2.09941 6.625 2.30566V4.18066H4.75C4.54375 4.18066 4.375 4.34941 4.375 4.55566C4.375 4.76191 4.54375 4.93066 4.75 4.93066Z\" fill=\"#616161\" stroke=\"#616161\" stroke-width=\"0.7\"/>\n</g>\n<path class=\"jp-icon3\" fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M11.5 9.5V11.5L2.5 11.5V9.5L11.5 9.5ZM12 8C12.5523 8 13 8.44772 13 9V12C13 12.5523 12.5523 13 12 13L2 13C1.44772 13 1 12.5523 1 12V9C1 8.44772 1.44771 8 2 8L12 8Z\" fill=\"#616161\"/>\n<defs>\n<clipPath id=\"clip0_137_19492\">\n<rect class=\"jp-icon3\" width=\"6\" height=\"6\" fill=\"white\" transform=\"matrix(-1 0 0 1 10 1.55566)\"/>\n</clipPath>\n</defs>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/add-below.svg":
/*!**********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/add-below.svg ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg width=\"14\" height=\"14\" viewBox=\"0 0 14 14\" fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\">\n<g clip-path=\"url(#clip0_137_19498)\">\n<path class=\"jp-icon3\" d=\"M9.25 10.0693L7.375 10.0693L7.375 8.19434C7.375 7.98809 7.20625 7.81934 7 7.81934C6.79375 7.81934 6.625 7.98809 6.625 8.19434L6.625 10.0693L4.75 10.0693C4.54375 10.0693 4.375 10.2381 4.375 10.4443C4.375 10.6506 4.54375 10.8193 4.75 10.8193L6.625 10.8193L6.625 12.6943C6.625 12.9006 6.79375 13.0693 7 13.0693C7.20625 13.0693 7.375 12.9006 7.375 12.6943L7.375 10.8193L9.25 10.8193C9.45625 10.8193 9.625 10.6506 9.625 10.4443C9.625 10.2381 9.45625 10.0693 9.25 10.0693Z\" fill=\"#616161\" stroke=\"#616161\" stroke-width=\"0.7\"/>\n</g>\n<path class=\"jp-icon3\" fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M2.5 5.5L2.5 3.5L11.5 3.5L11.5 5.5L2.5 5.5ZM2 7C1.44772 7 1 6.55228 1 6L1 3C1 2.44772 1.44772 2 2 2L12 2C12.5523 2 13 2.44772 13 3L13 6C13 6.55229 12.5523 7 12 7L2 7Z\" fill=\"#616161\"/>\n<defs>\n<clipPath id=\"clip0_137_19498\">\n<rect class=\"jp-icon3\" width=\"6\" height=\"6\" fill=\"white\" transform=\"matrix(1 1.74846e-07 1.74846e-07 -1 4 13.4443)\"/>\n</clipPath>\n</defs>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/add.svg":
/*!****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/add.svg ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M19 13h-6v6h-2v-6H5v-2h6V5h2v6h6v2z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/bug-dot.svg":
/*!********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/bug-dot.svg ***!
  \********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg width=\"24\" height=\"24\" viewBox=\"0 0 24 24\" fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\">\n    <g class=\"jp-icon3 jp-icon-selectable\" fill=\"#616161\">\n        <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M17.19 8H20V10H17.91C17.96 10.33 18 10.66 18 11V12H20V14H18.5H18V14.0275C15.75 14.2762 14 16.1837 14 18.5C14 19.208 14.1635 19.8779 14.4549 20.4739C13.7063 20.8117 12.8757 21 12 21C9.78 21 7.85 19.79 6.81 18H4V16H6.09C6.04 15.67 6 15.34 6 15V14H4V12H6V11C6 10.66 6.04 10.33 6.09 10H4V8H6.81C7.26 7.22 7.88 6.55 8.62 6.04L7 4.41L8.41 3L10.59 5.17C11.04 5.06 11.51 5 12 5C12.49 5 12.96 5.06 13.42 5.17L15.59 3L17 4.41L15.37 6.04C16.12 6.55 16.74 7.22 17.19 8ZM10 16H14V14H10V16ZM10 12H14V10H10V12Z\" fill=\"#616161\"/>\n        <path d=\"M22 18.5C22 20.433 20.433 22 18.5 22C16.567 22 15 20.433 15 18.5C15 16.567 16.567 15 18.5 15C20.433 15 22 16.567 22 18.5Z\" fill=\"#616161\"/>\n    </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/bug.svg":
/*!****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/bug.svg ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg viewBox=\"0 0 24 24\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\">\n  <g class=\"jp-icon3 jp-icon-selectable\" fill=\"#616161\">\n    <path d=\"M20 8h-2.81c-.45-.78-1.07-1.45-1.82-1.96L17 4.41 15.59 3l-2.17 2.17C12.96 5.06 12.49 5 12 5c-.49 0-.96.06-1.41.17L8.41 3 7 4.41l1.62 1.63C7.88 6.55 7.26 7.22 6.81 8H4v2h2.09c-.05.33-.09.66-.09 1v1H4v2h2v1c0 .34.04.67.09 1H4v2h2.81c1.04 1.79 2.97 3 5.19 3s4.15-1.21 5.19-3H20v-2h-2.09c.05-.33.09-.66.09-1v-1h2v-2h-2v-1c0-.34-.04-.67-.09-1H20V8zm-6 8h-4v-2h4v2zm0-4h-4v-2h4v2z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/check.svg":
/*!******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/check.svg ***!
  \******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n  <g class=\"jp-icon3 jp-icon-selectable\" fill=\"#616161\">\n    <path d=\"M9 16.17L4.83 12l-1.42 1.41L9 19 21 7l-1.41-1.41z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/circle-empty.svg":
/*!*************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/circle-empty.svg ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M12 2C6.47 2 2 6.47 2 12s4.47 10 10 10 10-4.47 10-10S17.53 2 12 2zm0 18c-4.41 0-8-3.59-8-8s3.59-8 8-8 8 3.59 8 8-3.59 8-8 8z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/circle.svg":
/*!*******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/circle.svg ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg viewBox=\"0 0 18 18\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <circle cx=\"9\" cy=\"9\" r=\"8\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/clear.svg":
/*!******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/clear.svg ***!
  \******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n  <mask id=\"donutHole\">\n    <rect width=\"24\" height=\"24\" fill=\"white\" />\n    <circle cx=\"12\" cy=\"12\" r=\"8\" fill=\"black\"/>\n  </mask>\n\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <rect height=\"18\" width=\"2\" x=\"11\" y=\"3\" transform=\"rotate(315, 12, 12)\"/>\n    <circle cx=\"12\" cy=\"12\" r=\"10\" mask=\"url(#donutHole)\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/close.svg":
/*!******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/close.svg ***!
  \******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg viewBox=\"0 0 24 24\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\">\n  <g class=\"jp-icon-none jp-icon-selectable-inverse jp-icon3-hover\" fill=\"none\">\n    <circle cx=\"12\" cy=\"12\" r=\"11\"/>\n  </g>\n\n  <g class=\"jp-icon3 jp-icon-selectable jp-icon-accent2-hover\" fill=\"#616161\">\n    <path d=\"M19 6.41L17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12z\"/>\n  </g>\n\n  <g class=\"jp-icon-none jp-icon-busy\" fill=\"none\">\n    <circle cx=\"12\" cy=\"12\" r=\"7\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/code.svg":
/*!*****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/code.svg ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg width=\"22\" height=\"22\" viewBox=\"0 0 28 28\" xmlns=\"http://www.w3.org/2000/svg\">\n\t<g class=\"jp-icon3\" fill=\"#616161\">\n\t\t<path d=\"M11.4 18.6L6.8 14L11.4 9.4L10 8L4 14L10 20L11.4 18.6ZM16.6 18.6L21.2 14L16.6 9.4L18 8L24 14L18 20L16.6 18.6V18.6Z\"/>\n\t</g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/copy.svg":
/*!*****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/copy.svg ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg viewBox=\"0 0 18 18\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M11.9,1H3.2C2.4,1,1.7,1.7,1.7,2.5v10.2h1.5V2.5h8.7V1z M14.1,3.9h-8c-0.8,0-1.5,0.7-1.5,1.5v10.2c0,0.8,0.7,1.5,1.5,1.5h8 c0.8,0,1.5-0.7,1.5-1.5V5.4C15.5,4.6,14.9,3.9,14.1,3.9z M14.1,15.5h-8V5.4h8V15.5z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/cut.svg":
/*!****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/cut.svg ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg viewBox=\"0 0 24 24\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M9.64 7.64c.23-.5.36-1.05.36-1.64 0-2.21-1.79-4-4-4S2 3.79 2 6s1.79 4 4 4c.59 0 1.14-.13 1.64-.36L10 12l-2.36 2.36C7.14 14.13 6.59 14 6 14c-2.21 0-4 1.79-4 4s1.79 4 4 4 4-1.79 4-4c0-.59-.13-1.14-.36-1.64L12 14l7 7h3v-1L9.64 7.64zM6 8c-1.1 0-2-.89-2-2s.9-2 2-2 2 .89 2 2-.9 2-2 2zm0 12c-1.1 0-2-.89-2-2s.9-2 2-2 2 .89 2 2-.9 2-2 2zm6-7.5c-.28 0-.5-.22-.5-.5s.22-.5.5-.5.5.22.5.5-.22.5-.5.5zM19 3l-6 6 2 2 7-7V3z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/delete.svg":
/*!*******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/delete.svg ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\" width=\"16px\" height=\"16px\">\n    <path d=\"M0 0h24v24H0z\" fill=\"none\" />\n    <path class=\"jp-icon3\" fill=\"#626262\" d=\"M6 19c0 1.1.9 2 2 2h8c1.1 0 2-.9 2-2V7H6v12zM19 4h-3.5l-1-1h-5l-1 1H5v2h14V4z\" />\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/download.svg":
/*!*********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/download.svg ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg viewBox=\"0 0 24 24\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M19 9h-4V3H9v6H5l7 7 7-7zM5 18v2h14v-2H5z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/duplicate.svg":
/*!**********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/duplicate.svg ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg width=\"14\" height=\"14\" viewBox=\"0 0 14 14\" fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\">\n<path class=\"jp-icon3\" fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M2.79998 0.875H8.89582C9.20061 0.875 9.44998 1.13914 9.44998 1.46198C9.44998 1.78482 9.20061 2.04896 8.89582 2.04896H3.35415C3.04936 2.04896 2.79998 2.3131 2.79998 2.63594V9.67969C2.79998 10.0025 2.55061 10.2667 2.24582 10.2667C1.94103 10.2667 1.69165 10.0025 1.69165 9.67969V2.04896C1.69165 1.40328 2.1904 0.875 2.79998 0.875ZM5.36665 11.9V4.55H11.0833V11.9H5.36665ZM4.14165 4.14167C4.14165 3.69063 4.50728 3.325 4.95832 3.325H11.4917C11.9427 3.325 12.3083 3.69063 12.3083 4.14167V12.3083C12.3083 12.7594 11.9427 13.125 11.4917 13.125H4.95832C4.50728 13.125 4.14165 12.7594 4.14165 12.3083V4.14167Z\" fill=\"#616161\"/>\n<path class=\"jp-icon3\" d=\"M9.43574 8.26507H8.36431V9.3365C8.36431 9.45435 8.26788 9.55078 8.15002 9.55078C8.03217 9.55078 7.93574 9.45435 7.93574 9.3365V8.26507H6.86431C6.74645 8.26507 6.65002 8.16864 6.65002 8.05078C6.65002 7.93292 6.74645 7.8365 6.86431 7.8365H7.93574V6.76507C7.93574 6.64721 8.03217 6.55078 8.15002 6.55078C8.26788 6.55078 8.36431 6.64721 8.36431 6.76507V7.8365H9.43574C9.5536 7.8365 9.65002 7.93292 9.65002 8.05078C9.65002 8.16864 9.5536 8.26507 9.43574 8.26507Z\" fill=\"#616161\" stroke=\"#616161\" stroke-width=\"0.5\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/edit.svg":
/*!*****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/edit.svg ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg viewBox=\"0 0 24 24\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M3 17.25V21h3.75L17.81 9.94l-3.75-3.75L3 17.25zM20.71 7.04c.39-.39.39-1.02 0-1.41l-2.34-2.34c-.39-.39-1.02-.39-1.41 0l-1.83 1.83 3.75 3.75 1.83-1.83z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/ellipses.svg":
/*!*********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/ellipses.svg ***!
  \*********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg viewBox=\"0 0 24 24\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <circle cx=\"5\" cy=\"12\" r=\"2\"/>\n    <circle cx=\"12\" cy=\"12\" r=\"2\"/>\n    <circle cx=\"19\" cy=\"12\" r=\"2\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/fast-forward.svg":
/*!*************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/fast-forward.svg ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"24\" height=\"24\" viewBox=\"0 0 24 24\">\n    <g class=\"jp-icon3\" fill=\"#616161\">\n        <path d=\"M4 18l8.5-6L4 6v12zm9-12v12l8.5-6L13 6z\"/>\n    </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/file-upload.svg":
/*!************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/file-upload.svg ***!
  \************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M9 16h6v-6h4l-7-7-7 7h4zm-4 2h14v2H5z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/filter-list.svg":
/*!************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/filter-list.svg ***!
  \************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M10 18h4v-2h-4v2zM3 6v2h18V6H3zm3 7h12v-2H6v2z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/launch.svg":
/*!*******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/launch.svg ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg viewBox=\"0 0 32 32\" width=\"32\" xmlns=\"http://www.w3.org/2000/svg\">\n  <g class=\"jp-icon3 jp-icon-selectable\" fill=\"#616161\">\n    <path d=\"M26,28H6a2.0027,2.0027,0,0,1-2-2V6A2.0027,2.0027,0,0,1,6,4H16V6H6V26H26V16h2V26A2.0027,2.0027,0,0,1,26,28Z\"/>\n    <polygon points=\"20 2 20 4 26.586 4 18 12.586 19.414 14 28 5.414 28 12 30 12 30 2 20 2\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/link.svg":
/*!*****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/link.svg ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg viewBox=\"0 0 24 24\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M3.9 12c0-1.71 1.39-3.1 3.1-3.1h4V7H7c-2.76 0-5 2.24-5 5s2.24 5 5 5h4v-1.9H7c-1.71 0-3.1-1.39-3.1-3.1zM8 13h8v-2H8v2zm9-6h-4v1.9h4c1.71 0 3.1 1.39 3.1 3.1s-1.39 3.1-3.1 3.1h-4V17h4c2.76 0 5-2.24 5-5s-2.24-5-5-5z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/move-down.svg":
/*!**********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/move-down.svg ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg width=\"14\" height=\"14\" viewBox=\"0 0 14 14\" fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\">\n<path class=\"jp-icon3\" d=\"M12.471 7.52899C12.7632 7.23684 12.7632 6.76316 12.471 6.47101V6.47101C12.179 6.17905 11.7057 6.17884 11.4135 6.47054L7.75 10.1275V1.75C7.75 1.33579 7.41421 1 7 1V1C6.58579 1 6.25 1.33579 6.25 1.75V10.1275L2.59726 6.46822C2.30338 6.17381 1.82641 6.17359 1.53226 6.46774V6.46774C1.2383 6.7617 1.2383 7.2383 1.53226 7.53226L6.29289 12.2929C6.68342 12.6834 7.31658 12.6834 7.70711 12.2929L12.471 7.52899Z\" fill=\"#616161\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/move-up.svg":
/*!********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/move-up.svg ***!
  \********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg width=\"14\" height=\"14\" viewBox=\"0 0 14 14\" fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\">\n<path class=\"jp-icon3\" d=\"M1.52899 6.47101C1.23684 6.76316 1.23684 7.23684 1.52899 7.52899V7.52899C1.82095 7.82095 2.29426 7.82116 2.58649 7.52946L6.25 3.8725V12.25C6.25 12.6642 6.58579 13 7 13V13C7.41421 13 7.75 12.6642 7.75 12.25V3.8725L11.4027 7.53178C11.6966 7.82619 12.1736 7.82641 12.4677 7.53226V7.53226C12.7617 7.2383 12.7617 6.7617 12.4677 6.46774L7.70711 1.70711C7.31658 1.31658 6.68342 1.31658 6.29289 1.70711L1.52899 6.47101Z\" fill=\"#616161\"/>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/new-folder.svg":
/*!***********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/new-folder.svg ***!
  \***********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 24 24\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M20 6h-8l-2-2H4c-1.11 0-1.99.89-1.99 2L2 18c0 1.11.89 2 2 2h16c1.11 0 2-.89 2-2V8c0-1.11-.89-2-2-2zm-1 8h-3v3h-2v-3h-3v-2h3V9h2v3h3v2z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/numbering.svg":
/*!**********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/numbering.svg ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg width=\"22\" height=\"22\" viewBox=\"0 0 28 28\" xmlns=\"http://www.w3.org/2000/svg\">\n\t<g class=\"jp-icon3\" fill=\"#616161\">\n\t\t<path d=\"M4 19H6V19.5H5V20.5H6V21H4V22H7V18H4V19ZM5 10H6V6H4V7H5V10ZM4 13H5.8L4 15.1V16H7V15H5.2L7 12.9V12H4V13ZM9 7V9H23V7H9ZM9 21H23V19H9V21ZM9 15H23V13H9V15Z\"/>\n\t</g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/offline-bolt.svg":
/*!*************************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/offline-bolt.svg ***!
  \*************************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\" width=\"16\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M12 2.02c-5.51 0-9.98 4.47-9.98 9.98s4.47 9.98 9.98 9.98 9.98-4.47 9.98-9.98S17.51 2.02 12 2.02zM11.48 20v-6.26H8L13 4v6.26h3.35L11.48 20z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/paste.svg":
/*!******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/paste.svg ***!
  \******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg height=\"24\" viewBox=\"0 0 24 24\" width=\"24\" xmlns=\"http://www.w3.org/2000/svg\">\n    <g class=\"jp-icon3\" fill=\"#616161\">\n        <path d=\"M19 2h-4.18C14.4.84 13.3 0 12 0c-1.3 0-2.4.84-2.82 2H5c-1.1 0-2 .9-2 2v16c0 1.1.9 2 2 2h14c1.1 0 2-.9 2-2V4c0-1.1-.9-2-2-2zm-7 0c.55 0 1 .45 1 1s-.45 1-1 1-1-.45-1-1 .45-1 1-1zm7 18H5V4h2v3h10V4h2v16z\"/>\n    </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/redo.svg":
/*!*****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/redo.svg ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" height=\"24\" viewBox=\"0 0 24 24\" width=\"16\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n      <path d=\"M0 0h24v24H0z\" fill=\"none\"/><path d=\"M18.4 10.6C16.55 8.99 14.15 8 11.5 8c-4.65 0-8.58 3.03-9.96 7.22L3.9 16c1.05-3.19 4.05-5.5 7.6-5.5 1.95 0 3.73.72 5.12 1.88L13 16h9V7l-3.6 3.6z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/refresh.svg":
/*!********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/refresh.svg ***!
  \********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"16\" viewBox=\"0 0 18 18\">\n    <g class=\"jp-icon3\" fill=\"#616161\">\n        <path d=\"M9 13.5c-2.49 0-4.5-2.01-4.5-4.5S6.51 4.5 9 4.5c1.24 0 2.36.52 3.17 1.33L10 8h5V3l-1.76 1.76C12.15 3.68 10.66 3 9 3 5.69 3 3.01 5.69 3.01 9S5.69 15 9 15c2.97 0 5.43-2.16 5.9-5h-1.52c-.46 2-2.24 3.5-4.38 3.5z\"/>\n    </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/run.svg":
/*!****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/run.svg ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg height=\"24\" viewBox=\"0 0 24 24\" width=\"24\" xmlns=\"http://www.w3.org/2000/svg\">\n    <g class=\"jp-icon3\" fill=\"#616161\">\n        <path d=\"M8 5v14l11-7z\"/>\n    </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/save.svg":
/*!*****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/save.svg ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg height=\"24\" viewBox=\"0 0 24 24\" width=\"24\" xmlns=\"http://www.w3.org/2000/svg\">\n    <g class=\"jp-icon3\" fill=\"#616161\">\n        <path d=\"M17 3H5c-1.11 0-2 .9-2 2v14c0 1.1.89 2 2 2h14c1.1 0 2-.9 2-2V7l-4-4zm-5 16c-1.66 0-3-1.34-3-3s1.34-3 3-3 3 1.34 3 3-1.34 3-3 3zm3-10H5V5h10v4z\"/>\n    </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/search.svg":
/*!*******************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/search.svg ***!
  \*******************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg viewBox=\"0 0 18 18\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M12.1,10.9h-0.7l-0.2-0.2c0.8-0.9,1.3-2.2,1.3-3.5c0-3-2.4-5.4-5.4-5.4S1.8,4.2,1.8,7.1s2.4,5.4,5.4,5.4 c1.3,0,2.5-0.5,3.5-1.3l0.2,0.2v0.7l4.1,4.1l1.2-1.2L12.1,10.9z M7.1,10.9c-2.1,0-3.7-1.7-3.7-3.7s1.7-3.7,3.7-3.7s3.7,1.7,3.7,3.7 S9.2,10.9,7.1,10.9z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/stop.svg":
/*!*****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/stop.svg ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg height=\"24\" viewBox=\"0 0 24 24\" width=\"24\" xmlns=\"http://www.w3.org/2000/svg\">\n    <g class=\"jp-icon3\" fill=\"#616161\">\n        <path d=\"M0 0h24v24H0z\" fill=\"none\"/>\n        <path d=\"M6 6h12v12H6z\"/>\n    </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/table-rows.svg":
/*!***********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/table-rows.svg ***!
  \***********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg height=\"24\" viewBox=\"0 0 24 24\" width=\"24\" xmlns=\"http://www.w3.org/2000/svg\">\n    <g class=\"jp-icon3\" fill=\"#616161\">\n        <path d=\"M0 0h24v24H0z\" fill=\"none\"/>\n        <path d=\"M21,8H3V4h18V8z M21,10H3v4h18V10z M21,16H3v4h18V16z\"/>\n    </g>\n</svg>");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/tag.svg":
/*!****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/tag.svg ***!
  \****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg width=\"28\" height=\"28\" viewBox=\"0 0 43 28\" xmlns=\"http://www.w3.org/2000/svg\">\n\t<g class=\"jp-icon3\" fill=\"#616161\">\n\t\t<path d=\"M28.8332 12.334L32.9998 16.5007L37.1665 12.334H28.8332Z\"/>\n\t\t<path d=\"M16.2095 21.6104C15.6873 22.1299 14.8443 22.1299 14.3248 21.6104L6.9829 14.7245C6.5724 14.3394 6.08313 13.6098 6.04786 13.0482C5.95347 11.5288 6.02002 8.61944 6.06621 7.07695C6.08281 6.51477 6.55548 6.04347 7.11804 6.03055C9.08863 5.98473 13.2638 5.93579 13.6518 6.32425L21.7369 13.639C22.256 14.1585 21.7851 15.4724 21.262 15.9946L16.2095 21.6104ZM9.77585 8.265C9.33551 7.82566 8.62351 7.82566 8.1828 8.265C7.74346 8.70571 7.74346 9.41733 8.1828 9.85667C8.62382 10.2964 9.33582 10.2964 9.77585 9.85667C10.2156 9.41733 10.2156 8.70533 9.77585 8.265Z\"/>\n\t</g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/tree-view.svg":
/*!**********************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/tree-view.svg ***!
  \**********************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg height=\"24\" viewBox=\"0 0 24 24\" width=\"24\" xmlns=\"http://www.w3.org/2000/svg\">\n    <g class=\"jp-icon3\" fill=\"#616161\">\n        <path d=\"M0 0h24v24H0z\" fill=\"none\"/>\n        <path d=\"M22 11V3h-7v3H9V3H2v8h7V8h2v10h4v3h7v-8h-7v3h-2V8h2v3z\"/>\n    </g>\n</svg>");

/***/ }),

/***/ "./node_modules/@jupyterlab/ui-components/style/icons/toolbar/undo.svg":
/*!*****************************************************************************!*\
  !*** ./node_modules/@jupyterlab/ui-components/style/icons/toolbar/undo.svg ***!
  \*****************************************************************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = ("<svg viewBox=\"0 0 24 24\" width=\"16\" xmlns=\"http://www.w3.org/2000/svg\">\n  <g class=\"jp-icon3\" fill=\"#616161\">\n    <path d=\"M12.5 8c-2.65 0-5.05.99-6.9 2.6L2 7v9h9l-3.62-3.62c1.39-1.16 3.16-1.88 5.12-1.88 3.54 0 6.55 2.31 7.6 5.5l2.37-.78C21.08 11.03 17.15 8 12.5 8z\"/>\n  </g>\n</svg>\n");

/***/ }),

/***/ "./node_modules/typestyle/lib/index.js":
/*!*********************************************!*\
  !*** ./node_modules/typestyle/lib/index.js ***!
  \*********************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";

Object.defineProperty(exports, "__esModule", ({ value: true }));
var typestyle_1 = __webpack_require__(/*! ./internal/typestyle */ "./node_modules/typestyle/lib/internal/typestyle.js");
exports.TypeStyle = typestyle_1.TypeStyle;
/**
 * All the CSS types in the 'types' namespace
 */
var types = __webpack_require__(/*! ./types */ "./node_modules/typestyle/lib/types.js");
exports.types = types;
/**
 * Export certain utilities
 */
var utilities_1 = __webpack_require__(/*! ./internal/utilities */ "./node_modules/typestyle/lib/internal/utilities.js");
exports.extend = utilities_1.extend;
exports.classes = utilities_1.classes;
exports.media = utilities_1.media;
/** Zero configuration, default instance of TypeStyle */
var ts = new typestyle_1.TypeStyle({ autoGenerateTag: true });
/** Sets the target tag where we write the css on style updates */
exports.setStylesTarget = ts.setStylesTarget;
/**
 * Insert `raw` CSS as a string. This is useful for e.g.
 * - third party CSS that you are customizing with template strings
 * - generating raw CSS in JavaScript
 * - reset libraries like normalize.css that you can use without loaders
 */
exports.cssRaw = ts.cssRaw;
/**
 * Takes CSSProperties and registers it to a global selector (body, html, etc.)
 */
exports.cssRule = ts.cssRule;
/**
 * Renders styles to the singleton tag imediately
 * NOTE: You should only call it on initial render to prevent any non CSS flash.
 * After that it is kept sync using `requestAnimationFrame` and we haven't noticed any bad flashes.
 **/
exports.forceRenderStyles = ts.forceRenderStyles;
/**
 * Utility function to register an @font-face
 */
exports.fontFace = ts.fontFace;
/**
 * Allows use to use the stylesheet in a node.js environment
 */
exports.getStyles = ts.getStyles;
/**
 * Takes keyframes and returns a generated animationName
 */
exports.keyframes = ts.keyframes;
/**
 * Helps with testing. Reinitializes FreeStyle + raw
 */
exports.reinit = ts.reinit;
/**
 * Takes CSSProperties and return a generated className you can use on your component
 */
exports.style = ts.style;
/**
 * Takes an object where property names are ideal class names and property values are CSSProperties, and
 * returns an object where property names are the same ideal class names and the property values are
 * the actual generated class names using the ideal class name as the $debugName
 */
exports.stylesheet = ts.stylesheet;
/**
 * Creates a new instance of TypeStyle separate from the default instance.
 *
 * - Use this for creating a different typestyle instance for a shadow dom component.
 * - Use this if you don't want an auto tag generated and you just want to collect the CSS.
 *
 * NOTE: styles aren't shared between different instances.
 */
function createTypeStyle(target) {
    var instance = new typestyle_1.TypeStyle({ autoGenerateTag: false });
    if (target) {
        instance.setStylesTarget(target);
    }
    return instance;
}
exports.createTypeStyle = createTypeStyle;


/***/ }),

/***/ "./node_modules/typestyle/lib/internal/formatting.js":
/*!***********************************************************!*\
  !*** ./node_modules/typestyle/lib/internal/formatting.js ***!
  \***********************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";

Object.defineProperty(exports, "__esModule", ({ value: true }));
/**
 * We need to do the following to *our* objects before passing to freestyle:
 * - For any `$nest` directive move up to FreeStyle style nesting
 * - For any `$unique` directive map to FreeStyle Unique
 * - For any `$debugName` directive return the debug name
 */
function convertToStyles(object) {
    /** The final result we will return */
    var styles = {};
    for (var key in object) {
        /** Grab the value upfront */
        var val = object[key];
        /** TypeStyle configuration options */
        if (key === '$nest') {
            var nested = val;
            for (var selector in nested) {
                var subproperties = nested[selector];
                styles[selector] = convertToStyles(subproperties);
            }
        }
        else if (key === '$debugName') {
            styles.$displayName = val;
        }
        else {
            styles[key] = val;
        }
    }
    return styles;
}
exports.convertToStyles = convertToStyles;
// todo: better name here
function convertToKeyframes(frames) {
    var result = {};
    for (var offset in frames) {
        if (offset !== '$debugName') {
            result[offset] = frames[offset];
        }
    }
    if (frames.$debugName) {
        result.$displayName = frames.$debugName;
    }
    return result;
}
exports.convertToKeyframes = convertToKeyframes;


/***/ }),

/***/ "./node_modules/typestyle/lib/internal/typestyle.js":
/*!**********************************************************!*\
  !*** ./node_modules/typestyle/lib/internal/typestyle.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {

"use strict";

Object.defineProperty(exports, "__esModule", ({ value: true }));
var FreeStyle = __webpack_require__(/*! free-style */ "./node_modules/free-style/dist.es2015/index.js");
var formatting_1 = __webpack_require__(/*! ./formatting */ "./node_modules/typestyle/lib/internal/formatting.js");
var utilities_1 = __webpack_require__(/*! ./utilities */ "./node_modules/typestyle/lib/internal/utilities.js");
/**
 * Creates an instance of free style with our options
 */
var createFreeStyle = function () { return FreeStyle.create(); };
/**
 * Maintains a single stylesheet and keeps it in sync with requested styles
 */
var TypeStyle = /** @class */ (function () {
    function TypeStyle(_a) {
        var _this = this;
        var autoGenerateTag = _a.autoGenerateTag;
        /**
         * Insert `raw` CSS as a string. This is useful for e.g.
         * - third party CSS that you are customizing with template strings
         * - generating raw CSS in JavaScript
         * - reset libraries like normalize.css that you can use without loaders
         */
        this.cssRaw = function (mustBeValidCSS) {
            if (!mustBeValidCSS) {
                return;
            }
            _this._raw += mustBeValidCSS || '';
            _this._pendingRawChange = true;
            _this._styleUpdated();
        };
        /**
         * Takes CSSProperties and registers it to a global selector (body, html, etc.)
         */
        this.cssRule = function (selector) {
            var objects = [];
            for (var _i = 1; _i < arguments.length; _i++) {
                objects[_i - 1] = arguments[_i];
            }
            var styles = formatting_1.convertToStyles(utilities_1.extend.apply(void 0, objects));
            _this._freeStyle.registerRule(selector, styles);
            _this._styleUpdated();
            return;
        };
        /**
         * Renders styles to the singleton tag imediately
         * NOTE: You should only call it on initial render to prevent any non CSS flash.
         * After that it is kept sync using `requestAnimationFrame` and we haven't noticed any bad flashes.
         **/
        this.forceRenderStyles = function () {
            var target = _this._getTag();
            if (!target) {
                return;
            }
            target.textContent = _this.getStyles();
        };
        /**
         * Utility function to register an @font-face
         */
        this.fontFace = function () {
            var fontFace = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                fontFace[_i] = arguments[_i];
            }
            var freeStyle = _this._freeStyle;
            for (var _a = 0, _b = fontFace; _a < _b.length; _a++) {
                var face = _b[_a];
                freeStyle.registerRule('@font-face', face);
            }
            _this._styleUpdated();
            return;
        };
        /**
         * Allows use to use the stylesheet in a node.js environment
         */
        this.getStyles = function () {
            return (_this._raw || '') + _this._freeStyle.getStyles();
        };
        /**
         * Takes keyframes and returns a generated animationName
         */
        this.keyframes = function (frames) {
            var keyframes = formatting_1.convertToKeyframes(frames);
            // TODO: replace $debugName with display name
            var animationName = _this._freeStyle.registerKeyframes(keyframes);
            _this._styleUpdated();
            return animationName;
        };
        /**
         * Helps with testing. Reinitializes FreeStyle + raw
         */
        this.reinit = function () {
            /** reinit freestyle */
            var freeStyle = createFreeStyle();
            _this._freeStyle = freeStyle;
            _this._lastFreeStyleChangeId = freeStyle.changeId;
            /** reinit raw */
            _this._raw = '';
            _this._pendingRawChange = false;
            /** Clear any styles that were flushed */
            var target = _this._getTag();
            if (target) {
                target.textContent = '';
            }
        };
        /** Sets the target tag where we write the css on style updates */
        this.setStylesTarget = function (tag) {
            /** Clear any data in any previous tag */
            if (_this._tag) {
                _this._tag.textContent = '';
            }
            _this._tag = tag;
            /** This special time buffer immediately */
            _this.forceRenderStyles();
        };
        /**
         * Takes an object where property names are ideal class names and property values are CSSProperties, and
         * returns an object where property names are the same ideal class names and the property values are
         * the actual generated class names using the ideal class name as the $debugName
         */
        this.stylesheet = function (classes) {
            var classNames = Object.getOwnPropertyNames(classes);
            var result = {};
            for (var _i = 0, classNames_1 = classNames; _i < classNames_1.length; _i++) {
                var className = classNames_1[_i];
                var classDef = classes[className];
                if (classDef) {
                    classDef.$debugName = className;
                    result[className] = _this.style(classDef);
                }
            }
            return result;
        };
        var freeStyle = createFreeStyle();
        this._autoGenerateTag = autoGenerateTag;
        this._freeStyle = freeStyle;
        this._lastFreeStyleChangeId = freeStyle.changeId;
        this._pending = 0;
        this._pendingRawChange = false;
        this._raw = '';
        this._tag = undefined;
        // rebind prototype to TypeStyle.  It might be better to do a function() { return this.style.apply(this, arguments)}
        this.style = this.style.bind(this);
    }
    /**
     * Only calls cb all sync operations settle
     */
    TypeStyle.prototype._afterAllSync = function (cb) {
        var _this = this;
        this._pending++;
        var pending = this._pending;
        utilities_1.raf(function () {
            if (pending !== _this._pending) {
                return;
            }
            cb();
        });
    };
    TypeStyle.prototype._getTag = function () {
        if (this._tag) {
            return this._tag;
        }
        if (this._autoGenerateTag) {
            var tag = typeof window === 'undefined'
                ? { textContent: '' }
                : document.createElement('style');
            if (typeof document !== 'undefined') {
                document.head.appendChild(tag);
            }
            this._tag = tag;
            return tag;
        }
        return undefined;
    };
    /** Checks if the style tag needs updating and if so queues up the change */
    TypeStyle.prototype._styleUpdated = function () {
        var _this = this;
        var changeId = this._freeStyle.changeId;
        var lastChangeId = this._lastFreeStyleChangeId;
        if (!this._pendingRawChange && changeId === lastChangeId) {
            return;
        }
        this._lastFreeStyleChangeId = changeId;
        this._pendingRawChange = false;
        this._afterAllSync(function () { return _this.forceRenderStyles(); });
    };
    TypeStyle.prototype.style = function () {
        var className = this._freeStyle.registerStyle(formatting_1.convertToStyles(utilities_1.extend.apply(undefined, arguments)));
        this._styleUpdated();
        return className;
    };
    return TypeStyle;
}());
exports.TypeStyle = TypeStyle;


/***/ }),

/***/ "./node_modules/typestyle/lib/internal/utilities.js":
/*!**********************************************************!*\
  !*** ./node_modules/typestyle/lib/internal/utilities.js ***!
  \**********************************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";

Object.defineProperty(exports, "__esModule", ({ value: true }));
/** Raf for node + browser */
exports.raf = typeof requestAnimationFrame === 'undefined'
    /**
     * Make sure setTimeout is always invoked with
     * `this` set to `window` or `global` automatically
     **/
    ? function (cb) { return setTimeout(cb); }
    /**
     * Make sure window.requestAnimationFrame is always invoked with `this` window
     * We might have raf without window in case of `raf/polyfill` (recommended by React)
     **/
    : typeof window === 'undefined'
        ? requestAnimationFrame
        : requestAnimationFrame.bind(window);
/**
 * Utility to join classes conditionally
 */
function classes() {
    var classes = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        classes[_i] = arguments[_i];
    }
    return classes
        .map(function (c) { return c && typeof c === 'object' ? Object.keys(c).map(function (key) { return !!c[key] && key; }) : [c]; })
        .reduce(function (flattened, c) { return flattened.concat(c); }, [])
        .filter(function (c) { return !!c; })
        .join(' ');
}
exports.classes = classes;
/**
 * Merges various styles into a single style object.
 * Note: if two objects have the same property the last one wins
 */
function extend() {
    var objects = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        objects[_i] = arguments[_i];
    }
    /** The final result we will return */
    var result = {};
    for (var _a = 0, objects_1 = objects; _a < objects_1.length; _a++) {
        var object = objects_1[_a];
        if (object == null || object === false) {
            continue;
        }
        for (var key in object) {
            /** Falsy values except a explicit 0 is ignored */
            var val = object[key];
            if (!val && val !== 0) {
                continue;
            }
            /** if nested media or pseudo selector */
            if (key === '$nest' && val) {
                result[key] = result['$nest'] ? extend(result['$nest'], val) : val;
            }
            /** if freestyle sub key that needs merging. We come here due to our recursive calls */
            else if ((key.indexOf('&') !== -1 || key.indexOf('@media') === 0)) {
                result[key] = result[key] ? extend(result[key], val) : val;
            }
            else {
                result[key] = val;
            }
        }
    }
    return result;
}
exports.extend = extend;
/**
 * Utility to help customize styles with media queries. e.g.
 * ```
 * style(
 *  media({maxWidth:500}, {color:'red'})
 * )
 * ```
 */
exports.media = function (mediaQuery) {
    var _a;
    var objects = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        objects[_i - 1] = arguments[_i];
    }
    var mediaQuerySections = [];
    if (mediaQuery.type)
        mediaQuerySections.push(mediaQuery.type);
    if (mediaQuery.orientation)
        mediaQuerySections.push("(orientation: " + mediaQuery.orientation + ")");
    if (mediaQuery.minWidth)
        mediaQuerySections.push("(min-width: " + mediaLength(mediaQuery.minWidth) + ")");
    if (mediaQuery.maxWidth)
        mediaQuerySections.push("(max-width: " + mediaLength(mediaQuery.maxWidth) + ")");
    if (mediaQuery.minHeight)
        mediaQuerySections.push("(min-height: " + mediaLength(mediaQuery.minHeight) + ")");
    if (mediaQuery.maxHeight)
        mediaQuerySections.push("(max-height: " + mediaLength(mediaQuery.maxHeight) + ")");
    var stringMediaQuery = "@media " + mediaQuerySections.join(' and ');
    var object = {
        $nest: (_a = {},
            _a[stringMediaQuery] = extend.apply(void 0, objects),
            _a)
    };
    return object;
};
var mediaLength = function (value) {
    return typeof value === 'string' ? value : value + "px";
};


/***/ }),

/***/ "./node_modules/typestyle/lib/types.js":
/*!*********************************************!*\
  !*** ./node_modules/typestyle/lib/types.js ***!
  \*********************************************/
/***/ ((__unused_webpack_module, exports) => {

"use strict";

Object.defineProperty(exports, "__esModule", ({ value: true }));


/***/ })

}]);
//# sourceMappingURL=vendors-node_modules_blueprintjs_icons_lib_esm_generated_iconNames_js-node_modules_jupyterlab-6aeeed.209aef617b8b41aa9ac3.js.map